@@ -176,7 +176,7 @@ AssistantBase("Export", "export")
 
   GSList *radiobutton_bible_type_group = NULL;
 
-  radiobutton_bible_usfm = gtk_radio_button_new_with_mnemonic (NULL, "Unified Standard Format Marker (USFM)");
+  radiobutton_bible_usfm = gtk_radio_button_new_with_mnemonic (NULL, "Unified Standard Format Markers (USFM)");
   gtk_widget_show (radiobutton_bible_usfm);
   gtk_box_pack_start (GTK_BOX (vbox_bible_type), radiobutton_bible_usfm, FALSE, FALSE, 0);
   gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_bible_usfm), radiobutton_bible_type_group);
@@ -533,9 +533,9 @@ AssistantBase("Export", "export")
   gtk_assistant_set_page_type (GTK_ASSISTANT (assistant), label_confirm, GTK_ASSISTANT_PAGE_CONFIRM);
   gtk_assistant_set_page_complete (GTK_ASSISTANT (assistant), label_confirm, true);
   
-  label_progress = gtk_label_new ("");
+  label_progress = gtk_label_new ("Export in progress");
   gtk_widget_show (label_progress);
-  gtk_assistant_append_page (GTK_ASSISTANT (assistant), label_progress);
+  page_number_progress = gtk_assistant_append_page (GTK_ASSISTANT (assistant), label_progress);
 
   gtk_assistant_set_page_title (GTK_ASSISTANT (assistant), label_progress, "");
   gtk_assistant_set_page_type (GTK_ASSISTANT (assistant), label_progress, GTK_ASSISTANT_PAGE_PROGRESS);
@@ -649,6 +649,8 @@ void ExportAssistant::on_assistant_apply_signal (GtkAssistant *assistant, gpoint
 
 void ExportAssistant::on_assistant_apply ()
 {
+  // Show progress page.
+  gtk_assistant_set_current_page (GTK_ASSISTANT (assistant), page_number_progress);
   // Take action depending on the type of export.
   switch (get_type()) {
     case etBible:
@@ -939,10 +941,12 @@ gint ExportAssistant::assistant_forward (gint current_page)
   forward_sequence.insert (page_number_confirm);
   forward_sequence.insert (summary_page_number);
   
-  // Take the next page in the forward sequence.
-  do {
-    current_page++;
-  } while (forward_sequence.find (current_page) == forward_sequence.end());
+  // Take the next page in the forward sequence if there's one available.
+  if (current_page < summary_page_number) {
+    do {
+      current_page++;
+    } while (forward_sequence.find (current_page) == forward_sequence.end());
+  }
   return current_page;
 }
 
