@@ -19,7 +19,6 @@
 
 
 #include "libraries.h"
-#include "exception.h"
 #include "mainwindow.h"
 #include "directories.h"
 #include "utilities.h"
@@ -27,7 +26,6 @@
 #include "directories.h"
 #include "dialogshowscript.h"
 #include "shell.h"
-#include "user.h"
 #include "maintenance.h"
 #include "gtkwrappers.h"
 #include "upgrade.h"
@@ -42,9 +40,10 @@
 #include <libxml/xmlreader.h>
 #include "vcs.h"
 #include "d_bus.h"
+#include "startup.h"
 
 
-// DBus * dbus;
+DBus * dbus;
 Settings *settings;
 BookLocalizations *booklocalizations;
 Versifications *versifications;
@@ -56,19 +55,45 @@ VCS *vcs;
 
 int main(int argc, char *argv[])
 {
-  // Unhandled exception handler.
-  set_terminate(terminator);
-  // Handler for unexpected exceptions.
-  set_unexpected(my_unexpected);
-  // Do not allow to run as root.
-  if (runs_as_root())
-    return 1;
   // Initialize g threads.
   g_thread_init(NULL);
+  // Initialize g types.
+  g_type_init();
+  // Initialize GTK
+  gtk_init(&argc, &argv);
+
+  // Check whether it is fine to start the program.
+  if (!check_bibledit_startup_okay(argc, argv)) {
+    // Quit the program normally.
+    return 0;
+  }
+
+  // Save logfile from previous session.
+  if (g_file_test (log_file_name(false).c_str(), G_FILE_TEST_IS_REGULAR)) {
+    GwSpawn spawn ("mv");
+    spawn.arg ("-f");
+    spawn.arg (log_file_name(false));
+    spawn.arg (log_file_name(true));
+    spawn.run ();
+  }
+
+  // Redirect stdout and stderr to file.
+  {
+    // When a file is opened it is always allocated the lowest available file 
+    // descriptor. Therefore the following commands cause stdout to be 
+    // redirected to the logfile.
+    close(1);
+    creat (log_file_name(false).c_str(), 0666); 
+    // The dup() routine makes a duplicate file descriptor for an already opened 
+    // file using the first available file descriptor. Therefore the following 
+    // commands cause stderr to be redirected to the file stdout writes to.
+    close(2);
+    if (dup(1));
+  }    
+
   // Initialize the dbus.
-  //DBus mydbus (dbntOrgBibleditMain);
-  //dbus = &mydbus;
-  // todo Check through the dbus whether bibledit is already running.
+  DBus mydbus (0);
+  dbus = &mydbus;
   // Initialize the xml library.
   xmlInitParser();
   // Check on default data structure.
@@ -76,8 +101,7 @@ int main(int argc, char *argv[])
   // Maintenance system.
   maintenance_initialize ();
   // Settings object. 
-  // Only save the settings on exit if there is no scripting.
-  Settings mysettings(argc == 1);
+  Settings mysettings(true);
   settings = &mysettings;
   // LocalizedBooks object.
   BookLocalizations mybooklocalizations(0);
@@ -91,8 +115,6 @@ int main(int argc, char *argv[])
   // Styles object.
   Styles mystyles(0);
   styles = &mystyles;
-  // Initialize g types.
-  g_type_init();
   // Version control object.
   VCS myvcs (0);
   vcs = &myvcs;
@@ -118,11 +140,9 @@ int main(int argc, char *argv[])
     xembed = strtoul(argv[2], &argv[2], 0);
     if (*argv[2] != 0) {
       fprintf(stderr, "Bad xembed value: %s\n", argv[2]);
-      return 1;
+      return 0;
     }
   }
-  // Initialize GTK
-  gtk_init(&argc, &argv);
   // Upgrade data.
   upgrade();
   // Window icon fallback.
