@@ -1,9 +1,9 @@
 /*
-** Copyright (C) 2003-2006 Teus Benschop.
+** Copyright (©) 2003-2009 Teus Benschop.
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 **  
 ** This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
 **  
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
-** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 **  
 */
 
@@ -23,6 +23,7 @@
 
 
 #include "libraries.h"
+#include "progresswindow.h"
 
 
 class CheckValidateUsfm
@@ -35,6 +36,7 @@ public:
   ~CheckValidateUsfm ();
   vector<ustring> references;
   vector<ustring> comments;
+  bool cancelled;
 private:
   unsigned int book;
   unsigned int chapter;
@@ -44,8 +46,9 @@ private:
   void check (const ustring& text);
   void deprecated_marker (const ustring& marker);
   ustring usfm_extract_marker_with_forwardslash (ustring & line);
-  void check_on_endmarker (ustring& line, const ustring& marker);
+  void check_on_endmarker (ustring& line, const ustring& marker, bool optional);
   void message (const ustring& message);
+  ProgressWindow * progresswindow;
 };
 
 
