@@ -1,9 +1,9 @@
 /*
-** Copyright (C) 2003-2006 Teus Benschop.
+** Copyright (©) 2003-2009 Teus Benschop.
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 **  
 ** This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
 **  
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
-** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 **  
 */
 
@@ -24,13 +24,16 @@
 
 #include "libraries.h"
 #include <gdk/gdk.h>
+#include <gtk/gtk.h>
 
 
 void color_decimal_to_gdk (unsigned int colour, GdkColor * color);
 unsigned int color_gdk_to_decimal (GdkColor * color);
 ustring color_decimal_to_hex (unsigned int colour);
-ustring color_xslfo (unsigned int color);
-ustring color_odt (unsigned int color);
+void color_widget_default (GtkWidget * widget);
+void color_widget_set (GtkWidget * widget, 
+                       unsigned int normal_text, unsigned int background, 
+                       unsigned int selected_text, unsigned int selection);
 
 
 #endif
