@@ -17,6 +17,7 @@
 **  
 */
 
+
 #include "libraries.h"
 #include "dialogproject.h"
 #include "utilities.h"
@@ -28,7 +29,6 @@
 #include <glib.h>
 #include "stylesheetutils.h"
 #include "constants.h"
-#include "dialogimporttext.h"
 #include "gwrappers.h"
 #include "gtkwrappers.h"
 #include "combobox.h"
@@ -46,8 +46,10 @@
 #include "scripts.h"
 #include "dialogdictionary.h"
 
+
 #define NEW_PROJECT "New Project"
 
+
 ProjectDialog::ProjectDialog(bool newproject)
 {
   // Settings.
@@ -172,28 +174,6 @@ ProjectDialog::ProjectDialog(bool newproject)
 
   shortcuts.label(label6);
 
-  importbutton = gtk_button_new();
-  gtk_widget_show(importbutton);
-  gtk_table_attach(GTK_TABLE(table1), importbutton, 0, 1, 2, 3, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-
-  alignment3 = gtk_alignment_new(0.5, 0.5, 0, 0);
-  gtk_widget_show(alignment3);
-  gtk_container_add(GTK_CONTAINER(importbutton), alignment3);
-
-  hbox5 = gtk_hbox_new(FALSE, 2);
-  gtk_widget_show(hbox5);
-  gtk_container_add(GTK_CONTAINER(alignment3), hbox5);
-
-  image3 = gtk_image_new_from_stock("gtk-add", GTK_ICON_SIZE_BUTTON);
-  gtk_widget_show(image3);
-  gtk_box_pack_start(GTK_BOX(hbox5), image3, FALSE, FALSE, 0);
-
-  label10 = gtk_label_new_with_mnemonic("Import");
-  gtk_widget_show(label10);
-  gtk_box_pack_start(GTK_BOX(hbox5), label10, FALSE, FALSE, 0);
-
-  shortcuts.label(label10);
-
   hseparator1 = gtk_hseparator_new();
   gtk_widget_show(hseparator1);
   gtk_box_pack_start(GTK_BOX(vbox1), hseparator1, TRUE, TRUE, 2);
@@ -325,7 +305,6 @@ ProjectDialog::ProjectDialog(bool newproject)
   g_signal_connect((gpointer) checkbutton_editable, "toggled", G_CALLBACK(on_checkbutton_editable_toggled), gpointer(this));
   g_signal_connect((gpointer) addbutton, "clicked", G_CALLBACK(projectdialog_on_addbutton_clicked), gpointer(this));
   g_signal_connect((gpointer) deletebutton, "clicked", G_CALLBACK(projectdialog_on_deletebutton_clicked), gpointer(this));
-  g_signal_connect((gpointer) importbutton, "clicked", G_CALLBACK(on_importbutton_clicked), gpointer(this));
   g_signal_connect((gpointer) cancelbutton1, "clicked", G_CALLBACK(projectdialog_on_cancelbutton1_clicked), gpointer(this));
   g_signal_connect((gpointer) okbutton1, "clicked", G_CALLBACK(projectdialog_on_okbutton1_clicked), gpointer(this));
   g_signal_connect((gpointer) checkbutton_dependent, "toggled", G_CALLBACK(on_checkbutton_dependent_toggled), gpointer(this));
@@ -346,16 +325,19 @@ ProjectDialog::ProjectDialog(bool newproject)
   set_gui();
 }
 
+
 ProjectDialog::~ProjectDialog()
 {
   gtk_widget_destroy(projectdialog);
 }
 
+
 int ProjectDialog::run()
 {
   return gtk_dialog_run(GTK_DIALOG(projectdialog));
 }
 
+
 void ProjectDialog::set_gui()
 {
   bool sensitive = true;
@@ -395,7 +377,6 @@ void ProjectDialog::set_gui()
   gtk_widget_set_sensitive(messagelabel, editable);
   gtk_widget_set_sensitive(addbutton, editable);
   gtk_widget_set_sensitive(deletebutton, editable && project_get_books(currentprojectname).size() > 0);
-  gtk_widget_set_sensitive(importbutton, editable);
   gtk_widget_set_sensitive(combobox_versification, editable);
   gtk_widget_set_sensitive(combobox_language, editable);
   gtk_widget_set_sensitive(label1, editable);
@@ -412,6 +393,7 @@ void ProjectDialog::set_gui()
   gtk_widget_set_sensitive(button_dictionaries, sensitive);
 }
 
+
 void ProjectDialog::on_ok()
 {
   // Deal with possible new projectname.
@@ -507,12 +489,14 @@ void ProjectDialog::on_ok()
 
 }
 
+
 void ProjectDialog::on_cancel()
 {
   // Remove the "New Project". It was created but not used.
   project_delete(NEW_PROJECT);
 }
 
+
 void ProjectDialog::on_book_add()
 {
 /*
@@ -580,6 +564,7 @@ void ProjectDialog::on_book_add()
   set_gui();
 }
 
+
 void ProjectDialog::on_book_delete()
 {
   vector < unsigned int >selectables;
@@ -621,57 +606,50 @@ void ProjectDialog::on_book_delete()
   set_gui();
 }
 
-void ProjectDialog::on_import()
-{
-  extern Settings *settings;
-  ustring project = settings->genconfig.project_get();
-  settings->genconfig.project_set(currentprojectname);
-  ImportTextDialog dialog(0);
-  dialog.run();
-  settings->genconfig.project_set(project);
-  set_gui();
-}
+
 
 void ProjectDialog::projectdialog_on_nameentry_changed(GtkEditable * editable, gpointer user_data)
 {
   ((ProjectDialog *) user_data)->set_gui();
 }
 
+
 void ProjectDialog::projectdialog_on_okbutton1_clicked(GtkButton * button, gpointer user_data)
 {
   ((ProjectDialog *) user_data)->on_ok();
 }
 
+
 void ProjectDialog::projectdialog_on_addbutton_clicked(GtkButton * button, gpointer user_data)
 {
   ((ProjectDialog *) user_data)->on_book_add();
 }
 
+
 void ProjectDialog::projectdialog_on_deletebutton_clicked(GtkButton * button, gpointer user_data)
 {
   ((ProjectDialog *) user_data)->on_book_delete();
 }
 
+
 void ProjectDialog::projectdialog_on_cancelbutton1_clicked(GtkButton * button, gpointer user_data)
 {
   ((ProjectDialog *) user_data)->on_cancel();
 }
 
-void ProjectDialog::on_importbutton_clicked(GtkButton * button, gpointer user_data)
-{
-  ((ProjectDialog *) user_data)->on_import();
-}
 
 void ProjectDialog::on_checkbutton_editable_toggled(GtkToggleButton * togglebutton, gpointer user_data)
 {
   ((ProjectDialog *) user_data)->set_gui();
 }
 
+
 void ProjectDialog::on_checkbutton_dependent_toggled(GtkToggleButton * togglebutton, gpointer user_data)
 {
   ((ProjectDialog *) user_data)->on_checkbutton_dependent();
 }
 
+
 void ProjectDialog::on_checkbutton_dependent()
 {
   bool on = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbutton_dependent));
@@ -683,11 +661,13 @@ void ProjectDialog::on_checkbutton_dependent()
   gtk_widget_set_sensitive(combobox_depend, on);
 }
 
+
 void ProjectDialog::on_button_depend_clicked(GtkButton * button, gpointer user_data)
 {
   ((ProjectDialog *) user_data)->on_button_depend();
 }
 
+
 void ProjectDialog::on_button_depend()
 {
   ustring project(dependent_project());
@@ -696,6 +676,7 @@ void ProjectDialog::on_button_depend()
   }
 }
 
+
 ustring ProjectDialog::dependent_project(const ustring & project)
 {
   ustring label(project);
@@ -704,11 +685,13 @@ ustring ProjectDialog::dependent_project(const ustring & project)
   return label;
 }
 
+
 ustring ProjectDialog::none_project()
 {
   return "<none>";
 }
 
+
 ustring ProjectDialog::dependent_project()
 // Gets the project name from the button.
 {
@@ -718,18 +701,23 @@ ustring ProjectDialog::dependent_project()
   return project;
 }
 
+
 void ProjectDialog::on_button_dictionaries_clicked(GtkButton * button, gpointer user_data)
 {
   ((ProjectDialog *) user_data)->on_button_dictionaries();
 }
 
+
 void ProjectDialog::on_button_dictionaries()
 {
   DictionaryDialog dialog(currentprojectname);
   dialog.run();
 }
 
+
 void ProjectDialog::on_checkbutton_spelling_toggled(GtkToggleButton * togglebutton, gpointer user_data)
 {
   ((ProjectDialog *) user_data)->set_gui();
 }
+
+
