@@ -29,7 +29,7 @@
 class RadiobuttonDialog
 {
 public:
-  RadiobuttonDialog (const ustring& title, const ustring& info, const vector <ustring>& labels, unsigned int selection);
+  RadiobuttonDialog (const ustring& title, const ustring& info, const vector <ustring>& labels, unsigned int selection, bool autoscale);
   ~RadiobuttonDialog ();
   int run ();
   unsigned int selection;
@@ -37,11 +37,16 @@ protected:
   GtkWidget *radiobuttondialog;
   GtkWidget *dialog_vbox1;
   GtkWidget *label;
+  GtkWidget *scrolledwindow1;
+  GtkWidget *viewport1;
+  GtkWidget *vbox1;
   GtkWidget *dialog_action_area1;
   GtkWidget *cancelbutton;
   GtkWidget *okbutton;
 private:
   vector <GtkWidget *> radiobuttons;
+  static gboolean on_radiobutton_button_press_event (GtkWidget *widget, GdkEventButton *event, gpointer user_data);
+  void radiobutton_button_press_event (GdkEventButton *event);
   static void on_okbutton_clicked (GtkButton *button, gpointer user_data);
   void on_okbutton ();
 };
