@@ -17,6 +17,7 @@
  **  
  */
 
+
 #include "libraries.h"
 #include "dialogsearchspecial.h"
 #include "dialogselectbooks.h"
@@ -31,15 +32,16 @@
 #include "settings.h"
 #include "gui.h"
 
-#define RESULTS_LOAD   "Load them in the References Area"
-#define RESULTS_ADD    "Add them to the ones already in the References Area"
-#define RESULTS_REMOVE "Remove them from the ones already in the References Area"
-#define RESULTS_SHARE  "Share them with the ones already in the References Area"
 
-SearchSpecialDialog::SearchSpecialDialog(BibleTime * bibletime)
+#define RESULTS_LOAD   "Load them in the references window"
+#define RESULTS_ADD    "Add them to the ones already in the references window"
+#define RESULTS_REMOVE "Remove them from the ones already in the references window"
+#define RESULTS_SHARE  "Share them with the ones already in the references window"
+
+
+SearchSpecialDialog::SearchSpecialDialog(int dummy)
 {
   extern Settings *settings;
-  mybibletime = bibletime;
 
   accel_group = gtk_accel_group_new();
 
@@ -72,7 +74,7 @@ SearchSpecialDialog::SearchSpecialDialog(BibleTime * bibletime)
   gtk_widget_show(label19);
   gtk_notebook_set_tab_label(GTK_NOTEBOOK(notebook_mode), gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook_mode), 0), label19);
 
-  label22 = gtk_label_new("Press Control-F for searching in BibleTime");
+  label22 = gtk_label_new("Press Control-F for Basic search");
   gtk_widget_show(label22);
   gtk_container_add(GTK_CONTAINER(notebook_mode), label22);
 
@@ -80,14 +82,6 @@ SearchSpecialDialog::SearchSpecialDialog(BibleTime * bibletime)
   gtk_widget_show(label20);
   gtk_notebook_set_tab_label(GTK_NOTEBOOK(notebook_mode), gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook_mode), 1), label20);
 
-  label18 = gtk_label_new("Press Control-F for Basic search");
-  gtk_widget_show(label18);
-  gtk_container_add(GTK_CONTAINER(notebook_mode), label18);
-
-  label21 = gtk_label_new("BibleTime");
-  gtk_widget_show(label21);
-  gtk_notebook_set_tab_label(GTK_NOTEBOOK(notebook_mode), gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook_mode), 2), label21);
-
   hbox1 = gtk_hbox_new(FALSE, 4);
   gtk_widget_show(hbox1);
   gtk_box_pack_start(GTK_BOX(vbox3), hbox1, TRUE, TRUE, 0);
@@ -261,101 +255,6 @@ SearchSpecialDialog::SearchSpecialDialog(BibleTime * bibletime)
   gtk_widget_show(label32);
   gtk_notebook_set_tab_label(GTK_NOTEBOOK(notebook_advanced), gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook_advanced), 1), label32);
 
-  vbox8 = gtk_vbox_new(FALSE, 4);
-  gtk_widget_show(vbox8);
-  gtk_container_add(GTK_CONTAINER(notebook_advanced), vbox8);
-
-  label26 = gtk_label_new("Search in:");
-  gtk_widget_show(label26);
-  gtk_box_pack_start(GTK_BOX(vbox8), label26, FALSE, FALSE, 0);
-  gtk_misc_set_alignment(GTK_MISC(label26), 0, 0.5);
-
-  GSList *radiobutton_bt_default_group = NULL;  // Moved here
-
-  radiobutton_bt_default = gtk_radio_button_new_with_mnemonic(NULL, "_Standard Bible");
-  gtk_widget_show(radiobutton_bt_default);
-  gtk_box_pack_start(GTK_BOX(vbox8), radiobutton_bt_default, FALSE, FALSE, 0);
-  gtk_radio_button_set_group(GTK_RADIO_BUTTON(radiobutton_bt_default), radiobutton_bt_default_group);
-  radiobutton_bt_default_group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(radiobutton_bt_default));
-
-  radiobutton_bt_open = gtk_radio_button_new_with_mnemonic(NULL, "_Open modules");
-  gtk_widget_show(radiobutton_bt_open);
-  gtk_box_pack_start(GTK_BOX(vbox8), radiobutton_bt_open, FALSE, FALSE, 0);
-  gtk_radio_button_set_group(GTK_RADIO_BUTTON(radiobutton_bt_open), radiobutton_bt_default_group);
-  radiobutton_bt_default_group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(radiobutton_bt_open));
-
-  table1 = gtk_table_new(2, 2, FALSE);
-  gtk_widget_show(table1);
-  gtk_box_pack_start(GTK_BOX(vbox8), table1, FALSE, FALSE, 0);
-
-  radiobutton_bt_bible = gtk_radio_button_new_with_mnemonic(NULL, "_Bible");
-  gtk_widget_show(radiobutton_bt_bible);
-  gtk_table_attach(GTK_TABLE(table1), radiobutton_bt_bible, 0, 1, 0, 1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-  gtk_radio_button_set_group(GTK_RADIO_BUTTON(radiobutton_bt_bible), radiobutton_bt_default_group);
-  radiobutton_bt_default_group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(radiobutton_bt_bible));
-
-  radiobutton_bt_commentary = gtk_radio_button_new_with_mnemonic(NULL, "Co_mmentary");
-  gtk_widget_show(radiobutton_bt_commentary);
-  gtk_table_attach(GTK_TABLE(table1), radiobutton_bt_commentary, 0, 1, 1, 2, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-  gtk_radio_button_set_group(GTK_RADIO_BUTTON(radiobutton_bt_commentary), radiobutton_bt_default_group);
-  radiobutton_bt_default_group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(radiobutton_bt_commentary));
-
-  // Set which radio button will be active.
-  switch (settings->session.searchbibletimetype) {
-  case sbttDefaultBible:
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radiobutton_bt_default), true);
-    break;
-  case sbttOpenModules:
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radiobutton_bt_open), true);
-    break;
-  case sbttBible:
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radiobutton_bt_bible), true);
-    break;
-  case sbttCommentary:
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radiobutton_bt_commentary), true);
-    break;
-  }
-
-  combobox_bt_bibles = gtk_combo_box_new_text();        // Modified.
-  gtk_widget_show(combobox_bt_bibles);
-  gtk_table_attach(GTK_TABLE(table1), combobox_bt_bibles, 1, 2, 0, 1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (GTK_FILL), 0, 0);
-
-  combobox_bt_commentaries = gtk_combo_box_new_text();  // Modified
-  gtk_widget_show(combobox_bt_commentaries);
-  gtk_table_attach(GTK_TABLE(table1), combobox_bt_commentaries, 1, 2, 1, 2, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (GTK_FILL), 0, 0);
-
-  // Load modules in the combos.
-  vector < ustring > modules;
-  modules = bibletime->getbibles();
-  combobox_set_strings(combobox_bt_bibles, modules);
-  if (modules.size() > 0) {
-    if (settings->session.search_bibletime_bible.length() > 0)
-      combobox_set_string(combobox_bt_bibles, settings->session.search_bibletime_bible);
-    else
-      combobox_set_string(combobox_bt_bibles, modules[0]);
-  }
-  modules.clear();
-  modules = bibletime->getcommentaries();
-  combobox_set_strings(combobox_bt_commentaries, modules);
-  if (modules.size() > 0) {
-    if (settings->session.search_bibletime_commentary.length() > 0)
-      combobox_set_string(combobox_bt_commentaries, settings->session.search_bibletime_commentary);
-    else
-      combobox_set_string(combobox_bt_commentaries, modules[0]);
-  }
-
-  label33 = gtk_label_new("");
-  gtk_widget_show(label33);
-  gtk_notebook_set_tab_label(GTK_NOTEBOOK(notebook_advanced), gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook_advanced), 2), label33);
-
-  empty_notebook_page = gtk_vbox_new(FALSE, 0);
-  gtk_widget_show(empty_notebook_page);
-  gtk_container_add(GTK_CONTAINER(notebook_advanced), empty_notebook_page);
-
-  label34 = gtk_label_new("");
-  gtk_widget_show(label34);
-  gtk_notebook_set_tab_label(GTK_NOTEBOOK(notebook_advanced), gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook_advanced), 3), label34);
-
   notebook_results = gtk_notebook_new();
   gtk_widget_show(notebook_results);
   gtk_box_pack_start(GTK_BOX(vbox3), notebook_results, TRUE, TRUE, 0);
@@ -451,8 +350,6 @@ SearchSpecialDialog::SearchSpecialDialog(BibleTime * bibletime)
   g_signal_connect((gpointer) button_area, "clicked", G_CALLBACK(on_button_area_clicked), gpointer(this));
   g_signal_connect((gpointer) findbutton, "clicked", G_CALLBACK(on_findbutton_clicked), gpointer(this));
   g_signal_connect_after((gpointer) notebook_mode, "switch_page", G_CALLBACK(on_notebook_mode_switch_page), gpointer(this));
-  g_signal_connect_after((gpointer) radiobutton_bt_bible, "toggled", G_CALLBACK(on_radiobutton_bt_bible_toggled), gpointer(this));
-  g_signal_connect_after((gpointer) radiobutton_bt_commentary, "toggled", G_CALLBACK(on_radiobutton_bt_commentary_toggled), gpointer(this));
 
   gtk_label_set_mnemonic_widget(GTK_LABEL(label_word_entry), word_entry);
   gtk_label_set_mnemonic_widget(GTK_LABEL(label14), combobox_results);
@@ -474,45 +371,36 @@ SearchSpecialDialog::SearchSpecialDialog(BibleTime * bibletime)
       on_control_f();
   }
 
-  if (!bibletime->connected()) {
-    // BibleTime is not available: set a couple of widgets insensitive.
-    gtk_widget_set_sensitive(radiobutton_bt_default, false);
-    gtk_widget_set_sensitive(radiobutton_bt_open, false);
-    gtk_widget_set_sensitive(radiobutton_bt_bible, false);
-    gtk_widget_set_sensitive(radiobutton_bt_commentary, false);
-    gtk_widget_set_sensitive(combobox_bt_bibles, false);
-    gtk_widget_set_sensitive(combobox_bt_commentaries, false);
-    gtk_widget_set_sensitive(label26, false);
-  }
   // Present the window after a while because other windows created may take away the focus.
   dialogpresenter = new DialogPresenter(searchspecialdialog);
 }
 
+
 SearchSpecialDialog::~SearchSpecialDialog()
 {
   delete dialogpresenter;
   gtk_widget_destroy(searchspecialdialog);
 }
 
+
 int SearchSpecialDialog::run()
 {
   return gtk_dialog_run(GTK_DIALOG(searchspecialdialog));
 }
 
+
 void SearchSpecialDialog::on_word_entry_changed(GtkEditable * editable, gpointer user_data)
 {
   ((SearchSpecialDialog *) user_data)->set_gui();
 }
 
+
 void SearchSpecialDialog::set_gui()
 {
   extern Settings *settings;
   bool findbuttonsensitive;
   string searchword = gtk_entry_get_text(GTK_ENTRY(word_entry));
   findbuttonsensitive = (searchword.size() > 0);
-  if (gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook_mode)) == 2)
-    if (!mybibletime->connected())
-      findbuttonsensitive = false;
   gtk_widget_set_sensitive(findbutton, findbuttonsensitive);
   bool searchcurrentbook = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbutton_current_book));
   gtk_widget_set_sensitive(button_books, !searchcurrentbook);
@@ -524,11 +412,13 @@ void SearchSpecialDialog::set_gui()
   gtk_label_set_text(GTK_LABEL(label_area), area_information().c_str());
 }
 
+
 void SearchSpecialDialog::on_findbutton_clicked(GtkButton * button, gpointer user_data)
 {
   ((SearchSpecialDialog *) user_data)->on_find();
 }
 
+
 void SearchSpecialDialog::on_find()
 {
   extern Settings *settings;
@@ -556,29 +446,20 @@ void SearchSpecialDialog::on_find()
   case sstSubtract:
   case sstShare:
     {
-      SessionHighlights
-          sessionhighlights(settings->session.searchword, settings->session.search_case_sensitive, settings->session.search_globbing, settings->session.search_start_word_match, settings->session.search_end_word_match, settings->session.area_type, settings->session.area_id, settings->session.area_intro, settings->session.area_heading, settings->session.area_chapter, settings->session.area_study, settings->session.area_notes, settings->session.area_xref, settings->session.area_verse);
+      SessionHighlights sessionhighlights(settings->session.searchword, settings->session.search_case_sensitive, settings->session.search_globbing, settings->session.search_start_word_match, settings->session.search_end_word_match, settings->session.area_type, settings->session.area_id, settings->session.area_intro, settings->session.area_heading, settings->session.area_chapter, settings->session.area_study, settings->session.area_notes, settings->session.area_xref, settings->session.area_verse);
       settings->session.highlights.push_back(sessionhighlights);
     }
   }
   completion_finish(word_entry, cpSearch);
-  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radiobutton_bt_default)))
-    settings->session.searchbibletimetype = sbttDefaultBible;
-  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radiobutton_bt_open)))
-    settings->session.searchbibletimetype = sbttOpenModules;
-  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radiobutton_bt_bible)))
-    settings->session.searchbibletimetype = sbttBible;
-  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radiobutton_bt_commentary)))
-    settings->session.searchbibletimetype = sbttCommentary;
-  settings->session.search_bibletime_bible = combobox_get_active_string(combobox_bt_bibles);
-  settings->session.search_bibletime_commentary = combobox_get_active_string(combobox_bt_commentaries);
 }
 
+
 void SearchSpecialDialog::on_button_books_clicked(GtkButton * button, gpointer user_data)
 {
   ((SearchSpecialDialog *) user_data)->on_books();
 }
 
+
 void SearchSpecialDialog::on_books()
 {
   extern Settings *settings;
@@ -590,16 +471,19 @@ void SearchSpecialDialog::on_books()
   set_gui();
 }
 
+
 void SearchSpecialDialog::on_checkbutton_current_book_toggled(GtkToggleButton * togglebutton, gpointer user_data)
 {
   ((SearchSpecialDialog *) user_data)->set_gui();
 }
 
+
 void SearchSpecialDialog::on_button_area_clicked(GtkButton * button, gpointer user_data)
 {
   ((SearchSpecialDialog *) user_data)->on_button_area();
 }
 
+
 void SearchSpecialDialog::on_button_area()
 {
   AreaDialog dialog(0);
@@ -607,28 +491,32 @@ void SearchSpecialDialog::on_button_area()
   set_gui();
 }
 
+
 void SearchSpecialDialog::on_searchspecialdialog_activate_focus(GtkWindow * window, gpointer user_data)
 {
   ((SearchSpecialDialog *) user_data)->on_control_f();
 }
 
+
 void SearchSpecialDialog::on_control_f()
 {
   allow_activate = false;
   g_timeout_add(1, GSourceFunc(on_timeout), gpointer(this));
   int page = gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook_mode));
   page++;
-  if (page > 2)
+  if (page > 1)
     page = 0;
   gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook_mode), page);
   gtk_widget_grab_focus(word_entry);
 }
 
+
 void SearchSpecialDialog::on_notebook_mode_switch_page(GtkNotebook * notebook, GtkNotebookPage * page, guint page_num, gpointer user_data)
 {
   ((SearchSpecialDialog *) user_data)->on_mode_change(page_num);
 }
 
+
 void SearchSpecialDialog::on_mode_change(guint page_num)
 // When the search mode changes (Simple / Advanced / BibleTime / ...), then
 // update the other notebooks too.
@@ -659,34 +547,13 @@ void SearchSpecialDialog::on_mode_change(guint page_num)
   set_gui();
 }
 
-void SearchSpecialDialog::on_radiobutton_bt_bible_toggled(GtkToggleButton * togglebutton, gpointer user_data)
-{
-  ((SearchSpecialDialog *) user_data)->focus_bible();
-}
-
-void SearchSpecialDialog::focus_bible()
-{
-  gtk_widget_grab_focus(combobox_bt_bibles);
-  // This does not work at present. It would need a timer that focuses
-  // the widget shortly after the button switched on.
-}
-
-void SearchSpecialDialog::on_radiobutton_bt_commentary_toggled(GtkToggleButton * togglebutton, gpointer user_data)
-{
-  ((SearchSpecialDialog *) user_data)->focus_commentary();
-}
-
-void SearchSpecialDialog::focus_commentary()
-{
-  gtk_widget_grab_focus(combobox_bt_commentaries);
-  // This does not work, see above.
-}
 
 void SearchSpecialDialog::on_word_entry_activate(GtkEntry * entry, gpointer user_data)
 {
   ((SearchSpecialDialog *) user_data)->on_activate();
 }
 
+
 void SearchSpecialDialog::on_activate()
 {
   // If the find button is disabled, bail out.
@@ -698,13 +565,17 @@ void SearchSpecialDialog::on_activate()
   }
 }
 
+
 bool SearchSpecialDialog::on_timeout(gpointer data)
 {
   ((SearchSpecialDialog *) data)->timeout();
   return false;
 }
 
+
 void SearchSpecialDialog::timeout()
 {
   allow_activate = true;
 }
+
+
