@@ -17,6 +17,7 @@
 **  
 */
 
+
 #include "libraries.h"
 #include <glib.h>
 #include "dialogselectbooks.h"
@@ -32,6 +33,7 @@
 #include "listview.h"
 #include <gdk/gdkkeysyms.h>
 #include "gwrappers.h"
+#include "screen.h"
 
 
 SelectBooksDialog::SelectBooksDialog(bool showportions)
@@ -55,7 +57,6 @@ bookset: Indicator for the caller's relevant books.
   Shortcuts shortcuts(0);
 
   selectbooksdialog = gtk_dialog_new();
-  gtk_widget_set_size_request(selectbooksdialog, -1, 600);
   ustring title("Select books");
   if (showportions)
     title.append(" and portions");
@@ -337,19 +338,24 @@ bookset: Indicator for the caller's relevant books.
   if (myshowportions) {
     update_gui_event_id = g_timeout_add_full(G_PRIORITY_DEFAULT, 100, GSourceFunc(on_update_gui_timeout), gpointer(this), NULL);
   }
+
+  new DialogAutoScaler (selectbooksdialog, G_MAXINT);
 }
 
+
 SelectBooksDialog::~SelectBooksDialog()
 {
   gw_destroy_source(update_gui_event_id);
   gtk_widget_destroy(selectbooksdialog);
 }
 
+
 int SelectBooksDialog::run()
 {
   return gtk_dialog_run(GTK_DIALOG(selectbooksdialog));
 }
 
+
 void SelectBooksDialog::language(const ustring & language)
 /*
 Sets the language to display the books in.
@@ -362,6 +368,7 @@ It will reload the books.
   loadbooks();
 }
 
+
 void SelectBooksDialog::selectables(vector < unsigned int >&selectablebooks)
 // Sets the selectables books, if this is different from the books in the project.
 {
@@ -369,6 +376,7 @@ void SelectBooksDialog::selectables(vector < unsigned int >&selectablebooks)
   loadbooks();
 }
 
+
 void SelectBooksDialog::selection_set(const set < unsigned int >&selectedbooks)
 // Sets the selected books.
 {
@@ -376,11 +384,13 @@ void SelectBooksDialog::selection_set(const set < unsigned int >&selectedbooks)
   loadbooks();
 }
 
+
 gboolean SelectBooksDialog::on_treeviewbooks_key_press_event(GtkWidget * widget, GdkEventKey * event, gpointer user_data)
 {
   return ((SelectBooksDialog *) user_data)->on_treeviewbooks_key_press(event);
 }
 
+
 gboolean SelectBooksDialog::on_treeviewbooks_key_press(GdkEventKey * event)
 {
   // Take special action on Enter: OK button.
@@ -393,11 +403,13 @@ gboolean SelectBooksDialog::on_treeviewbooks_key_press(GdkEventKey * event)
   return false;
 }
 
+
 void SelectBooksDialog::on_treeviewportions_row_activated(GtkTreeView * treeview, GtkTreePath * path, GtkTreeViewColumn * column, gpointer user_data)
 {
   ((SelectBooksDialog *) user_data)->on_treeviewportions_row();
 }
 
+
 void SelectBooksDialog::on_treeviewportions_row()
 {
   // Get the selected portion and the offset of it, and the corresponding book.
@@ -423,21 +435,25 @@ void SelectBooksDialog::on_treeviewportions_row()
   gtk_tree_selection_unselect_all(selectportions);
 }
 
+
 void SelectBooksDialog::on_nobutton_clicked(GtkButton * button, gpointer user_data)
 {
   ((SelectBooksDialog *) user_data)->on_button_no();
 }
 
+
 void SelectBooksDialog::on_button_no()
 {
   gtk_tree_selection_unselect_all(selectbooks);
 }
 
+
 void SelectBooksDialog::on_otbutton_clicked(GtkButton * button, gpointer user_data)
 {
   ((SelectBooksDialog *) user_data)->on_button_ot();
 }
 
+
 void SelectBooksDialog::on_button_ot()
 {
   vector < unsigned int >ids = books_type_to_ids(btOldTestament);
@@ -448,11 +464,13 @@ void SelectBooksDialog::on_button_ot()
   loadbooks();
 }
 
+
 void SelectBooksDialog::on_ntbutton_clicked(GtkButton * button, gpointer user_data)
 {
   ((SelectBooksDialog *) user_data)->on_button_nt();
 }
 
+
 void SelectBooksDialog::on_button_nt()
 {
   vector < unsigned int >ids = books_type_to_ids(btNewTestament);
@@ -463,11 +481,13 @@ void SelectBooksDialog::on_button_nt()
   loadbooks();
 }
 
+
 void SelectBooksDialog::on_otherbutton_clicked(GtkButton * button, gpointer user_data)
 {
   ((SelectBooksDialog *) user_data)->on_button_other();
 }
 
+
 void SelectBooksDialog::on_button_other()
 {
   myselection.clear();
@@ -482,21 +502,25 @@ void SelectBooksDialog::on_button_other()
   loadbooks();
 }
 
+
 void SelectBooksDialog::on_allbutton_clicked(GtkButton * button, gpointer user_data)
 {
   ((SelectBooksDialog *) user_data)->on_button_all();
 }
 
+
 void SelectBooksDialog::on_button_all()
 {
   gtk_tree_selection_select_all(selectbooks);
 }
 
+
 void SelectBooksDialog::on_currentbutton_clicked(GtkButton * button, gpointer user_data)
 {
   ((SelectBooksDialog *) user_data)->on_button_current();
 }
 
+
 void SelectBooksDialog::on_button_current()
 {
   myselection.clear();
@@ -505,11 +529,13 @@ void SelectBooksDialog::on_button_current()
   loadbooks();
 }
 
+
 void SelectBooksDialog::on_okbutton_clicked(GtkButton * button, gpointer user_data)
 {
   ((SelectBooksDialog *) user_data)->on_okbutton();
 }
 
+
 void SelectBooksDialog::on_okbutton()
 {
   // Get the list of books now selected.
@@ -551,6 +577,7 @@ void SelectBooksDialog::on_okbutton()
   }
 }
 
+
 void SelectBooksDialog::selection_display(set < unsigned int >&books)
 {
   // Get the model
@@ -593,6 +620,7 @@ void SelectBooksDialog::selection_display(set < unsigned int >&books)
   }
 }
 
+
 void SelectBooksDialog::loadbooks()
 {
   // Translate and load the selectable books.
@@ -605,6 +633,7 @@ void SelectBooksDialog::loadbooks()
   selection_display(myselection);
 }
 
+
 void SelectBooksDialog::selection_foreach_function(GtkTreeModel * model, GtkTreePath * path, GtkTreeIter * iter, gpointer data)
 {
   gchar *book;
@@ -613,6 +642,7 @@ void SelectBooksDialog::selection_foreach_function(GtkTreeModel * model, GtkTree
   g_free(book);
 }
 
+
 void SelectBooksDialog::loadportions()
 {
   // Get the list of (included) books and their portions.
@@ -632,12 +662,14 @@ void SelectBooksDialog::loadportions()
   listview_set_strings(treeviewportions, storeportions, portions);
 }
 
+
 bool SelectBooksDialog::on_update_gui_timeout(gpointer user_data)
 {
   ((SelectBooksDialog *) user_data)->update_gui();
   return true;
 }
 
+
 void SelectBooksDialog::update_gui()
 {
   // Get the upper corners of the visible area of both treeviews.
