@@ -1,9 +1,9 @@
 /*
-** Copyright (C) 2003-2006 Teus Benschop.
+** Copyright (©) 2003-2009 Teus Benschop.
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 **  
 ** This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
 **  
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
-** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 **  
 */
 
@@ -32,7 +32,7 @@
 class ExportTranslationNotes
 {
 public:
-  ExportTranslationNotes (const ustring& filename, ExportNotesFormat format, const vector<unsigned int> & ids_to_display, bool export_all, GtkWidget * parent);
+  ExportTranslationNotes (const ustring& filename, const vector<unsigned int> & ids_to_display, bool export_all);
   ~ExportTranslationNotes ();
 private:
   sqlite3 *db;
@@ -43,7 +43,6 @@ private:
   bool my_export_all;
   set<gint> * my_ids;
   WriteText * my_wt;
-  ExportNotesFormat myformat;
   ProgressWindow progresswindow;
   static int count_callback (void *userdata, int argc, char **argv, char **column_names);
   void on_count (int argc, char **argv);
