@@ -17,6 +17,7 @@
  **  
  */
 
+
 #include "settings.h"
 #include "directories.h"
 #include "gwrappers.h"
@@ -28,16 +29,20 @@
 #include <libxml/xmlreader.h>
 #include <libxml/xmlwriter.h>
 #include "config.xml.h"
+#include "windowsoutpost.h"
+
 
 ustring general_configuration_filename()
 {
   return gw_build_filename(directories_get_configuration(), "configuration.1.xml");
 }
 
+
 void upgrade_configuration()
 {
 }
 
+
 /*
  A test was done on to see if the cause of irregular crashes of Bibledit, 
  when used a lot, is, that GeneralConfiguration was always left open in mainwindow.
@@ -49,6 +54,7 @@ void upgrade_configuration()
  uses the database, hence it is not relevant in this particular case.
  */
 
+
 GeneralConfiguration::GeneralConfiguration(bool save_on_destroy)
 /*
  This version of the general configuration uses a fast, in-memory system 
@@ -76,28 +82,12 @@ GeneralConfiguration::GeneralConfiguration(bool save_on_destroy)
   INITIALIZE (window_x_position);
   INITIALIZE (window_y_position);
   INITIALIZE (window_maximized);
-  INITIALIZE(menu_area_width);
-  INITIALIZE(menu_area_height);
-  INITIALIZE(menu_area_x_position);
-  INITIALIZE(menu_area_y_position);
-  INITIALIZE(text_area_width);
-  INITIALIZE(text_area_height);
-  INITIALIZE(text_area_x_position);
-  INITIALIZE(text_area_y_position);
-  INITIALIZE(notes_area_width);
-  INITIALIZE(notes_area_height);
-  INITIALIZE(notes_area_x_position);
-  INITIALIZE(notes_area_y_position);
-  INITIALIZE(tools_area_width);
-  INITIALIZE(tools_area_height);
-  INITIALIZE(tools_area_x_position);
-  INITIALIZE(tools_area_y_position);
   INITIALIZE(window_widths);
   INITIALIZE(window_heights);
   INITIALIZE(window_x_positions);
   INITIALIZE(window_y_positions);
   INITIALIZE(window_ids);
-  INITIALIZE(window_datas);
+  INITIALIZE(window_titles);
   INITIALIZE(window_shows);
   INITIALIZE(edit_note_standard_text_one);
   INITIALIZE(edit_note_standard_text_two);
@@ -136,13 +126,16 @@ GeneralConfiguration::GeneralConfiguration(bool save_on_destroy)
   INITIALIZE(notes_display_created_by);
   INITIALIZE(notes_display_summary);
   INITIALIZE(notes_display_reference_text);
-  INITIALIZE(bibleworks_executable);
   INITIALIZE(reference_exchange_send_to_bibleworks);
   INITIALIZE(reference_exchange_receive_from_bibleworks);
   INITIALIZE(reference_exchange_send_to_bibletime);
   INITIALIZE(reference_exchange_receive_from_bibletime);
   INITIALIZE(reference_exchange_send_to_santafefocus);
   INITIALIZE(reference_exchange_receive_from_santafefocus);
+  INITIALIZE(reference_exchange_send_to_xiphos);
+  INITIALIZE(reference_exchange_receive_from_xiphos);
+  INITIALIZE(reference_exchange_send_to_onlinebible);
+  INITIALIZE(reference_exchange_receive_from_onlinebible);
   INITIALIZE(check_markers_compare_project);
   INITIALIZE(check_markers_compare_all_markers);
   INITIALIZE(check_markers_compare_include_only);
@@ -171,8 +164,8 @@ GeneralConfiguration::GeneralConfiguration(bool save_on_destroy)
   INITIALIZE(use_outpost);
   INITIALIZE(outpost_networked);
   INITIALIZE(outpost_host);
-  INITIALIZE(outpost_path);
   INITIALIZE(wine_path);
+  INITIALIZE(wine_bottle);
   INITIALIZE(outpost_command);
   INITIALIZE(mychecks);
   INITIALIZE(tidy_translate);
@@ -206,7 +199,6 @@ GeneralConfiguration::GeneralConfiguration(bool save_on_destroy)
   INITIALIZE(encoding);
   INITIALIZE(features_mode);
   INITIALIZE(features_list);
-  INITIALIZE(windows_detached);
   INITIALIZE(remember_verse_per_chapter);
   INITIALIZE(administration_password);
   INITIALIZE(print_references_projects);
@@ -224,14 +216,18 @@ GeneralConfiguration::GeneralConfiguration(bool save_on_destroy)
   INITIALIZE(git_health);
   INITIALIZE(projects_displaying_verses);
   INITIALIZE(compare_disregard_notes);
+  INITIALIZE(source_language_names);
 }
 
+
 GeneralConfiguration::~GeneralConfiguration()
 {
-  if (my_save_on_destroy)
+  if (my_save_on_destroy) {
     save();
+  }
 }
 
+
 void GeneralConfiguration::save()
 // Saves all settings to disk.
 {
@@ -247,28 +243,12 @@ void GeneralConfiguration::save()
   SAVE_VALUE (window_x_position);
   SAVE_VALUE (window_y_position);
   SAVE_VALUE (window_maximized);
-  SAVE_VALUE(menu_area_width);
-  SAVE_VALUE(menu_area_height);
-  SAVE_VALUE(menu_area_x_position);
-  SAVE_VALUE(menu_area_y_position);
-  SAVE_VALUE(text_area_width);
-  SAVE_VALUE(text_area_height);
-  SAVE_VALUE(text_area_x_position);
-  SAVE_VALUE(text_area_y_position);
-  SAVE_VALUE(notes_area_width);
-  SAVE_VALUE(notes_area_height);
-  SAVE_VALUE(notes_area_x_position);
-  SAVE_VALUE(notes_area_y_position);
-  SAVE_VALUE(tools_area_width);
-  SAVE_VALUE(tools_area_height);
-  SAVE_VALUE(tools_area_x_position);
-  SAVE_VALUE(tools_area_y_position);
   SAVE_VALUE(window_widths);
   SAVE_VALUE(window_heights);
   SAVE_VALUE(window_x_positions);
   SAVE_VALUE(window_y_positions);
   SAVE_VALUE(window_ids);
-  SAVE_VALUE(window_datas);
+  SAVE_VALUE(window_titles);
   SAVE_VALUE(window_shows);
   SAVE_VALUE(edit_note_standard_text_one);
   SAVE_VALUE(edit_note_standard_text_two);
@@ -307,13 +287,16 @@ void GeneralConfiguration::save()
   SAVE_VALUE(notes_display_created_by);
   SAVE_VALUE(notes_display_summary);
   SAVE_VALUE(notes_display_reference_text);
-  SAVE_VALUE(bibleworks_executable);
   SAVE_VALUE(reference_exchange_send_to_bibleworks);
   SAVE_VALUE(reference_exchange_receive_from_bibleworks);
   SAVE_VALUE(reference_exchange_send_to_bibletime);
   SAVE_VALUE(reference_exchange_receive_from_bibletime);
   SAVE_VALUE(reference_exchange_send_to_santafefocus);
   SAVE_VALUE(reference_exchange_receive_from_santafefocus);
+  SAVE_VALUE(reference_exchange_send_to_xiphos);
+  SAVE_VALUE(reference_exchange_receive_from_xiphos);
+  SAVE_VALUE(reference_exchange_send_to_onlinebible);
+  SAVE_VALUE(reference_exchange_receive_from_onlinebible);
   SAVE_VALUE(check_markers_compare_project);
   SAVE_VALUE(check_markers_compare_all_markers);
   SAVE_VALUE(check_markers_compare_include_only);
@@ -342,8 +325,8 @@ void GeneralConfiguration::save()
   SAVE_VALUE(use_outpost);
   SAVE_VALUE(outpost_networked);
   SAVE_VALUE(outpost_host);
-  SAVE_VALUE(outpost_path);
   SAVE_VALUE(wine_path);
+  SAVE_VALUE(wine_bottle);
   SAVE_VALUE(outpost_command);
   SAVE_VALUE(mychecks);
   SAVE_VALUE(tidy_translate);
@@ -377,7 +360,6 @@ void GeneralConfiguration::save()
   SAVE_VALUE(encoding);
   SAVE_VALUE(features_mode);
   SAVE_VALUE(features_list);
-  SAVE_VALUE(windows_detached);
   SAVE_VALUE(remember_verse_per_chapter); 
   SAVE_VALUE(administration_password);
   SAVE_VALUE(print_references_projects);
@@ -395,6 +377,7 @@ void GeneralConfiguration::save()
   SAVE_VALUE(git_health);
   SAVE_VALUE(projects_displaying_verses);
   SAVE_VALUE(compare_disregard_notes);
+  SAVE_VALUE(source_language_names);
 
   config_xml_values_set_execute(general_configuration_filename(), values);
 }
@@ -495,28 +478,12 @@ IMPLEMENT (int, int_get, window_height, 0)
 IMPLEMENT (int, int_get, window_x_position, 0)
 IMPLEMENT (int, int_get, window_y_position, 0)
 IMPLEMENT (bool, bool_get, window_maximized, true)
-IMPLEMENT(int, int_get, menu_area_width, 0)
-IMPLEMENT(int, int_get, menu_area_height, 0)
-IMPLEMENT(int, int_get, menu_area_x_position, 0)
-IMPLEMENT(int, int_get, menu_area_y_position, 0)
-IMPLEMENT(int, int_get, text_area_width, 0)
-IMPLEMENT(int, int_get, text_area_height, 0)
-IMPLEMENT(int, int_get, text_area_x_position, 0)
-IMPLEMENT(int, int_get, text_area_y_position, 0)
-IMPLEMENT(int, int_get, notes_area_width, 0)
-IMPLEMENT(int, int_get, notes_area_height, 0)
-IMPLEMENT(int, int_get, notes_area_x_position, 0)
-IMPLEMENT(int, int_get, notes_area_y_position, 0)
-IMPLEMENT(int, int_get, tools_area_width, 0)
-IMPLEMENT(int, int_get, tools_area_height, 0)
-IMPLEMENT(int, int_get, tools_area_x_position, 0)
-IMPLEMENT(int, int_get, tools_area_y_position, 0)
 IMPLEMENT(vector < int >, vector_int_get, window_widths, NULL)
 IMPLEMENT(vector < int >, vector_int_get, window_heights, NULL)
 IMPLEMENT(vector < int >, vector_int_get, window_x_positions, NULL)
 IMPLEMENT(vector < int >, vector_int_get, window_y_positions, NULL)
 IMPLEMENT(vector < int >, vector_int_get, window_ids, NULL)
-IMPLEMENT(vector < ustring >, vector_string_get, window_datas, NULL)
+IMPLEMENT(vector < ustring >, vector_string_get, window_titles, NULL)
 IMPLEMENT(vector < bool >, vector_bool_get, window_shows, NULL)
 IMPLEMENT(ustring, string_get, edit_note_standard_text_one, "Exegetical problem: ")
 IMPLEMENT(ustring, string_get, edit_note_standard_text_two, "Checking question: ")
@@ -555,13 +522,16 @@ IMPLEMENT(bool, bool_get, notes_display_date_created, false)
 IMPLEMENT(bool, bool_get, notes_display_created_by, false)
 IMPLEMENT(bool, bool_get, notes_display_summary, false)
 IMPLEMENT(bool, bool_get, notes_display_reference_text, false)
-IMPLEMENT(ustring, string_get, bibleworks_executable, "bw700.exe")
 IMPLEMENT(bool, bool_get, reference_exchange_send_to_bibleworks, false)
 IMPLEMENT(bool, bool_get, reference_exchange_receive_from_bibleworks, false)
-IMPLEMENT(bool, bool_get, reference_exchange_send_to_bibletime, false)
+IMPLEMENT(bool, bool_get, reference_exchange_send_to_bibletime, true)
 IMPLEMENT(bool, bool_get, reference_exchange_receive_from_bibletime, false)
 IMPLEMENT(bool, bool_get, reference_exchange_send_to_santafefocus, true)
 IMPLEMENT(bool, bool_get, reference_exchange_receive_from_santafefocus, false)
+IMPLEMENT(bool, bool_get, reference_exchange_send_to_xiphos, true)
+IMPLEMENT(bool, bool_get, reference_exchange_receive_from_xiphos, false)
+IMPLEMENT(bool, bool_get, reference_exchange_send_to_onlinebible, false)
+IMPLEMENT(bool, bool_get, reference_exchange_receive_from_onlinebible, false)
 IMPLEMENT(ustring, string_get, check_markers_compare_project, "")
 IMPLEMENT(bool, bool_get, check_markers_compare_all_markers, true)
 IMPLEMENT(ustring, string_get, check_markers_compare_include_only, "")
@@ -590,9 +560,9 @@ IMPLEMENT(vector < bool >, vector_bool_get, parallel_bible_enabled, NULL)
 IMPLEMENT(bool, bool_get, use_outpost, false)
 IMPLEMENT(bool, bool_get, outpost_networked, false)
 IMPLEMENT(ustring, string_get, outpost_host, "")
-IMPLEMENT(ustring, string_get, outpost_path, gw_build_filename(g_get_home_dir(), ".wine/drive_c/Program Files/Bibledit Windows Outpost/bwoutpost.exe"))
 IMPLEMENT(ustring, string_get, wine_path, "wine")
-IMPLEMENT(ustring, string_get, outpost_command, wine_path_get() + shell_quote_space(outpost_path_get()))
+IMPLEMENT(ustring, string_get, wine_bottle, "")
+IMPLEMENT(ustring, string_get, outpost_command, wine_path_get() + shell_quote_space(windowsoutpost_path ()))
 IMPLEMENT(ustring, string_get, mychecks, "")
 IMPLEMENT(bool, bool_get, tidy_translate, false)
 IMPLEMENT(vector < int >, vector_int_get, tidy_books, NULL)
@@ -625,7 +595,6 @@ IMPLEMENT(int, int_get, text_editor_selection_color, 4294343)
 IMPLEMENT(ustring, string_get, encoding, "WINDOWS-1258")
 IMPLEMENT(int, int_get, features_mode, 1)
 IMPLEMENT(ustring, string_get, features_list, "")
-IMPLEMENT(bool, bool_get, windows_detached, false)
 IMPLEMENT(bool, bool_get, remember_verse_per_chapter, false) 
 IMPLEMENT(ustring, string_get, administration_password, "")
 IMPLEMENT(vector < ustring >, vector_string_get, print_references_projects, NULL)
@@ -643,3 +612,4 @@ IMPLEMENT(int, int_get, print_job, 0)
 IMPLEMENT(int, int_get, git_health, date_time_julian_day_get_current())
 IMPLEMENT(vector < ustring >, vector_string_get, projects_displaying_verses, NULL)
 IMPLEMENT(bool, bool_get, compare_disregard_notes, false)
+IMPLEMENT(vector <ustring>, vector_string_get, source_language_names, NULL)
