@@ -17,7 +17,7 @@
  **  
  */
 
-
+ 
 #include "utilities.h"
 #include <glib.h>
 #include "gui_navigation.h"
@@ -30,6 +30,7 @@
 #include "gwrappers.h"
 #include "tiny_utilities.h"
 #include "referencememory.h"
+#include "dialogradiobutton.h"
 
 
 GuiNavigation::GuiNavigation(int dummy):
@@ -59,6 +60,19 @@ void GuiNavigation::build(GtkWidget * toolbar)
   gtk_container_add(GTK_CONTAINER(toolitem_delayed), new_reference_signal);
 
   // Gui proper.
+  GtkToolItem *toolitem_list_back = gtk_tool_item_new ();
+  gtk_widget_show (GTK_WIDGET(toolitem_list_back));
+  gtk_toolbar_insert(GTK_TOOLBAR(toolbar), GTK_TOOL_ITEM(toolitem_list_back), -1);
+
+  button_list_back = gtk_button_new ();
+  gtk_widget_show (button_list_back);
+  gtk_container_add (GTK_CONTAINER (toolitem_list_back), button_list_back);
+  GTK_WIDGET_UNSET_FLAGS (button_list_back, GTK_CAN_FOCUS);
+
+  image_list_back = gtk_image_new_from_stock ("gtk-go-down", GTK_ICON_SIZE_BUTTON);
+  gtk_widget_show (image_list_back);
+  gtk_container_add (GTK_CONTAINER (button_list_back), image_list_back);
+
   GtkToolItem *toolitem1 = gtk_tool_item_new();
   gtk_widget_show(GTK_WIDGET(toolitem1));
   gtk_toolbar_insert(GTK_TOOLBAR(toolbar), GTK_TOOL_ITEM(toolitem1), -1);
@@ -85,6 +99,19 @@ void GuiNavigation::build(GtkWidget * toolbar)
   gtk_widget_show(image2);
   gtk_container_add(GTK_CONTAINER(button_forward), image2);
 
+  GtkToolItem *toolitem_list_forward = gtk_tool_item_new ();
+  gtk_widget_show (GTK_WIDGET(toolitem_list_forward));
+  gtk_toolbar_insert(GTK_TOOLBAR(toolbar), GTK_TOOL_ITEM(toolitem_list_forward), -1);
+
+  button_list_forward = gtk_button_new ();
+  gtk_widget_show (button_list_forward);
+  gtk_container_add (GTK_CONTAINER (toolitem_list_forward), button_list_forward);
+  GTK_WIDGET_UNSET_FLAGS (button_list_forward, GTK_CAN_FOCUS);
+
+  image_list_forward = gtk_image_new_from_stock ("gtk-go-down", GTK_ICON_SIZE_BUTTON);
+  gtk_widget_show (image_list_forward);
+  gtk_container_add (GTK_CONTAINER (button_list_forward), image_list_forward);
+
   GtkToolItem *toolitem3 = gtk_tool_item_new();
   gtk_widget_show(GTK_WIDGET(toolitem3));
   gtk_toolbar_insert(GTK_TOOLBAR(toolbar), GTK_TOOL_ITEM(toolitem3), -1);
@@ -166,8 +193,10 @@ void GuiNavigation::build(GtkWidget * toolbar)
   gtk_widget_set_size_request(spinbutton_chapter, int (defaultheight * 0.7), -1);
   gtk_widget_set_size_request(spinbutton_verse, int (defaultheight * 0.7), -1);
 
+  g_signal_connect((gpointer) button_list_back, "clicked", G_CALLBACK(on_button_list_back_clicked), gpointer(this));
   g_signal_connect((gpointer) button_back, "clicked", G_CALLBACK(on_button_back_clicked), gpointer(this));
   g_signal_connect((gpointer) button_forward, "clicked", G_CALLBACK(on_button_forward_clicked), gpointer(this));
+  g_signal_connect((gpointer) button_list_forward, "clicked", G_CALLBACK(on_button_list_forward_clicked), gpointer(this));
   g_signal_connect((gpointer) combo_book, "changed", G_CALLBACK(on_combo_book_changed), gpointer(this));
   g_signal_connect((gpointer) spinbutton_book, "value_changed", G_CALLBACK(on_spinbutton_book_value_changed), gpointer(this));
   g_signal_connect((gpointer) combo_chapter, "changed", G_CALLBACK(on_combo_chapter_changed), gpointer(this));
@@ -223,7 +252,7 @@ void GuiNavigation::set_project(const ustring & value, bool force)
 }
 
 
-void GuiNavigation::clamp(Reference & reference)
+void GuiNavigation::clampref(Reference & reference)
 // This clamps the reference, that is, it brings it within the limits of 
 // the project.
 {
@@ -237,7 +266,7 @@ void GuiNavigation::clamp(Reference & reference)
     if (books.empty()) {
       reference.book = 0;
     } else {
-      reference.book = CLAMP(reference.book, books[0], books[books.size() - 1]);
+      reference.book = clamp(reference.book, books[0], books[books.size() - 1]);
     }
   }
   // Clamp the chapter.
@@ -340,7 +369,7 @@ void GuiNavigation::nextbook()
     else
       reference.verse = "0";
   }
-  clamp(reference);
+  clampref(reference);
   set_book(reference.book);
   load_chapters(reference.book);
   set_chapter(reference.chapter);
@@ -377,7 +406,7 @@ void GuiNavigation::previousbook()
     else
       reference.verse = "0";
   }
-  clamp(reference);
+  clampref(reference);
   set_book(reference.book);
   load_chapters(reference.book);
   set_chapter(reference.chapter);
@@ -411,7 +440,7 @@ void GuiNavigation::nextchapter()
     else
       reference.verse = "0";
   }
-  clamp(reference);
+  clampref(reference);
   load_verses(reference.book, reference.chapter);
   set_verse(reference.verse);
   set_chapter(reference.chapter);
@@ -443,7 +472,7 @@ void GuiNavigation::previouschapter()
     else
       reference.verse = "0";
   }
-  clamp(reference);
+  clampref(reference);
   load_verses(reference.book, reference.chapter);
   set_verse(reference.verse);
   set_chapter(reference.chapter);
@@ -495,6 +524,12 @@ void GuiNavigation::previousverse()
 }
 
 
+void GuiNavigation::on_button_list_back_clicked(GtkButton * button, gpointer user_data)
+{
+  ((GuiNavigation *) user_data)->on_list_back();
+}
+
+
 void GuiNavigation::on_button_back_clicked(GtkButton * button, gpointer user_data)
 {
   ((GuiNavigation *) user_data)->on_back();
@@ -507,6 +542,12 @@ void GuiNavigation::on_button_forward_clicked(GtkButton * button, gpointer user_
 }
 
 
+void GuiNavigation::on_button_list_forward_clicked(GtkButton * button, gpointer user_data)
+{
+  ((GuiNavigation *) user_data)->on_list_forward();
+}
+
+
 void GuiNavigation::on_combo_book_changed(GtkComboBox * combobox, gpointer user_data)
 {
   ((GuiNavigation *) user_data)->on_combo_book();
@@ -574,7 +615,7 @@ void GuiNavigation::on_combo_book()
     reference.chapter = 1;
     reference.verse = "1";
   }
-  clamp(reference);
+  clampref(reference);
   load_chapters(reference.book);
   set_chapter(reference.chapter);
   load_verses(reference.book, reference.chapter);
@@ -591,7 +632,7 @@ void GuiNavigation::on_combo_chapter()
   if (!references_memory_retrieve (reference, true)) {
     reference.verse = "1";
   }
-  clamp(reference);
+  clampref(reference);
   load_verses(reference.book, reference.chapter);
   set_verse(reference.verse);
   signal();
@@ -831,9 +872,9 @@ void GuiNavigation::crossboundariesverse(bool forward)
   }
   // Get the previous book, and the next book.
   int previousbookindex = bookindex - 1;
-  previousbookindex = CLAMP(previousbookindex, 0, bookindex);
+  previousbookindex = clamp(previousbookindex, 0, bookindex);
   unsigned int nextbookindex = bookindex + 1;
-  nextbookindex = CLAMP(nextbookindex, 0, allbooks.size() - 1);
+  nextbookindex = clamp(nextbookindex, 0, allbooks.size() - 1);
   // Get a list of all references in these on the most three books.
   vector < unsigned int >books;
   vector < unsigned int >chapters;
@@ -902,9 +943,9 @@ void GuiNavigation::crossboundarieschapter(bool forward)
   }
   // Get the previous book, and the next book.
   int previousbookindex = bookindex - 1;
-  previousbookindex = CLAMP(previousbookindex, 0, bookindex);
+  previousbookindex = clamp(previousbookindex, 0, bookindex);
   unsigned int nextbookindex = bookindex + 1;
-  nextbookindex = CLAMP(nextbookindex, 0, allbooks.size() - 1);
+  nextbookindex = clamp(nextbookindex, 0, allbooks.size() - 1);
   // Get a list of all references in these on the most three books.
   vector < unsigned int >books;
   vector < unsigned int >chapters;
@@ -964,8 +1005,43 @@ void GuiNavigation::crossboundarieschapter(bool forward)
 void GuiNavigation::tracker_sensitivity()
 {
   // Buttons.
+  gtk_widget_set_sensitive(button_list_back, track.previous_reference_available());
   gtk_widget_set_sensitive(button_back, track.previous_reference_available());
   gtk_widget_set_sensitive(button_forward, track.next_reference_available());
+  gtk_widget_set_sensitive(button_list_forward, track.next_reference_available());
 }
 
 
+void GuiNavigation::on_list_back ()
+{
+  vector <Reference> references;
+  track.get_previous_references (references);
+  vector <ustring> labels;
+  for (unsigned int i = 0; i < references.size(); i++) {
+    labels.push_back (references[i].human_readable (language));
+  }
+  RadiobuttonDialog dialog ("Go back", "Where would you like to go back to?", labels, 0, true);
+  if (dialog.run () == GTK_RESPONSE_OK) {
+    for (unsigned int i = 0; i <= dialog.selection; i++) {
+      on_back();
+    }
+  }
+}
+
+
+void GuiNavigation::on_list_forward ()
+{
+  vector <Reference> references;
+  track.get_next_references (references);
+  vector <ustring> labels;
+  for (unsigned int i = 0; i < references.size(); i++) {
+    labels.push_back (references[i].human_readable (language));
+  }
+  RadiobuttonDialog dialog ("Go forward", "Where would you like to go forward to?", labels, 0, true);
+  if (dialog.run () == GTK_RESPONSE_OK) {
+    for (unsigned int i = 0; i <= dialog.selection; i++) {
+      on_forward();
+    }
+  }
+}
+
