@@ -17,6 +17,7 @@
 **  
 */
 
+
 #include "libraries.h"
 #include <glib.h>
 #include "highlight.h"
@@ -28,7 +29,8 @@
 #include "settings.h"
 #include "date_time_utils.h"
 
-Highlight::Highlight(GtkTextBuffer * buffer, GtkWidget * textview, const ustring & project, const vector < EditorNote > &editornotes, const vector < EditorTable > &editortables, GtkTextTag * tag, const ustring & verse)
+
+Highlight::Highlight(GtkTextBuffer * buffer, GtkWidget * textview, const ustring & project, GtkTextTag * tag, const ustring & verse)
 {
   // Save and initialize variables.
   maintextbuffer = buffer;
@@ -39,21 +41,9 @@ Highlight::Highlight(GtkTextBuffer * buffer, GtkWidget * textview, const ustring
 
   // Remove any previous highlights.  
   remove_previous_highlights(maintextbuffer);
-  for (unsigned int i = 0; i < editornotes.size(); i++) {
-    remove_previous_highlights(editornotes[i].textbuffer);
-  }
-  for (unsigned int i = 0; i < editortables.size(); i++) {
-    for (unsigned int row = 0; row < editortables[i].textviews.size(); row++) {
-      for (unsigned int column = 0; column < editortables[i].textviews[row].size(); column++) {
-        remove_previous_highlights(table_cell_get_buffer(editortables[i], row, column));
-      }
-    }
-  }
 
   // Determine the boundaries between which to highlight,
   // in order to highlight only the words that are within the right verse.
-  // At the same time collect any GtkTextChildAnchors within range.
-  set < GtkTextChildAnchor * >childanchors;
   {
     GtkTextIter startiter;
     GtkTextIter enditer;
@@ -68,7 +58,7 @@ Highlight::Highlight(GtkTextBuffer * buffer, GtkWidget * textview, const ustring
       ustring paragraph_style, character_style;
       get_styles_at_iterator(iter, paragraph_style, character_style);
       if (start || (character_style == verse_style)) {
-        ustring verse_at_iter = get_verse_number_at_iterator(iter, verse_style, "");
+        ustring verse_at_iter = get_verse_number_at_iterator(iter, verse_style, "", NULL);
         if (verse == verse_at_iter) {
           if (!started) {
             started = true;
@@ -84,12 +74,6 @@ Highlight::Highlight(GtkTextBuffer * buffer, GtkWidget * textview, const ustring
         }
       }
       start = false;
-      if ((started) && (!ended)) {
-        GtkTextChildAnchor *anchor = gtk_text_iter_get_child_anchor(&iter);
-        if (anchor) {
-          childanchors.insert(anchor);
-        }
-      }
       gtk_text_iter_forward_char(&iter);
     }
     main_start_offset = gtk_text_iter_get_offset(&startiter);
@@ -98,24 +82,11 @@ Highlight::Highlight(GtkTextBuffer * buffer, GtkWidget * textview, const ustring
 
   // Go through all the embedded editors that are within the verse, 
   // and mark these for processing too.
-  for (unsigned int i = 0; i < editornotes.size(); i++) {
-    if (childanchors.find(editornotes[i].childanchor_caller_text) != childanchors.end()) {
-      searchbuffers.push_back(editornotes[i].textbuffer);
-      searchviews.push_back(GTK_TEXT_VIEW(editornotes[i].textview));
-    }
-  }
-  for (unsigned int i = 0; i < editortables.size(); i++) {
-    if (childanchors.find(editortables[i].childanchor) != childanchors.end()) {
-      for (unsigned int row = 0; row < editortables[i].textviews.size(); row++) {
-        for (unsigned int column = 0; column < editortables[i].textviews[row].size(); column++) {
-          searchbuffers.push_back(table_cell_get_buffer(editortables[i], row, column));
-          searchviews.push_back(GTK_TEXT_VIEW(table_cell_get_view(editortables[i], row, column)));
-        }
-      }
-    }
-  }
+  //searchbuffers.push_back(editornotes[i].textbuffer);
+  //searchviews.push_back(GTK_TEXT_VIEW(editornotes[i].textview));
 }
 
+
 Highlight::~Highlight()
 {
   // Set flag to interrupt the thread.
@@ -127,6 +98,7 @@ Highlight::~Highlight()
   // The object destroys itself.
 }
 
+
 void Highlight::searchwords(GtkTextBuffer * textbuffer, GtkTextView * textview, gint startoffset, gint endoffset)
 /*
 This looks for the positions between startoffset and endoffset of the words to 
@@ -166,6 +138,7 @@ be highlighted highlights based upon the word that was searched for.
   }
 }
 
+
 void Highlight::searchwords_find_slow(GtkTextBuffer * textbuffer, GtkTextIter * beginbound, GtkTextIter * endbound, const ustring & searchword, bool casesensitive, bool globbing, bool matchbegin, bool matchend, vector < GtkTextIter > &wordstart, vector < GtkTextIter > &wordend)
 /*
 Searches for words to highlight.
@@ -268,6 +241,7 @@ to highlight, not from the casefolded searchword, but the original one.
   }
 }
 
+
 void Highlight::searchwords_find_fast(GtkTextBuffer * textbuffer, GtkTextIter * beginbound, GtkTextIter * endbound, const ustring & searchword, bool casesensitive, vector < GtkTextIter > &wordstart, vector < GtkTextIter > &wordend)
 // Searches for words to highlight. For simple highligthing. 
 // Is much faster than the slow routine, see there fore more information.
@@ -303,6 +277,7 @@ void Highlight::searchwords_find_fast(GtkTextBuffer * textbuffer, GtkTextIter *
   }
 }
 
+
 void Highlight::searchwords_in_area(GtkTextBuffer * textbuffer, vector < GtkTextIter > &start, vector < GtkTextIter > &end, bool area_id, bool area_intro, bool area_heading, bool area_chapter, bool area_study, bool area_notes, bool area_xref, bool area_verse)
 /*
 Finds out whether the text within the "start" and "end" iterators is inside
@@ -360,6 +335,7 @@ one of the given areas. If not, it removes the iterator from the containers.
   }
 }
 
+
 void Highlight::remove_previous_highlights(GtkTextBuffer * textbuffer)
 // Removes previous highlights.
 // Ensure that removing the tags does not influence the modified status of the textbuffer.
@@ -374,6 +350,7 @@ void Highlight::remove_previous_highlights(GtkTextBuffer * textbuffer)
     gtk_text_buffer_set_modified(textbuffer, false);
 }
 
+
 void Highlight::determine_locations()
 // Determine the locations where to highlight text.
 {
@@ -394,6 +371,7 @@ void Highlight::determine_locations()
   locations_ready = true;
 }
 
+
 void Highlight::highlight()
 // This does the actual highlighting.
 // Ensure that applying a tag does not change the modified status of the textbuffer.
