@@ -645,11 +645,6 @@ void keyterms_import_ktbh_txt_references(ustring line, vector <Reference> &refer
 }
 
 
-void keyterms_import_ktbh_standard_disclaimer (vector <ustring>& comments)
-{
-  comments.push_back ("Disclaimer: Key Terms in Biblical Hebrew: The entries are an experimental sample set, not yet fully reviewed and approved. The KTBH team would welcome feed-back to christopher_samuel@sil.org.");
-}
-
 void keyterms_import_ktbh_txt(const ustring& textfile, ustring category)
 {
   // Ensure the db is there.
@@ -717,7 +712,6 @@ void keyterms_import_ktbh_txt(const ustring& textfile, ustring category)
 
         // Hebrew keyterm: store.
         if (line.find("\\heb ") == 0) {
-          keyterms_import_ktbh_standard_disclaimer (comments);
           keyterms_import_textfile_flush(db, category_id, keyterm, comments, references);
           keyterm = "(" + line.substr(5, 1000) + ")";
         }
@@ -762,7 +756,6 @@ void keyterms_import_ktbh_txt(const ustring& textfile, ustring category)
 
     }
     // Flush remaining data.
-    keyterms_import_ktbh_standard_disclaimer (comments);
     keyterms_import_textfile_flush(db, category_id, keyterm, comments, references);
 
   }
@@ -1104,7 +1097,6 @@ void keyterms_export(const ustring & directory, bool gui)
   // Go through the categories.  
   vector < ustring > categories = keyterms_get_categories();
   for (unsigned int cat = 0; cat < categories.size(); cat++) {
-    cout << categories[cat] << endl;
     // Output data.
     ustring paratext_filename = gw_build_filename(directory, categories[cat] + ".lex");
     replace_text(paratext_filename, " ", "_");
@@ -1154,14 +1146,14 @@ void keyterms_export(const ustring & directory, bool gui)
 }
 
 
-vector < int >keyterms_get_terms_in_verse(const Reference & reference)
+vector <int> keyterms_get_terms_in_verse(const Reference & reference)
 {
   vector < int >terms;
   sqlite3 *db;
   sqlite3_open(keyterms_get_filename().c_str(), &db);
   sqlite3_busy_timeout(db, 1000);
   SqliteReader reader(0);
-  char *sql = g_strdup_printf("select keyword from refs where book = %d and chapter = %d and verse = '%s';", reference.book, reference.chapter, reference.verse.c_str());
+  char *sql = g_strdup_printf("select id from reference where book = %d and chapter = %d and verse = '%s';", reference.book, reference.chapter, reference.verse.c_str());
   sqlite3_exec(db, sql, reader.callback, &reader, NULL);
   g_free(sql);
   for (unsigned int i = 0; i < reader.ustring0.size(); i++) {
