@@ -25,18 +25,15 @@
 #include <gtk/gtk.h>
 #include "windowsoutpost.h"
 #include "ustring.h"
-#include "bibletime.h"
 #include "usfm.h"
 #include "note_editor.h"
-#include "editor.h"
+#include "editor2.h"
 #include "httpd.h"
 #include "reference.h"
 #include "gui_navigation.h"
 #include "displayprojectnotes.h"
 #include "git.h"
-#include "windowlayout.h"
-#include "windowshowkeyterms.h"
-#include "windowshowquickrefs.h"
+#include "windowshowrelatedverses.h"
 #include "windowmerge.h"
 #include "windowresource.h"
 #include "windowoutline.h"
@@ -45,7 +42,6 @@
 #include "windownotes.h"
 #include "windowreferences.h"
 #include "windoweditor.h"
-#include "windowshowverses.h"
 #include "assistantimportkeyterms.h"
 #include "assistantdeletekeyterms.h"
 #include "assistantchanges.h"
@@ -55,9 +51,11 @@
 #include "assistantbackup.h"
 #include "assistantrestore.h"
 #include "assistantexport.h"
+#include "assistantimport.h"
+#include "floatingwindow.h"
 
 
-class MainWindow : public WindowBase
+class MainWindow
 {
 public:
   MainWindow(unsigned long xembed, GtkAccelGroup *accelerator_group);
@@ -66,7 +64,7 @@ public:
 protected:
   /* IMPORTANT If more menu items are added see whether they should be made 
    * in(sensitive) depending on the context whether something has been opened. */
-  GtkWidget *hbox_main;
+  GtkWidget *window_main;
   GtkWidget *vbox_main;
   GtkWidget *menubar1;
   GtkWidget *menuitem_file;
@@ -80,8 +78,6 @@ protected:
   GtkWidget *delete1;
   GtkWidget *properties1;
   GtkWidget *image4995;
-  GtkWidget *import1;
-  GtkWidget *image464;
   GtkWidget *copy_project_to;
   GtkWidget *image2688;
   GtkWidget *compare_with1;
@@ -91,17 +87,6 @@ protected:
   GtkWidget *file_projects_merge;
   GtkWidget *projects_send_receive1;
   GtkWidget *image34440;
-  GtkWidget *file_references;
-  GtkWidget *image465;
-  GtkWidget *file_references_menu;
-  GtkWidget *open_references1;
-  GtkWidget *image466;
-  GtkWidget *close_references;
-  GtkWidget *image468;
-  GtkWidget *delete_references;
-  GtkWidget *image469;
-  GtkWidget *reference_hide;
-  GtkWidget *image6483;
   GtkWidget *style;
   GtkWidget *image10735;
   GtkWidget *style_menu;
@@ -120,15 +105,12 @@ protected:
   GtkWidget *stylesheets_new;
   GtkWidget *stylesheets_delete;
   GtkWidget *stylesheets_rename;
-  GtkWidget *stylesheets_import;
   GtkWidget *notes2;
   GtkWidget *image936;
   GtkWidget *notes2_menu;
   GtkWidget *new_note;
   GtkWidget *delete_note;
   GtkWidget *image963;
-  GtkWidget *import_notes;
-  GtkWidget *image1455;
   GtkWidget *file_resources;
   GtkWidget *image27365;
   GtkWidget *file_resources_menu;
@@ -145,10 +127,10 @@ protected:
   GtkWidget *file_keyterms;
   GtkWidget *image32231;
   GtkWidget *file_keyterms_menu;
-  GtkWidget *keyterms_import;
-  GtkWidget *image32232;
   GtkWidget *keyterms_delete;
   GtkWidget *print;
+  GtkWidget *file_import;
+  GtkWidget *image36797;
   GtkWidget *file_export;
   GtkWidget *image35236;
   GtkWidget *file_backup;
@@ -194,15 +176,12 @@ protected:
   GtkWidget *image20235;
   GtkWidget *viewnotes;
   GtkWidget *image2627;
-  GtkWidget *parallel_passages1;
   GtkWidget *view_usfm_code;
   GtkWidget *view_planning;
   GtkWidget *image26812;
-  GtkWidget *view_screen_layout;
-  GtkWidget *view_keyterms;
-  GtkWidget *view_quick_references;
+  GtkWidget *view_references;
+  GtkWidget *view_related_verses;
   GtkWidget *view_outline;
-  GtkWidget *view_verses;
   GtkWidget *insert1;
   GtkWidget *insert1_menu;
   GtkWidget *standard_text_1;
@@ -290,8 +269,6 @@ protected:
   GtkWidget *image35887;
   GtkWidget *menutools;
   GtkWidget *menutools_menu;
-  GtkWidget *line_cutter_for_hebrew_text1;
-  GtkWidget *image13532;
   GtkWidget *notes_transfer;
   GtkWidget *image14659;
   GtkWidget *tool_origin_references_in_bible_notes;
@@ -306,6 +283,11 @@ protected:
   GtkWidget *image29089;
   GtkWidget *tool_go_to_reference;
   GtkWidget *image36137;
+  GtkWidget *tools_maintenance;
+  GtkWidget *image36259;
+  GtkWidget *tool_send_reference;
+  GtkWidget *image37446;
+  GtkWidget *tools_receive_reference;
   GtkWidget *menuitem_preferences;
   GtkWidget *menuitem_preferences_menu;
   GtkWidget *notes_preferences;
@@ -314,8 +296,6 @@ protected:
   GtkWidget *image3493;
   GtkWidget *reference_exchange1;
   GtkWidget *image5972;
-  GtkWidget *ignored_references1;
-  GtkWidget *image6467;
   GtkWidget *prefs_books;
   GtkWidget *image12167;
   GtkWidget *preferences_windows_outpost;
@@ -346,13 +326,8 @@ protected:
   GtkWidget *image4388;
   GtkWidget *about1;
   GtkWidget *toolbar;
-  GtkWidget *hbox_editors;
-  GtkWidget *hbox_notes;
-  GtkWidget *hbox_status; 
-  GtkWidget *hbox7;
-  GtkWidget *statuslabel_style;
-  GtkWidget *statusbar;
-  GtkWidget *vbox_tools;
+  GtkWidget *scrolledwindow_layout;
+  GtkWidget *layout;
 
   // Navigator object.
   GuiNavigation navigation;
@@ -361,8 +336,6 @@ protected:
   void enable_or_disable_widgets(bool enable);
 
   /* Menu window */
-  static void on_window_menu_delete_button_clicked(GtkButton *button, gpointer user_data);
-  void on_window_menu_delete_button();
   static void on_open1_activate(GtkMenuItem * menuitem, gpointer user_data);
   void open();
   static void on_new1_activate(GtkMenuItem * menuitem, gpointer user_data);
@@ -379,17 +352,15 @@ protected:
   static void on_about1_activate(GtkMenuItem * menuitem, gpointer user_data);
   void showabout();
   static void on_undo1_activate(GtkMenuItem * menuitem, gpointer user_data);
-  void menu_accelerator_undo(bool called_by_menu);
+  void menu_accelerator_undo();
   static void on_redo1_activate(GtkMenuItem * menuitem, gpointer user_data);
-  void menu_accelerator_redo(bool called_by_menu);
+  void menu_accelerator_redo();
   static void on_edit1_activate(GtkMenuItem * menuitem, gpointer user_data);
   void menu_edit();
   static void on_find_and_replace1_activate(GtkMenuItem * menuitem, gpointer user_data);
   void menu_replace();
   static void on_findspecial1_activate(GtkMenuItem * menuitem, gpointer user_data);
   void menu_findspecial();
-  static void on_import1_activate(GtkMenuItem * menuitem, gpointer user_data);
-  void menu_import();
   static void on_insert1_activate(GtkMenuItem *menuitem, gpointer user_data);
   void on_menu_insert();
   static void on_notes_preferences_activate(GtkMenuItem *menuitem, gpointer user_data);
@@ -414,8 +385,6 @@ protected:
   void on_tool_simple_text_corrections();
   static void on_preferences_text_replacement_activate(GtkMenuItem *menuitem, gpointer user_data);
   void on_preferences_text_replacement();
-  static void on_parallel_passages1_activate(GtkMenuItem *menuitem, gpointer user_data);
-  void on_parallel_passages1();
   static void on_pdf_viewer1_activate(GtkMenuItem *menuitem, gpointer user_data);
   void on_pdf_viewer();
   static void on_insert_special_character_activate(GtkMenuItem *menuitem, gpointer user_data);
@@ -442,51 +411,49 @@ protected:
 
   /* Clipboard */
   static void on_cut1_activate(GtkMenuItem * menuitem, gpointer user_data);
-  void on_cut(bool called_by_menu);
+  void on_cut();
   static void on_copy1_activate(GtkMenuItem * menuitem, gpointer user_data);
-  void on_copy(bool called_by_menu);
+  void on_copy();
   static void on_copy_with_formatting_activate(GtkMenuItem *menuitem, gpointer user_data);
-  void on_copy_with_formatting(bool called_by_menu);
+  void on_copy_with_formatting();
   static void on_paste1_activate(GtkMenuItem * menuitem, gpointer user_data);
-  void on_paste(bool called_by_menu);
+  void on_paste();
 
   /* References */
+  bool references_management_enabled;
+  static void on_view_references_activate (GtkMenuItem *menuitem, gpointer user_data);
+  void on_view_references ();
   void show_references_window();
   WindowReferences * window_references;
   static void on_window_references_delete_button_clicked(GtkButton *button, gpointer user_data);
   void on_window_references_delete_button();
-  static void on_window_references_general_signal_button_clicked(GtkButton *button, gpointer user_data);
-  void on_window_references_general_signal_button();
-  void on_list_goto();
-  static void on_open_references1_activate(GtkMenuItem * menuitem, gpointer user_data);
-  void on_open_references();
-  static void on_close_references_activate(GtkMenuItem * menuitem, gpointer user_data);
-  void on_clear_references();
-  static void on_delete_references_activate(GtkMenuItem * menuitem, gpointer user_data);
-  void on_delete_references();
+  static void on_window_references_signal_button_clicked(GtkButton *button, gpointer user_data);
+  void on_window_references_signal_button();
   void on_next_reference();
   void on_previous_reference();
-  static void on_ignored_references1_activate(GtkMenuItem *menuitem, gpointer user_data);
-  void on_ignored_references();
-  static void on_reference_hide_activate(GtkMenuItem *menuitem, gpointer user_data);
-  void on_reference_hide();
-  void treeview_references_display_quick_reference();
+  static void on_show_quick_references_signal_button_clicked(GtkButton * button, gpointer user_data);
+  void on_show_quick_references_signal_button(GtkButton * button);
 
   // Bibledit Windows Outpost
   // BibleTime
-  static bool mainwindow_on_external_programs_timeout(gpointer data);
-  bool on_external_programs_timeout();
   WindowsOutpost * windowsoutpost;
   static void on_reference_exchange1_activate(GtkMenuItem *menuitem, gpointer user_data);
   void on_reference_exchange();
-  BibleTime bibletime;
-  int got_new_bt_reference;
-  ustring bibledit_bt_previous_reference;
-  ustring bibletime_previous_reference;
   static void on_send_word_to_toolbox_signalled(GtkButton *button, gpointer user_data);
   void send_word_to_toolbox();
   static void on_preferences_windows_outpost_activate(GtkMenuItem *menuitem, gpointer user_data);
   void on_preferences_windows_outpost();
+  static void on_tool_send_reference_activate (GtkMenuItem *menuitem, gpointer user_data);
+  void on_tool_send_reference ();
+  void send_reference_to_bibleworks (Reference reference);
+  void send_reference_to_santa_fe (Reference reference);
+  void send_reference_to_onlinebible (Reference reference);
+  static void on_tools_receive_reference_activate (GtkMenuItem *menuitem, gpointer user_data);
+  void on_tools_receive_reference ();
+  guint event_id_receive_reference;
+  static bool on_tools_receive_reference_timeout(gpointer data);
+  void tools_receive_reference_timeout();
+  Reference * previously_received_reference;
 
   /* Title bar and status bar, GUI */
   static bool on_gui_timeout(gpointer data);
@@ -494,6 +461,7 @@ protected:
 
   /* Project notes */
   bool project_notes_enabled;
+  bool project_notes_management_enabled;
   void view_project_notes();
   WindowNotes * window_notes;
   static void on_window_notes_delete_button_clicked(GtkButton *button, gpointer user_data);
@@ -506,7 +474,6 @@ protected:
   void notes_redisplay();
   static void on_find_in_notes1_activate(GtkMenuItem *menuitem, gpointer user_data);
   void find_in_notes();
-  static void on_import_notes_activate(GtkMenuItem *menuitem, gpointer user_data);
   void on_import_notes();
   static void on_standard_text_1_activate(GtkMenuItem *menuitem, gpointer user_data);
   static void on_standard_text_2_activate(GtkMenuItem *menuitem, gpointer user_data);
@@ -518,7 +485,6 @@ protected:
   void on_menuitem_view();
   static void on_get_references_from_note_activate(GtkMenuItem *menuitem, gpointer user_data);
   void on_get_references_from_note();
-  void notes_get_references_from_id(gint id);
   static void on_window_notes_references_available_button_clicked(GtkButton *button, gpointer user_data);
   void on_window_notes_references_available_button();
 
@@ -595,6 +561,7 @@ protected:
   void editor_style_changed();
   static void on_style_edited(GtkButton *button, gpointer user_data);
   void reload_styles();
+  bool style_management_enabled;
 
   /* Footnotes, endnotes, crossreferences */
   static void on_edit_bible_note_activate(GtkMenuItem *menuitem, gpointer user_data);
@@ -602,8 +569,6 @@ protected:
 
   /* Tools */
   static void on_menutools_activate(GtkMenuItem *menuitem, gpointer user_data);
-  static void on_line_cutter_for_hebrew_text1_activate(GtkMenuItem *menuitem, gpointer user_data);
-  void on_line_cutter_for_hebrew_text();
   static void on_notes_transfer_activate(GtkMenuItem *menuitem, gpointer user_data);
   void on_notes_transfer();
   static void on_tool_origin_references_in_bible_notes_activate(GtkMenuItem *menuitem, gpointer user_data);
@@ -612,6 +577,8 @@ protected:
   void on_tool_project_notes_mass_update();
   static void on_tool_transfer_project_notes_to_text_activate(GtkMenuItem *menuitem, gpointer user_data);
   void on_tool_transfer_project_notes_to_text();
+  static void on_tools_maintenance_activate (GtkMenuItem *menuitem, gpointer user_data);
+  void on_tools_maintenance ();
 
   /* Webserver */
   Httpd httpd;
@@ -622,14 +589,15 @@ protected:
   WindowCheckKeyterms * window_check_keyterms;
   static void on_window_check_keyterms_delete_button_clicked(GtkButton *button, gpointer user_data);
   void on_window_check_keyterms_delete_button();
-  static void on_keyterms_new_reference(GtkButton *button, gpointer user_data);
-  void keyterms_check_move_new_reference();
-  static void on_view_keyterms_activate(GtkMenuItem *menuitem, gpointer user_data);
-  void on_view_keyterms();
-  WindowShowKeyterms * window_show_keyterms;
-  static void on_window_show_keyterms_delete_button_clicked(GtkButton *button, gpointer user_data);
-  void on_window_show_keyterms_delete_button();
-  static void on_keyterms_import_activate (GtkMenuItem *menuitem, gpointer user_data);
+  static void on_keyterms_signal_button_clicked(GtkButton *button, gpointer user_data);
+  void keyterms_check_action();
+  static void on_view_related_verses_activate(GtkMenuItem *menuitem, gpointer user_data);
+  void on_view_related_verses();
+  WindowShowRelatedVerses * window_show_related_verses;
+  static void on_window_show_related_verses_delete_button_clicked(GtkButton *button, gpointer user_data);
+  void on_window_show_related_verses_delete_button();
+  static void on_window_show_related_verses_item_button_clicked(GtkButton *button, gpointer user_data);
+  void on_window_show_related_verses_item_button();
   void on_keyterms_import ();
   ImportKeytermsAssistant * import_keyterms_assistant;
   static void on_keyterms_delete_activate (GtkMenuItem *menuitem, gpointer user_data);
@@ -742,40 +710,6 @@ protected:
   static void on_print_activate(GtkMenuItem *menuitem, gpointer user_data);
   void on_print();
 
-  /* Windowing system */
-  static void on_view_screen_layout_activate(GtkMenuItem *menuitem, gpointer user_data);
-  void on_view_screen_layout();
-  WindowLayout * window_screen_layout;
-  static void on_window_screen_layout_button_clicked(GtkButton *button, gpointer user_data);
-  void on_window_screen_layout_button();
-  static bool on_windows_startup_timeout(gpointer data);
-  bool on_windows_startup();
-  unsigned int windows_startup_pointer;
-  ustring focused_project_last_session;
-  void shutdown_windows();
-  static void on_window_focus_button_clicked(GtkButton *button, gpointer user_data);
-  void on_window_focus_button(GtkButton *button);
-  void present_windows(GtkWidget * widget);
-  GtkWidget * now_focused_window_button;
-  GtkWidget * last_focused_window_button;
-  GtkWidget * focused_editor_button;
-  GtkWidget * focused_resource_button;
-  GtkWidget * focused_tool_button;
-  bool windows_are_detached;
-  static void on_window_set_focus (GtkWindow *window, GtkWidget *widget, gpointer user_data);
-  void window_set_focus (GtkWidget *widget);
-  void resize_text_area_if_tools_area_is_empty();
-  void store_last_focused_tool_button (GtkButton * button);
-
-  /* Quick references */
-  static void on_view_quick_references_activate(GtkMenuItem *menuitem, gpointer user_data);
-  void on_view_quick_references();
-  WindowShowQuickReferences * window_show_quick_references;
-  static void on_window_show_quick_references_delete_button_clicked(GtkButton *button, gpointer user_data);
-  void on_window_show_quick_references_delete_button();
-  static void on_show_quick_references_signal_button_clicked(GtkButton *button, gpointer user_data);
-  void on_show_quick_references_signal_button(GtkButton *button);
-
   // Accelerators.
   static void accelerator_undo_callback(gpointer user_data);
   static void accelerator_redo_callback(gpointer user_data);
@@ -815,27 +749,21 @@ protected:
   static void accelerator_find_callback(gpointer user_data);
   static void accelerator_replace_callback(gpointer user_data);
   static void accelerator_main_help_callback(gpointer user_data);
-  static void accelerator_menu_callback(gpointer user_data);
   static void accelerator_view_usfm_code(gpointer user_data);
   void accelerator_view_usfm_code_toggle();
-  void accelerator_menu();
+  static void accelerator_left_square_bracket(gpointer user_data);
+  void left_square_bracket ();
+  static void accelerator_right_square_bracket(gpointer user_data);  
+  void right_square_bracket ();
   
   // Shutdown.
   bool shutting_down;
+  static bool on_window_delete_event(GtkWidget *widget, GdkEvent *event, gpointer user_data);
   void initiate_shutdown();
   
-  // Verses
-  static void on_view_verses_activate (GtkMenuItem *menuitem, gpointer user_data);
-  void on_view_verses ();
-  WindowShowVerses * window_show_verses;
-  static void on_window_show_verses_delete_button_clicked(GtkButton *button, gpointer user_data);
-  void on_window_show_verses_delete_button();
-  void show_verses();
-  
   // Assistants.
   static void on_assistant_ready_signal (GtkButton *button, gpointer user_data);
-  void on_assistant_keyterms_ready ();
-  References * assistant_references;
+  void on_assistant_ready ();
 
   // Check USFM
   static void on_check_usfm_activate (GtkMenuItem *menuitem, gpointer user_data);
@@ -844,6 +772,27 @@ protected:
   static void on_window_check_usfm_delete_button_clicked(GtkButton *button, gpointer user_data);
   void on_window_check_usfm_delete_button();
   void check_usfm_window_ping();
+
+  /* Import */
+  static void on_file_import_activate (GtkMenuItem *menuitem, gpointer user_data);
+  void on_file_import ();
+  ImportAssistant * import_assistant;
+  
+  /* Floating windows */
+  static void on_scrolledwindow_layout_size_allocate (GtkWidget *widget, GdkRectangle *allocation, gpointer user_data);
+  void scrolledwindow_layout_size_allocate (GdkRectangle *allocation);
+  ustring focused_project_last_session;
+  static bool on_windows_startup_timeout(gpointer data);
+  bool on_windows_startup();
+  unsigned int windows_startup_pointer;
+  static void on_window_focus_button_clicked(GtkButton *button, gpointer user_data);
+  void on_window_focus_button(GtkButton *button);
+  GtkWidget * focused_editor_button;
+  GtkWidget * focused_resource_button;
+  GtkWidget * focused_tool_button;
+  void store_last_focused_tool_button (GtkButton * button);
+  void shutdown_windows();
 };
 
+
 #endif
