@@ -36,7 +36,7 @@ gint notes_database_get_unique_id();
 void notes_delete_one(int id);
 void notes_sort(vector<unsigned int>& ids, const vector<ustring>& refs, const vector<ustring>& allrefs, const vector<int>& dates);
 void notes_select(vector<unsigned int>& ids, unsigned int& id_cursor, const ustring& currentreference);
-void notes_display(ustring& note_buffer, vector <unsigned int> ids, unsigned int cursor_id, unsigned int& cursor_offset, bool& stop);
+void notes_display(ustring& note_buffer, vector <unsigned int> ids, unsigned int cursor_id, unsigned int& cursor_offset, bool& stop, unsigned int edited_note_id);
 void notes_get_references_from_editor(GtkTextBuffer *textbuffer, vector<Reference>& references, vector<ustring>& messages);
 ustring notes_categories_filename();
 void notes_categories_check();
