@@ -17,6 +17,7 @@
  **  
  */
 
+
 #include "opendocument.h"
 #include "usfm.h"
 #include "bible.h"
@@ -49,20 +50,19 @@
  because frames would be needed, and this makes copying text more difficult.
  */
 
-OpenDocument::OpenDocument(const ustring & project, const ustring & filename, bool gui, set < unsigned int >*selection)
+
+OpenDocument::OpenDocument(const ustring & project, const ustring & filename, set < unsigned int >*selection)
 // Export a project to OpenDocument format. Allows books selection.
 {
   projectconfig = new ProjectConfiguration(project, false);
   usfm = new Usfm(stylesheet_get_actual ());
 
   // Check on basic markers.
-  if (!usfm_basic_markers_present(*usfm, gui))
+  if (!usfm_basic_markers_present(*usfm, true))
     return;
 
   // Progress information.  
-  progresswindow = NULL;
-  if (gui)
-    progresswindow = new ProgressWindow("Exporting to OpenDocument", true);
+  progresswindow = new ProgressWindow("Exporting to OpenDocument", true);
 
   // Prepare for inline text markers, notes and xrefs.
   usfm_inline_markers = new UsfmInlineMarkers(*usfm);
@@ -101,13 +101,9 @@ OpenDocument::OpenDocument(const ustring & project, const ustring & filename, bo
   for (unsigned int i = 0; i < books.size(); i++) {
 
     // Progress.
-    if (progresswindow) {
-      progresswindow->iterate();
-      if (progresswindow->cancel) {
-        return;
-      }
-    } else {
-      gw_message(books_id_to_english(books[i]));
+    progresswindow->iterate();
+    if (progresswindow->cancel) {      
+      return;
     }
 
     // Skip "Other Material".
@@ -121,7 +117,7 @@ OpenDocument::OpenDocument(const ustring & project, const ustring & filename, bo
     anchor_book = books[i];
 
     // Open the book. Do any replacements.
-    vector < ustring > book_lines;
+    vector <ustring> book_lines;
     book_lines = project_retrieve_book(project, books[i]);
     text_replacement(book_lines);
 
@@ -144,10 +140,10 @@ OpenDocument::OpenDocument(const ustring & project, const ustring & filename, bo
   zip(filename_odt);
 }
 
+
 OpenDocument::~OpenDocument()
 {
-  if (progresswindow)
-    delete progresswindow;
+  delete progresswindow;
   delete projectconfig;
   delete usfm;
   delete usfm_inline_markers;
@@ -156,6 +152,7 @@ OpenDocument::~OpenDocument()
   delete odtxref;
 }
 
+
 void OpenDocument::unpack_template()
 {
   // Clear working directory.
@@ -175,14 +172,13 @@ void OpenDocument::unpack_template()
   command.append(gw_build_filename(directories_get_package_data(), "template.odt"));
   command.append(" .; unzip *; rm *.odt");
 #endif
-  if (system(command.c_str())) ;
+  if (system(command.c_str())) ; // This one does not work with GwSpawn because of the wildcards used.
 }
 
+
 void OpenDocument::cover()
 // Generate cover page.
 {
-  extern Settings *settings;
-
   // Store the lines containing the cover.  
   vector < ustring > lines;
 
@@ -190,7 +186,7 @@ void OpenDocument::cover()
   for (unsigned int i = 0; i < books.size(); i++) {
     if (books_id_to_type(books[i]) == btOtherMaterial)
       continue;
-    vector < ustring > rawlines = project_retrieve_chapter(settings->genconfig.project_get(), books[i], 0);
+    vector < ustring > rawlines = project_retrieve_chapter(myproject, books[i], 0);
     bool within_cover_section = false;
     for (unsigned int i2 = 0; i2 < rawlines.size(); i2++) {
       ustring line = rawlines[i2];
@@ -212,7 +208,8 @@ void OpenDocument::cover()
   format_general(lines);
 }
 
-void OpenDocument::format_general(vector < ustring > &lines)
+
+void OpenDocument::format_general(vector <ustring>& lines)
 // General formatter for USFM lines given.
 {
   // Go through all the lines.
@@ -303,6 +300,8 @@ void OpenDocument::format_general(vector < ustring > &lines)
       if (!odttextparagraph)
         odttextparagraph = new OdtTextParagraph(&odtlines, "");
       odttextparagraph->plaintext(line);
+      // Make a note of this marker, that it was not formatted.
+      unformatted_markers.insert (marker);
     }
   }
   // Close possible last paragraph.
@@ -310,6 +309,7 @@ void OpenDocument::format_general(vector < ustring > &lines)
     delete odttextparagraph;
 }
 
+
 void OpenDocument::generate_styles(xmlTextWriterPtr writer)
 {
   // Go through all the styles and generate the appropriate code.
@@ -410,6 +410,7 @@ void OpenDocument::generate_styles(xmlTextWriterPtr writer)
   }
 }
 
+
 void OpenDocument::zip(const ustring filename)
 {
   ustring command = "cd ";
@@ -428,9 +429,10 @@ void OpenDocument::zip(const ustring filename)
 #endif
   command.append(shell_quote_space(filename));
   command.append(" *");
-  if (system(command.c_str())) ;
+  if (system(command.c_str())) ; // This one does not work with GwSpawn because of the wildcards used.
 }
 
+
 void OpenDocument::generate_styles_xml(bool right_to_left)
 // This generates the file "styles.xml" in the OpenDocument.
 {
@@ -517,6 +519,7 @@ void OpenDocument::generate_styles_xml(bool right_to_left)
     xmlBufferFree(buffer);
 }
 
+
 void OpenDocument::paragraph_style(xmlTextWriterPtr writer, const ustring & marker, const ustring & name, const ustring & fontname, double fontsize, int lineheight, const ustring & italic, const ustring & bold, const ustring & underline, const ustring & smallcaps, ustring justification, double spacebefore, double spaceafter, double leftmargin, double rightmargin, double firstlineindent, bool spancolumns, bool startpage)
 {
   // Style properties.
@@ -602,6 +605,7 @@ void OpenDocument::paragraph_style(xmlTextWriterPtr writer, const ustring & mark
   xmlTextWriterEndElement(writer);
 }
 
+
 void OpenDocument::span_style(xmlTextWriterPtr writer, const ustring & marker, const ustring & name, const ustring & fontname, double fontpercentage, ustring italic, ustring bold, ustring underline, ustring smallcaps, bool superscript, unsigned int color)
 {
   // Open the style.
@@ -668,3 +672,18 @@ void OpenDocument::span_style(xmlTextWriterPtr writer, const ustring & marker, c
   // Close style.
   xmlTextWriterEndElement(writer);
 }
+
+
+void OpenDocument::note_unformatted_markers (vector <ustring>& markers)
+{
+  // Add the markers from the object to the container.
+  vector <ustring> temporal_markers (unformatted_markers.begin(), unformatted_markers.end());
+  for (unsigned int i = 0; i < temporal_markers.size(); i++) {
+    markers.push_back (temporal_markers[i]);
+  }
+  // Remove double ones.
+  set <ustring> temporal_set (markers.begin(), markers.end());
+  markers.clear();
+  markers.assign (temporal_set.begin(), temporal_set.end());
+}
+
