@@ -1,9 +1,9 @@
 /*
-** Copyright (C) 2003-2006 Teus Benschop.
+** Copyright (©) 2003-2009 Teus Benschop.
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 **  
 ** This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
 **  
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
-** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 **  
 */
 
@@ -36,13 +36,13 @@ public:
   void set_iterate (double minimum, double maximum, unsigned int max_iteration);
   void iterate ();
   void pulse ();
+  void hide ();
   bool cancel;
 private:
+  GtkBuilder *gtkbuilder;
   GtkWidget *progresswindow;
-  GtkWidget *vbox3;
-  GtkWidget *infolabel;
+  GtkWidget *label;
   GtkWidget *progressbar;
-  GtkWidget *hbox6;
   GtkWidget *cancelbutton;
   static void on_cancelbutton_clicked (GtkButton *button, gpointer user_data);
   void on_cancel ();
