@@ -17,11 +17,11 @@
 **  
 */
 
+
 #include "utilities.h"
 #include "search_utils.h"
 #include "bible.h"
 #include "gtkwrappers.h"
-#include "references.h"
 #include "bibletime.h"
 #include <sqlite3.h>
 #include "sqlite_reader.h"
@@ -36,15 +36,14 @@
 #include "settings.h"
 #include "tiny_utilities.h"
 
-void search_string_basic(const ustring & project, bool use_book_selection, unsigned int currentchapter, vector < Reference > &results)
+
+void search_string_basic(const ustring & project, bool use_book_selection, unsigned int currentchapter, vector <Reference> &results)
 /*
 Basic search for a string in the text.
 project: project to search.
 use_book_selection: whether to limit searches to the selected books only.
 chapter: currently opened chapter in the editor.
 results: will contain the search results.
-It uses grep for searching the textfiles, e.g.:
-grep --recursive --line-number --include data '10' .
 */
 {
   // Settings.
@@ -59,9 +58,9 @@ grep --recursive --line-number --include data '10' .
     localsearchword = localsearchword.casefold();
   // Book and chapter selection.
   bool search_current_chapter = settings->session.search_current_chapter;
-  set < unsigned int >selectedbooks = settings->session.selected_books;
+  set <unsigned int> selectedbooks = settings->session.selected_books;
   // Get all books.
-  vector < unsigned int >books = project_get_books(project);
+  vector <unsigned int> books = project_get_books(project);
   // Progress.
   ProgressWindow progresswindow("Searching", false);
   progresswindow.set_iterate(0, 1, books.size());
@@ -76,7 +75,7 @@ grep --recursive --line-number --include data '10' .
       }
     }
     // Get all chapters and go through them.
-    vector < unsigned int >chapters = project_get_chapters(project, book);
+    vector <unsigned int> chapters = project_get_chapters(project, book);
     for (unsigned int ch = 0; ch < chapters.size(); ch++) {
       unsigned int chapter = chapters[ch];
       // Do we search this chapter?
@@ -119,6 +118,7 @@ grep --recursive --line-number --include data '10' .
   }
 }
 
+
 ustring search_in_bibledit_assemble_line(const ustring & input, AreaType areatype, bool area_id, bool area_intro, bool area_heading, bool area_chapter, bool area_study, bool area_notes, bool area_xref, bool area_verse)
 // Assembles the line of text we have to search through, depending on the area
 // selection.
@@ -188,6 +188,7 @@ ustring search_in_bibledit_assemble_line(const ustring & input, AreaType areatyp
   return line;
 }
 
+
 bool search_in_bibledit_word_boundaries_match(const ustring & text, const ustring & searchword, bool matchbeginning, bool matchending, bool globbing)
 // Does the word boundary matching.
 {
@@ -323,6 +324,7 @@ bool search_in_bibledit_word_boundaries_match(const ustring & text, const ustrin
   return match;
 }
 
+
 vector < Reference > search_in_bibledit()
 // Advanced searching in Bibledit.
 {
@@ -371,7 +373,7 @@ vector < Reference > search_in_bibledit()
   for (unsigned int bk = 0; bk < availablebooks.size(); bk++) {
     progresswindow.iterate();
     if (progresswindow.cancel) {
-      throw runtime_error("Search cancelled");
+      return results;
     }
     // If the book is not to be searched, skip it.
     if (search_current_book)
@@ -436,60 +438,8 @@ vector < Reference > search_in_bibledit()
   return results;
 }
 
-vector < Reference > search_in_bibletime(BibleTime * bibletime)
-/*
-This handles the bibletime search functions.
-*/
-{
-  extern Settings *settings;
 
-  ProgressWindow progresswindow("Searching in BibleTime", false);
-  progresswindow.set_fraction(0.5);
-
-  // Storage for search results.
-  vector < ustring > searchresults;
-
-  // We need to normalize the search expression, as prescribed, when comparing strings.
-  ustring localsearchword;
-  localsearchword = settings->session.searchword;
-  localsearchword = localsearchword.normalize();
-
-  // Do the actual search.
-  switch (settings->session.searchbibletimetype) {
-  case sbttDefaultBible:
-    searchresults = bibletime->search_in_default_bible(localsearchword);
-    break;
-  case sbttOpenModules:
-    searchresults = bibletime->search_in_open_modules(localsearchword);
-    break;
-  case sbttBible:
-    searchresults = bibletime->search_in_module(settings->session.search_bibletime_bible, localsearchword);
-    break;
-  case sbttCommentary:
-    searchresults = bibletime->search_in_module(settings->session.search_bibletime_commentary, localsearchword);
-    break;
-  }
-
-  // Change the results to our format.
-  vector < Reference > searchresults2;
-  for (unsigned int i = 0; i < searchresults.size(); i++) {
-    size_t position;
-    position = searchresults[i].find("] ");
-    if (position != string::npos) {
-      position++;
-      position++;
-      searchresults[i].erase(0, position);
-    }
-    Reference reference(0);
-    if (reference_discover(0, 0, "", searchresults[i], reference.book, reference.chapter, reference.verse)) {
-      searchresults2.push_back(reference);
-    }
-  }
-
-  return searchresults2;
-}
-
-void search_load_references(vector < Reference > &searchresults, GtkListStore * liststore, GtkWidget * listview, GtkTreeViewColumn * treeviewcolumn)
+void search_load_references(WindowReferences * references_window, vector <Reference>& searchresults)
 /*
 This function takes the searchresults from a search, and depending on information
 entered in the search dialog, loads this in the reference area, or merges it 
@@ -499,9 +449,6 @@ with the references that are already there.
   // Session data.  
   extern Settings *settings;
 
-  // Project data.
-  ProjectConfiguration *projectconfig = settings->projectconfig(settings->genconfig.project_get());
-
   // Deal with how the current search results interact with the ones in the editor.
   SearchResultsType searchresultstype = settings->session.searchresultstype;
   // If the search page is zero, that means we are on basic search. And that 
@@ -514,18 +461,13 @@ with the references that are already there.
     {
       // Sort and load the references.
       sort_references(searchresults);
-      References references(liststore, listview, treeviewcolumn);
-      references.set_references(searchresults);
-      references.fill_store(projectconfig->language_get());
+      references_window->set (searchresults, settings->genconfig.project_get(), NULL);
       break;
     }
   case sstAdd:
     {
       // Add the references to the ones already in the editor
-      vector < Reference > loaded_references;
-      References references(liststore, listview, treeviewcolumn);
-      references.get_loaded();
-      references.get_references(loaded_references);
+      vector <Reference> loaded_references = references_window->get();
       for (unsigned int i = 0; i < searchresults.size(); i++) {
         bool add = true;
         for (unsigned int i2 = 0; i2 < loaded_references.size(); i2++) {
@@ -539,17 +481,13 @@ with the references that are already there.
       }
       searchresults = loaded_references;
       sort_references(searchresults);
-      references.set_references(searchresults);
-      references.fill_store(projectconfig->language_get());
+      references_window->set (searchresults, settings->genconfig.project_get(), NULL);
       break;
     }
   case sstSubtract:
     {
       // Subtract the references from the ones already in the editor.
-      vector < Reference > loaded_references;
-      References references(liststore, listview, treeviewcolumn);
-      references.get_loaded();
-      references.get_references(loaded_references);
+      vector <Reference> loaded_references = references_window->get();
       for (unsigned int i = 0; i < searchresults.size(); i++) {
         vector < Reference >::iterator iter(loaded_references.begin());
         for (unsigned int i2 = 0; i2 < loaded_references.size(); i2++) {
@@ -562,8 +500,7 @@ with the references that are already there.
       }
       searchresults = loaded_references;
       sort_references(searchresults);
-      references.set_references(searchresults);
-      references.fill_store(projectconfig->language_get());
+      references_window->set (searchresults, settings->genconfig.project_get(), NULL);
       break;
     }
   case sstShare:
@@ -573,11 +510,8 @@ with the references that are already there.
       // and the ones that are the result of this search, will be loaded,
       // provided they are the same.
       // All other ones will be discarded.
-      vector < Reference > loaded_references;
-      References references(liststore, listview, treeviewcolumn);
-      references.get_loaded();
-      references.get_references(loaded_references);
-      vector < Reference > shared_references;
+      vector <Reference> loaded_references = references_window->get();
+      vector <Reference> shared_references;
       for (unsigned int i = 0; i < searchresults.size(); i++) {
         for (unsigned int i2 = 0; i2 < loaded_references.size(); i2++) {
           if (searchresults[i].equals(loaded_references[i2])) {
@@ -588,17 +522,17 @@ with the references that are already there.
       }
       searchresults = shared_references;
       sort_references(searchresults);
-      references.set_references(searchresults);
-      references.fill_store(projectconfig->language_get());
+      references_window->set (searchresults, settings->genconfig.project_get(), NULL);
       break;
     }
   }
 }
 
-void search_string(GtkListStore * liststore, GtkWidget * listview, GtkTreeViewColumn * treeviewcolumn, BibleTime * bibletime)
+
+void search_string(WindowReferences * references_window)
 {
   // Storage for results;
-  vector < Reference > searchresults;
+  vector <Reference> searchresults;
 
   // Configuration & session.
   extern Settings *settings;
@@ -607,20 +541,25 @@ void search_string(GtkListStore * liststore, GtkWidget * listview, GtkTreeViewCo
   case 0:
     {
       // Basic search.
-      vector < unsigned int >mybooks;
-      {
-        set < unsigned int >selected_books = settings->session.selected_books;
-        mybooks.assign(selected_books.begin(), selected_books.end());
+
+      // Save the current book selection in case we modify it.
+      set <unsigned int> saved_book_selection = settings->session.selected_books;
+
+      // In case we search in the current book only, modify the book selection.
+      if (settings->session.search_current_book) {
+        settings->session.selected_books.clear();
+        settings->session.selected_books.insert(settings->genconfig.book_get());
       }
-      set < unsigned int >selected_books;
-      selected_books.insert(settings->genconfig.book_get());
-      settings->session.selected_books = selected_books;
+
+      // Search.
       unsigned int chapter = convert_to_int(settings->genconfig.chapter_get());
-      search_string_basic(settings->genconfig.project_get(), settings->session.search_current_book, chapter, searchresults);
-      selected_books.clear();
-      for (unsigned int i = 0; i < mybooks.size(); i++)
-        selected_books.insert(mybooks[i]);
-      settings->session.selected_books = selected_books;
+      search_string_basic(settings->genconfig.project_get(), true, chapter, searchresults);
+      sort_references(searchresults);
+
+      // Restore current book selection.
+      settings->session.selected_books = saved_book_selection;
+
+      // Done.
       break;
     }
   case 1:
@@ -631,11 +570,10 @@ void search_string(GtkListStore * liststore, GtkWidget * listview, GtkTreeViewCo
     }
   case 2:
     {
-      // Search in bibletime.
-      searchresults = search_in_bibletime(bibletime);
       break;
     }
   }
   // Load the references in the editor.
-  search_load_references(searchresults, liststore, listview, treeviewcolumn);
+  search_load_references(references_window, searchresults);
 }
+
