@@ -45,9 +45,6 @@ public:
   bool search_end_word_match;
   SearchResultsType searchresultstype;
   int search_page;
-  SearchBibleTimeType searchbibletimetype;
-  ustring search_bibletime_bible;
-  ustring search_bibletime_commentary;
   // Book selection.
   set<unsigned int> selected_books;
   // References highlighting.
@@ -88,14 +85,19 @@ public:
   // Import raw text.
   int import_raw_text_book;
   int import_raw_text_chapter;
-  // Windows.
-  vector <GtkWindow *> open_windows;
+  // Floating windows.
+  vector <gpointer> open_floating_windows;
   // Project notes.
   bool project_notes_show_title;
   // Styles.
   ustring selected_style;
   // Merge.
   unsigned int merge_action;
+  // Question dialogs.
+  map <int, bool> yes_no_always_dialog_enabled;
+  map <int, int> yes_no_always_dialog_response;
+  // Reference exchange.
+  bool receiving_references;
 private:
 };
 
