@@ -1,9 +1,9 @@
 /*
-** Copyright (C) 2003-2006 Teus Benschop.
+** Copyright (©) 2003-2009 Teus Benschop.
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 **  
 ** This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
 **  
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
-** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 **  
 */
 
@@ -30,15 +30,19 @@ class Shortcuts
 {
 public:
   Shortcuts (int dummy);
+  ~Shortcuts ();
   void stockbutton (GtkWidget * widget);
   void button (GtkWidget * widget);
   void label (GtkWidget * widget);
   void process ();
   GtkWidget * lastwidget;
+  void consider_assistant ();
 private:
   vector <GtkWidget *> widgets;
   vector <bool> is_button;
   set <ustring> unavailables;
+  vector <GtkWidget *> created_widgets;
+  void create_widget (const gchar * stock);
 };
 
 
