@@ -199,9 +199,44 @@ void SpellingChecker::collect_words(GtkTextBuffer * textbuffer)
   while (gtk_text_iter_forward_word_end(&enditer)) {
     startiter = enditer;
     gtk_text_iter_backward_word_start(&startiter);
-    GtkTextIter iter = startiter;
-    check_word(textbuffer, &startiter, &enditer);
+    GtkTextIter moved_enditer;
+    if (move_end_iterator_before_note_caller_and_validate (startiter, enditer, moved_enditer)) {
+      check_word(textbuffer, &startiter, &moved_enditer);
+    }
   }
+  
+  /*
+
+See the following bug:
+
+I'm working with a bunch of languages that use the hyphen within their
+words.  The hyphen is seen as a word break in BE.  Does anyone know if
+there a unicode character that looks like a hyphen, but will be viewed
+as a regular character?  I've tried a non-breaking hyphen and the
+spellchecker still sees it as a word break.
+
+As far as I can tell, Unicode does not specify any hyphen character that must not act as a word boundary
+(except for the soft hyphen, but that would not fulfill your needs because it is not visible except when it is followed by a line break); 
+pretty much any of the hyphen characters may be tailored not to act as a word boundary, though.  
+I would say that should be something that the localization of the spell checker should take care of, 
+so if none of the characters works (see the list below—in particular notice that the actual hyphen Unicode character is not what you get 
+when you type a hyphen on your keyboard; that is instead the hyphen-minus character), you may want to submit this as a 
+bug/feature request with the project for whatever spell checking library is used by Bibledit 
+(I'm assuming BE uses one of the many open-source spelling libraries and not a home-grown one).  
+In particular, I would say that a person who uses a "non-breaking hyphen" probably typically expects its "non-breaking" aspect to apply to words 
+as well as lines (although in reality the Unicode standard requires only that a non-breaking hyphen prevent line breaks).
+
+The complete list of hyphen characters in Unicode is as follows:
+
+Hyphen or minus sign (hyphen-minus or hyphus) - U+002D
+Soft (or discretionary) hyphen - U+00AD
+Hyphen - U+2010
+Non-breaking hyphen - U+2011
+Hyphen bullet - U+2043
+
+Since Pango routines are used for determining the word boundaries, the right thing to do is to fix Pango.
+
+  */
 }
 
 
@@ -269,7 +304,7 @@ vector <ustring> SpellingChecker::get_misspellings (GtkTextBuffer * textbuffer)
 
 gboolean SpellingChecker::on_button_press_event(GtkWidget * widget, GdkEventButton * event, gpointer user_data)
 // When the user right-clicks on a word, they want to check that word.
-// Here, we do NOT  move the cursor to the location of the clicked-upon word
+// Here, we do not move the cursor to the location of the clicked-upon word
 // since that prevents the use of edit functions on the context menu.
 {
   ((SpellingChecker *) user_data)->button_press_event(widget, event);
@@ -298,7 +333,7 @@ void SpellingChecker::populate_popup(GtkTextView * textview, GtkMenu * menu)
   // Find out whether a misspelled word was picked.
   GtkTextIter start, end;
   right_clicked_word_get_extends(&start, &end);
-
+  
   // Bail out if there was no misspelled word.
   if (!gtk_text_iter_has_tag(&start, misspelling_tag))
     return;
@@ -354,6 +389,7 @@ GtkWidget *SpellingChecker::build_suggestion_menu(GtkTextBuffer * buffer, const
   if (dicts.empty()) {
     return topmenu;
   }
+
   // There can be more than one dictionary. Go through them all to find suggestions.
   // The use of more than one dictionary will inevitably give double suggestions.
   // These are weeded out.
@@ -438,12 +474,16 @@ GtkWidget *SpellingChecker::build_suggestion_menu(GtkTextBuffer * buffer, const
 void SpellingChecker::right_clicked_word_get_extends(GtkTextIter * start, GtkTextIter * end)
 // Get the word boundaries for the word the user right-clicked.
 {
+  // Get the boundaries.
   *start = right_clicked_iter;
   if (!gtk_text_iter_starts_word(start))
     gtk_text_iter_backward_word_start(start);
   *end = *start;
   if (gtk_text_iter_inside_word(end))
     gtk_text_iter_forward_word_end(end);
+    
+  // Exclude note callers that follow.
+  move_end_iterator_before_note_caller_and_validate (* start, * end, * end);
 }
 
 
@@ -521,10 +561,8 @@ void SpellingChecker::on_replace_word(GtkWidget * menuitem, gpointer user_data)
 
 
 void SpellingChecker::replace_word(GtkWidget * menuitem)
-/*
-Replaces the misspelled word in the text with the word that is chosen in the menu.
-An algorithm is used that gives the replacement the same styles as the original.
-*/
+// Replaces the misspelled word in the text with the word that is chosen in the menu.
+// An algorithm is used that gives the replacement the same styles as the original.
 {
   // Bail out if there is no dictionary.
   if (dicts.empty())
@@ -558,6 +596,7 @@ An algorithm is used that gives the replacement the same styles as the original.
 
   // Delete the old word, and insert the new one.
   gtk_text_buffer_delete(buffer, &start, &end);
+  gtk_text_buffer_get_iter_at_offset (buffer, &start, offset);
   gtk_text_buffer_insert(buffer, &start, newword, -1);
 
   // Store this replacement in enchant.
@@ -566,7 +605,8 @@ An algorithm is used that gives the replacement the same styles as the original.
   // Free the memory used.
   g_free(oldword);
 
-  // Apply the tags of the old word to the new. 
+/*
+  // Apply the tags of the old word to the new. This has been disabled for just now. It should use EditorActions.
   // If there are not enough tags, keep repeating the last one.
   ustring unewword(newword);
   for (unsigned int i = 0; i < unewword.length(); i++) {
@@ -589,6 +629,7 @@ An algorithm is used that gives the replacement the same styles as the original.
     if (!characterstyle.empty())
       gtk_text_buffer_apply_tag_by_name(buffer, characterstyle.c_str(), &start, &end);
   }
+  */
 }
 
 
