@@ -1,9 +1,9 @@
 /*
-** Copyright (C) 2003-2006 Teus Benschop.
+** Copyright (©) 2003-2009 Teus Benschop.
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 **  
 ** This program is distributed in the hope that it will be useful,
@@ -13,10 +13,11 @@
 **  
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
-** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 **  
 */
 
+
 #ifndef INCLUDED_UNIXWRAPPERS_H
 #define INCLUDED_UNIXWRAPPERS_H
 
@@ -25,4 +26,12 @@
 #include <glib.h>
 
 
+bool unix_fnmatch (const char * pattern, const ustring& text);
+void unix_cp (const ustring& from, const ustring& to);
+void unix_cp_r (const ustring& from, const ustring& to);
+void unix_mv (const ustring& from, const ustring& to);
+void unix_rmdir (const ustring& dir);
+void unix_kill (GPid pid);
+
+
 #endif
