@@ -17,6 +17,7 @@
 **  
 */
 
+
 #include "libraries.h"
 #include "upgrade.h"
 #include "stylesheetutils.h"
@@ -27,11 +28,15 @@
 #include "git.h"
 #include "referencememory.h"
 #include "snapshots.h"
+#include "directories.h"
+#include "gwrappers.h"
+#include "kjv.h"
+
 
 void upgrade()
 {
   stylesheets_upgrade();
-  projects_initial_check(true);
+  projects_initial_check();
   notes_database_verify();
   notes_categories_check();
   upgrade_configuration();
@@ -39,8 +44,10 @@ void upgrade()
   for (unsigned int i = 0; i < projects.size(); i++) {
     upgrade_project_configuration(projects[i]);
   }
-  statistics_initial_check_all(true);
+  statistics_initial_check_all();
   references_memory_database_verify();
   snapshots_initialize_all ();
   git_upgrade ();
 }
+
+
