@@ -17,6 +17,7 @@
 **  
 */
 
+
 #include "libraries.h"
 #include "utilities.h"
 #include <glib.h>
@@ -27,8 +28,10 @@
 #include "shell.h"
 #include "tiny_utilities.h"
 
+
 #define MY_NUMBERS "0123456789"
 
+
 ustring number_in_string(const ustring & str)
 {
   // Looks for and returns a positive number in a string.
@@ -41,8 +44,10 @@ ustring number_in_string(const ustring & str)
   return output;
 }
 
+
 #undef MY_NUMBERS
 
+
 unsigned int digit_count_in_string(const ustring & str)
 {
   unsigned int digitcount = 0;
@@ -54,6 +59,7 @@ unsigned int digit_count_in_string(const ustring & str)
   return digitcount;
 }
 
+
 ustring upperCase(const ustring & s)
 {
 // Make an uppercase copy of s
@@ -63,6 +69,7 @@ ustring upperCase(const ustring & s)
   return upper;
 }
 
+
 ustring lowerCase(const ustring & s)
 {
 // Make a lowercase copy of s
@@ -72,6 +79,7 @@ ustring lowerCase(const ustring & s)
   return lower;
 }
 
+
 ustring remove_spaces(const ustring & s)
 {
   ustring s2 = s;
@@ -83,6 +91,7 @@ ustring remove_spaces(const ustring & s)
   return s2;
 }
 
+
 void write_lines(const ustring & file, vector < ustring > &lines)
 {
   WriteText wt(file);
@@ -92,11 +101,13 @@ void write_lines(const ustring & file, vector < ustring > &lines)
   }
 }
 
+
 ustring temporary_file(const ustring & filename)
 {
   return gw_build_filename(directories_get_temp(), filename);
 }
 
+
 ustring string_reverse(const ustring & s)
 {
   ustring returnvalue;
@@ -105,6 +116,7 @@ ustring string_reverse(const ustring & s)
   return returnvalue;
 }
 
+
 ustring double_apostrophy(const ustring & line)
 {
   /*
@@ -123,6 +135,7 @@ ustring double_apostrophy(const ustring & line)
   return returnvalue;
 }
 
+
 unsigned int file_get_modification_time(const ustring & filename)
 {
   struct stat statbuf;
@@ -130,6 +143,7 @@ unsigned int file_get_modification_time(const ustring & filename)
   return statbuf.st_mtime;
 }
 
+
 unsigned int file_get_size(const ustring & filename)
 {
   struct stat statbuf;
@@ -137,6 +151,7 @@ unsigned int file_get_size(const ustring & filename)
   return statbuf.st_size;
 }
 
+
 void textbuffer_get_lines(GtkTextBuffer * buffer, vector < ustring > &lines, bool trimline)
 // Reads all the lines in the textbuffer.
 {
@@ -164,6 +179,7 @@ void textbuffer_get_lines(GtkTextBuffer * buffer, vector < ustring > &lines, boo
   }
 }
 
+
 bool replace_text(ustring & line, const ustring & look_for, const ustring & replace_with)
 // Replaces some text. Returns true if any replacement was done.
 {
@@ -177,6 +193,7 @@ bool replace_text(ustring & line, const ustring & look_for, const ustring & repl
   return replacements_done;
 }
 
+
 bool replace_text_between(ustring & line, const ustring & start, const ustring & end, const ustring & replacement)
 // Replaces text that starts with "start" and ends with "end" with "replacement".
 // Returns true if replacement was done.
@@ -193,6 +210,7 @@ bool replace_text_between(ustring & line, const ustring & start, const ustring &
   return replacements_done;
 }
 
+
 void quick_swap(ustring & a, ustring & b)
 {
   ustring t = a;
@@ -200,6 +218,7 @@ void quick_swap(ustring & a, ustring & b)
   b = t;
 }
 
+
 void quick_swap(unsigned int &a, unsigned int &b)
 {
   unsigned int t = a;
@@ -207,6 +226,15 @@ void quick_swap(unsigned int &a, unsigned int &b)
   b = t;
 }
 
+
+void quick_swap(long unsigned int &a, long unsigned int &b)
+{
+  long unsigned int t = a;
+  a = b;
+  b = t;
+}
+
+
 void quick_swap(int &a, int &b)
 {
   int t = a;
@@ -214,6 +242,7 @@ void quick_swap(int &a, int &b)
   b = t;
 }
 
+
 void quick_swap(bool & a, bool & b)
 {
   bool t = a;
@@ -221,6 +250,7 @@ void quick_swap(bool & a, bool & b)
   b = t;
 }
 
+
 void quick_sort(vector < unsigned int >&one, vector < ustring > &two, unsigned int beg, unsigned int end)
 /*
 This function is unusual in the sense that it does not sort one container, as
@@ -250,6 +280,7 @@ following the reordering done in the first container.
   }
 }
 
+
 void quick_sort(vector < ustring > &one, vector < unsigned int >&two, unsigned int beg, unsigned int end)
 {
   if (end > beg + 1) {
@@ -273,6 +304,7 @@ void quick_sort(vector < ustring > &one, vector < unsigned int >&two, unsigned i
   }
 }
 
+
 void quick_sort(vector < unsigned int >&one, vector < unsigned int >&two, unsigned int beg, unsigned int end)
 {
   if (end > beg + 1) {
@@ -375,6 +407,7 @@ void quick_sort(vector < ustring > &one, vector < ustring > &two, unsigned int b
   }
 }
 
+
 void quick_sort(vector < ustring > &one, vector < bool > &two, unsigned int beg, unsigned int end)
 {
   if (end > beg + 1) {
@@ -406,6 +439,7 @@ void quick_sort(vector < ustring > &one, vector < bool > &two, unsigned int beg,
   }
 }
 
+
 void quick_sort(vector < ustring > &one, unsigned int beg, unsigned int end)
 {
   if (end > beg + 1) {
@@ -427,6 +461,31 @@ void quick_sort(vector < ustring > &one, unsigned int beg, unsigned int end)
   }
 }
 
+
+void quick_sort(vector <long unsigned int>& one, vector <long unsigned int>& two, unsigned int beg, unsigned int end)
+{
+  if (end > beg + 1) {
+    long unsigned int piv = one[beg];
+    unsigned int l = beg + 1;
+    unsigned int r = end;
+    while (l < r) {
+      if (one[l] <= piv) {
+        l++;
+      } else {
+        --r;
+        quick_swap(one[l], one[r]);
+        quick_swap(two[l], two[r]);
+      }
+    }
+    --l;
+    quick_swap(one[l], one[beg]);
+    quick_swap(two[l], two[beg]);
+    quick_sort(one, two, beg, l);
+    quick_sort(one, two, r, end);
+  }
+}
+
+
 gchar *de_windows_notepad(gchar * contents)
 // Some Windows textfiles, probably the ones created with Notepad, have 
 // the "feature" to put \xEF\xBB\xBF at the start of the file.
@@ -442,6 +501,17 @@ gchar *de_windows_notepad(gchar * contents)
   return returnvalue;
 }
 
+
+void de_byte_order_mark (ustring& line)
+// Some textfiles start with a byte order mark.
+// This function remove it.
+{
+  if (line.find ("﻿") == 0) { // Note that there's text between the quotation marks.
+    line.erase (0, 1);
+  }
+}
+
+
 ustring spaces(unsigned int count)
 // Returns "count" spaces.
 {
@@ -451,12 +521,14 @@ ustring spaces(unsigned int count)
   return space;
 }
 
+
 void bitpattern_add(ustring & pattern, bool setting)
 // Adds one bit for "setting" to "pattern".
 {
   pattern.append(convert_to_string(setting));
 }
 
+
 bool bitpattern_take(ustring & pattern)
 // Return the next bit from "pattern" and removes it from that string.
 // This implies that settngs from the pattern must be taken in the same order
@@ -470,6 +542,7 @@ bool bitpattern_take(ustring & pattern)
   return setting;
 }
 
+
 ustring character_to_decimal_entity(const ustring & character)
 {
   gunichar unichar;
@@ -483,6 +556,7 @@ ustring character_to_decimal_entity(const ustring & character)
   return udec;
 }
 
+
 ustring character_to_hexadecimal_entity(const ustring & character)
 {
   gunichar unichar;
@@ -496,6 +570,7 @@ ustring character_to_hexadecimal_entity(const ustring & character)
   return udec;
 }
 
+
 void string_append_line(ustring & container, const ustring & line)
 {
   if (!container.empty()) {
@@ -504,6 +579,7 @@ void string_append_line(ustring & container, const ustring & line)
   container.append(line);
 }
 
+
 ustring present_working_directory()
 // Gives the present working directory.
 {
@@ -527,6 +603,16 @@ bool vector_strings_equal (const vector <ustring>& vector1, const vector <ustrin
 }
 
 
+int clamp (int in, int min, int max)
+{
+  if (in < min)
+    in = min;
+  if (in > max)
+    in = max;
+  return in;
+}
+
+
 ReadDirectories::ReadDirectories(const ustring & path, const ustring & prefix, const ustring & suffix)
 {
   // Reads the directories in directory "path" that end on "suffix".
@@ -549,10 +635,12 @@ ReadDirectories::ReadDirectories(const ustring & path, const ustring & prefix, c
   }
 }
 
+
 ReadDirectories::~ReadDirectories()
 {
 }
 
+
 ReadFiles::ReadFiles(const ustring & path, const ustring & prefix, const ustring & suffix)
 {
   // Reads the regular files in directory "path" that end on "suffix".
@@ -575,10 +663,12 @@ ReadFiles::ReadFiles(const ustring & path, const ustring & prefix, const ustring
   }
 }
 
+
 ReadFiles::~ReadFiles()
 {
 }
 
+
 ReadText::ReadText(const ustring & file, bool silent, bool trimming)
 {
   // Reads the text and stores it line by line, trimmed, into "lines".
@@ -600,10 +690,12 @@ ReadText::ReadText(const ustring & file, bool silent, bool trimming)
   }
 }
 
+
 ReadText::~ReadText()
 {
 }
 
+
 WriteText::WriteText(const ustring & file)
 {
 /*
@@ -619,11 +711,13 @@ WriteText::WriteText(const ustring & file)
   }
 }
 
+
 WriteText::~WriteText()
 {
   close(fd);
 }
 
+
 void WriteText::text(const ustring & text)
 // Write the text. For calculating the lenght, do not use text.length(),
 // because this gives the number of unicode characters, not the length in bytes. 
@@ -632,6 +726,7 @@ void WriteText::text(const ustring & text)
   if (write(fd, text.c_str(), strlen(text.c_str()))) ;
 }
 
+
 Parse::Parse(const ustring & line, bool remove_punctuation, const ustring & separator)
 // Parses a line of text in its separate words.
 // remove_punctuation: remove some standard punctuation.
@@ -655,10 +750,12 @@ Parse::Parse(const ustring & line, bool remove_punctuation, const ustring & sepa
   }
 }
 
+
 Parse::~Parse()
 {
 }
 
+
 ParseWords::ParseWords(const ustring & text)
 // Parses a line of text in its separate words.
 // Note: This is comparable to object Parse, but does a better job.
@@ -684,3 +781,4 @@ ParseWords::ParseWords(const ustring & text)
   g_object_unref(textbuffer);
 }
 
+
