@@ -49,7 +49,9 @@ void quick_sort (vector<int>& one, vector<unsigned int>& two, unsigned int beg,
 void quick_sort (vector<ustring>& one, vector<ustring>& two, unsigned int beg, unsigned int end);
 void quick_sort (vector<ustring>& one, vector<bool>& two, unsigned int beg, unsigned int end);
 void quick_sort (vector<ustring>& one, unsigned int beg, unsigned int end);
+void quick_sort (vector<long unsigned int>& one, vector<long unsigned int>& two, unsigned int beg, unsigned int end);
 gchar * de_windows_notepad (gchar * contents);
+void de_byte_order_mark (ustring& line);
 ustring spaces (unsigned int count);
 void bitpattern_add (ustring& pattern, bool setting);
 bool bitpattern_take (ustring& pattern);
@@ -58,6 +60,7 @@ ustring character_to_hexadecimal_entity (const ustring& character);
 void string_append_line (ustring& container, const ustring& line);
 ustring present_working_directory ();
 bool vector_strings_equal (const vector <ustring>& vector1, const vector <ustring>& vector2);
+int clamp (int in, int min, int max);
 
 
 class ReadDirectories
