@@ -22,7 +22,7 @@
 #include <glib.h>
 #include "windowcheckkeyterms.h"
 #include "help.h"
-#include "window.h"
+#include "floatingwindow.h"
 #include "keyterms.h"
 #include "tiny_utilities.h"
 #include "utilities.h"
@@ -34,10 +34,11 @@
 #include "mapping.h"
 #include "bible.h"
 #include "books.h"
+#include "xmlutils.h"
 
 
-WindowCheckKeyterms::WindowCheckKeyterms(GtkAccelGroup * accelerator_group, bool startup, GtkWidget * parent_box):
-WindowBase(widCheckKeyterms, "Check keyterms", startup, 0, parent_box), myreference(0)
+WindowCheckKeyterms::WindowCheckKeyterms(GtkWidget * parent_layout, GtkAccelGroup *accelerator_group, bool startup):
+FloatingWindow(parent_layout, widCheckKeyterms, "Check keyterms", startup), myreference(0)
 // Window for checking keyterms.
 {
   // Save / initialize variables.
@@ -46,7 +47,7 @@ WindowBase(widCheckKeyterms, "Check keyterms", startup, 0, parent_box), myrefere
   // Build gui.
   vbox = gtk_vbox_new(FALSE, 0);
   gtk_widget_show(vbox);
-  gtk_container_add(GTK_CONTAINER(window_vbox), vbox);
+  gtk_container_add(GTK_CONTAINER(vbox_client), vbox);
 
   // Produce the signal to be given on a new reference.
   signal = gtk_button_new();
@@ -65,6 +66,8 @@ WindowBase(widCheckKeyterms, "Check keyterms", startup, 0, parent_box), myrefere
   gtk_widget_show (combobox_collection);
   gtk_box_pack_start (GTK_BOX (hbox_collection), combobox_collection, TRUE, TRUE, 0);
 
+  connect_focus_signals (combobox_collection);
+  
   label_list = gtk_label_new_with_mnemonic ("_List");
   gtk_widget_show (label_list);
   gtk_box_pack_start (GTK_BOX (vbox), label_list, FALSE, FALSE, 0);
@@ -81,6 +84,8 @@ WindowBase(widCheckKeyterms, "Check keyterms", startup, 0, parent_box), myrefere
   gtk_container_add(GTK_CONTAINER(scrolledwindow_terms), htmlview_terms);
   gtk_html_allow_selection(GTK_HTML(htmlview_terms), true);
 
+  connect_focus_signals (htmlview_terms);
+  
   // Store for the renderings.
   treestore_renderings = gtk_tree_store_new(4, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_STRING, G_TYPE_BOOLEAN);
 
@@ -88,7 +93,7 @@ WindowBase(widCheckKeyterms, "Check keyterms", startup, 0, parent_box), myrefere
   gtk_widget_show(treeview_renderings);
   gtk_box_pack_start(GTK_BOX(vbox), treeview_renderings, false, false, 0);
 
-  g_signal_connect((gpointer) treeview_renderings, "visibility-notify-event", G_CALLBACK(on_visibility_notify_event), gpointer(this));
+  connect_focus_signals (treeview_renderings);
 
   // Renderer, column and selection.
   GtkCellRenderer *renderer_renderings = gtk_cell_renderer_toggle_new();
@@ -107,6 +112,7 @@ WindowBase(widCheckKeyterms, "Check keyterms", startup, 0, parent_box), myrefere
   gtk_tree_selection_set_mode(treeselect_renderings, GTK_SELECTION_SINGLE);
 
   g_signal_connect((gpointer) htmlview_terms, "link-clicked", G_CALLBACK(on_html_link_clicked), gpointer(this));
+  g_signal_connect((gpointer) htmlview_terms, "submit", G_CALLBACK(on_html_submit), gpointer(this));
   g_signal_connect((gpointer) combobox_collection, "changed", G_CALLBACK(on_combobox_keyterm_collection_changed), gpointer(this));
 
   gtk_label_set_mnemonic_widget(GTK_LABEL(label_collection), combobox_collection);
@@ -129,14 +135,10 @@ WindowCheckKeyterms::~WindowCheckKeyterms()
 }
 
 
-void WindowCheckKeyterms::go_to(const ustring & project, Reference & reference)
+void WindowCheckKeyterms::go_to_term(unsigned int id)
 {
-  // Bail out if there's no change in the reference.
-  if (myreference.equals(reference))
-    return;
-
-  // Store the new reference in the object.
-  myreference.assign(reference);
+  ustring url = "keyterm " + convert_to_string (id);
+  html_link_clicked (url.c_str());
 }
 
 
@@ -234,7 +236,7 @@ void WindowCheckKeyterms::save_renderings()
   ustring project = settings->genconfig.project_get();
   keyterms_store_renderings(project, keyterm, category, renderings, wholewords, casesensitives);
   load_renderings();
-  html_link_clicked (active_url.c_str());
+  html_link_clicked (last_keyword_url.c_str());
 }
 
 
@@ -411,22 +413,27 @@ void WindowCheckKeyterms::html_link_clicked (const gchar * url)
   // New url.
   active_url = url;
 
+  // Whether to show some widgets.
+  bool show_collections = false;
+  bool show_renderings = false;
+    
   // Start writing a html page.
   HtmlWriter2 htmlwriter ("");
   bool display_another_page = false;
 
-  //extern Settings *settings;
-  //myproject = settings->genconfig.project_get();
-
   if (active_url.find ("keyterm ") == 0) {
+    // Store url of this keyterm.
+    last_keyword_url = active_url;
     // Get the keyterm identifier.
     ustring url = active_url;
     url.erase (0, 8);
     keyword_id = convert_to_int (url);
-    // Show the renderings (to be done before displaying the verses themselves).
+    // Load the renderings. 
+    // To be done before displaying the verses themselves since the latter depends on the former.
     load_renderings ();
     // Write extra bits.
-    html_write_extras (htmlwriter, keyword_id);
+    html_write_keyterms (htmlwriter, keyword_id);
+    show_renderings = true;
     display_another_page = true;
   }
 
@@ -439,8 +446,23 @@ void WindowCheckKeyterms::html_link_clicked (const gchar * url)
     gtk_button_clicked(GTK_BUTTON(signal));
   }
   
+  else if (active_url.find ("send") == 0) {
+    // Send the references to the references window.
+    ustring url = active_url;
+    new_reference_showing = NULL;
+    gtk_button_clicked(GTK_BUTTON(signal));
+  }
+  
   else {
     // Give the starting page with all keyterms of the active selection.
+    show_collections = true;
+    if (collection().find ("Biblical") != string::npos) {
+      if (collection().find ("Hebrew") != string::npos) {
+        htmlwriter.paragraph_open ();
+        htmlwriter.text_add ("Key Terms in Biblical Hebrew: The entries are an experimental sample set, not yet fully reviewed and approved. The KTBH team would welcome feed-back to christopher_samuel@sil.org.");
+        htmlwriter.paragraph_close ();
+      }
+    }
     vector <ustring> terms;
     vector <unsigned int> ids;
     keyterms_get_terms("", collection(), terms, ids);
@@ -462,11 +484,31 @@ void WindowCheckKeyterms::html_link_clicked (const gchar * url)
     gtk_html_end(GTK_HTML(htmlview_terms), stream, GTK_HTML_STREAM_OK);
     // Scroll to the position that possibly was stored while this url was last active.
     gtk_adjustment_set_value (adjustment, scrolling_position[active_url]);
+    // Whether to show collections.
+    if (show_collections)
+      gtk_widget_show (hbox_collection);
+    else
+      gtk_widget_hide (hbox_collection);
+    if (show_renderings)
+      gtk_widget_show (treeview_renderings);
+    else
+      gtk_widget_hide (treeview_renderings);
   }
 }
 
 
-void WindowCheckKeyterms::html_write_extras (HtmlWriter2& htmlwriter, unsigned int keyword_id)
+void WindowCheckKeyterms::on_html_submit (GtkHTML *html, const gchar *method, const gchar *url, const gchar *encoding, gpointer user_data)
+{
+  ((WindowCheckKeyterms *) user_data)->html_submit(method, url, encoding);
+}
+
+
+void WindowCheckKeyterms::html_submit (const gchar *method, const gchar *url, const gchar *encoding)
+{
+}
+
+
+void WindowCheckKeyterms::html_write_keyterms (HtmlWriter2& htmlwriter, unsigned int keyword_id)
 {
   // Get data about the project.
   extern Settings *settings;
@@ -474,9 +516,11 @@ void WindowCheckKeyterms::html_write_extras (HtmlWriter2& htmlwriter, unsigned i
   ProjectConfiguration *projectconfig = settings->projectconfig(project);
   ustring versification = projectconfig->versification_get();
 
-  // Add a link for the index.
+  // Add action links.
   htmlwriter.paragraph_open ();
-  htmlwriter.hyperlink_add ("", "Index");
+  htmlwriter.hyperlink_add ("", "[Index]");
+  htmlwriter.text_add (" ");
+  htmlwriter.hyperlink_add ("send", "[Send to references window]");
   htmlwriter.paragraph_close ();
 
   // Add the keyterm itself.
@@ -495,7 +539,6 @@ void WindowCheckKeyterms::html_write_extras (HtmlWriter2& htmlwriter, unsigned i
   // Get the data for the keyword identifier.
   ustring dummy;
   ustring information;
-  vector <Reference> references;
   keyterms_get_data(keyword_id, dummy, information, references);
 
   // Divide the information into lines.
@@ -554,6 +597,8 @@ void WindowCheckKeyterms::html_write_extras (HtmlWriter2& htmlwriter, unsigned i
         size_t processposition = 0;
         if (find_renderings (verse, renderings, wholewords, casesensitives, &startpositions, &lengths)) {
           quick_sort (startpositions, lengths, 0, startpositions.size());
+          // Overlapping items need to be combined to avoid crashes.
+          xml_combine_overlaps (startpositions, lengths);
           for (unsigned int i = 0; i < startpositions.size(); i++) {
             htmlwriter.text_add (verse.substr (0, startpositions[i] - processposition));
             htmlwriter.bold_open();
