@@ -20,7 +20,7 @@
 #include "libraries.h"
 #include <glib.h>
 #include "windowcheckusfm.h"
-#include "window.h"
+#include "floatingwindow.h"
 #include "settings.h"
 #include "shortcuts.h"
 #include "gwrappers.h"
@@ -32,8 +32,8 @@
 #include "scripts.h"
 
 
-WindowCheckUSFM::WindowCheckUSFM(GtkAccelGroup * accelerator_group, bool startup, GtkWidget * parent_box):
-WindowBase(widCheckUSFM, "Check USFM", startup, 0, parent_box)
+WindowCheckUSFM::WindowCheckUSFM(GtkWidget * parent_layout, GtkAccelGroup *accelerator_group, bool startup):
+FloatingWindow(parent_layout, widCheckUSFM, "Check USFM", startup)
 // Window for checking USFM.
 {
   // Initialize variables.
@@ -43,13 +43,14 @@ WindowBase(widCheckUSFM, "Check USFM", startup, 0, parent_box)
   
   vbox = gtk_vbox_new (FALSE, 6);
   gtk_widget_show (vbox);
-  gtk_container_add (GTK_CONTAINER (window_vbox), vbox);
+  gtk_container_add (GTK_CONTAINER (vbox_client), vbox);
 
   checkbutton_verses_at_start = gtk_check_button_new_with_mnemonic ("Verses in raw text are at line start");
   gtk_widget_show (checkbutton_verses_at_start);
   gtk_box_pack_start (GTK_BOX (vbox), checkbutton_verses_at_start, FALSE, FALSE, 0);
   
   shortcuts.button (checkbutton_verses_at_start);
+  connect_focus_signals (checkbutton_verses_at_start);
 
   vbox_filter = gtk_vbox_new (FALSE, 0);
   gtk_widget_show (vbox_filter);
@@ -66,10 +67,14 @@ WindowBase(widCheckUSFM, "Check USFM", startup, 0, parent_box)
   gtk_widget_show (combobox_filter);
   gtk_box_pack_start (GTK_BOX (vbox_filter), combobox_filter, FALSE, FALSE, 0);
 
+  connect_focus_signals (combobox_filter);
+  
   button_filter = gtk_button_new ();
   gtk_widget_show (button_filter);
   gtk_box_pack_start (GTK_BOX (vbox_filter), button_filter, FALSE, FALSE, 0);
 
+  connect_focus_signals (button_filter);
+  
   alignment4 = gtk_alignment_new (0.5, 0.5, 0, 0);
   gtk_widget_show (alignment4);
   gtk_container_add (GTK_CONTAINER (button_filter), alignment4);
@@ -92,6 +97,8 @@ WindowBase(widCheckUSFM, "Check USFM", startup, 0, parent_box)
   gtk_widget_show (button_discover_markup);
   gtk_box_pack_start (GTK_BOX (vbox), button_discover_markup, FALSE, FALSE, 0);
 
+  connect_focus_signals (button_discover_markup);
+  
   alignment3 = gtk_alignment_new (0.5, 0.5, 0, 0);
   gtk_widget_show (alignment3);
   gtk_container_add (GTK_CONTAINER (button_discover_markup), alignment3);
@@ -130,10 +137,6 @@ WindowBase(widCheckUSFM, "Check USFM", startup, 0, parent_box)
 
   gtk_label_set_mnemonic_widget(GTK_LABEL(label_filter), combobox_filter);
 
-  g_signal_connect((gpointer) combobox_filter, "visibility-notify-event", G_CALLBACK(on_visibility_notify_event), gpointer(this));
-  g_signal_connect((gpointer) button_discover_markup, "visibility-notify-event", G_CALLBACK(on_visibility_notify_event), gpointer(this));
-  g_signal_connect((gpointer) label_information_text, "visibility-notify-event", G_CALLBACK(on_visibility_notify_event), gpointer(this));
-
   g_signal_connect ((gpointer) button_filter, "clicked", G_CALLBACK (on_button_filter_clicked), gpointer(this));
   g_signal_connect ((gpointer) button_discover_markup, "clicked", G_CALLBACK (on_button_discover_markup_clicked), gpointer(this));
   
@@ -183,6 +186,9 @@ void WindowCheckUSFM::on_button_discover_markup ()
     if (lines[i].empty())
       continue;
 
+    // Trim the line.
+    lines[i] = trim (lines[i]);
+    
     // Remove chapter markup.
     if (lines[i].find("\\c") != string::npos) {
       lines[i].clear();
@@ -231,27 +237,46 @@ void WindowCheckUSFM::on_button_discover_markup ()
     if (discoveries_passed) {
       ustring output;
       ustring number = number_in_string(lines[i]);
-      while (!number.empty()) {
-        if (!paragraph_open) {
-          output.append("\\p");
-          paragraph_open = true;
-        }
-        size_t pos = lines[i].find(number);
-        if (pos > 0) {
-          output.append(" " + lines[i].substr(0, pos));
-          lines[i].erase(0, pos);
-        }
-        output.append("\n\\v ");
-        output.append(number);
-        output.append(" ");
-        lines[i].erase(0, number.length());
-        lines[i] = trim(lines[i]);
-        number = number_in_string(lines[i]);
-        // Setting for discovering only first number in a paragraph.
-        if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (checkbutton_verses_at_start))) {
+      // Setting for having the number only at the start of the line.
+      bool treat_as_normal_paragraph = false;
+      if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (checkbutton_verses_at_start))) {
+        if (lines[i].find (number) != 0) {
           number.clear();
+          treat_as_normal_paragraph = true;
         }
       }
+      if (treat_as_normal_paragraph) {
+
+        // Normal paragraph.
+        lines[i].insert(0, "\\p ");
+
+      } else {
+
+        // Find all verse numbers.   
+        while (!number.empty()) {
+          if (!paragraph_open) {
+            output.append("\\p");
+            paragraph_open = true;
+          }
+          size_t pos = lines[i].find(number);
+          if (pos > 0) {
+            output.append(" " + lines[i].substr(0, pos));
+            lines[i].erase(0, pos);
+          }
+          output.append("\n\\v ");
+          output.append(number);
+          output.append(" ");
+          lines[i].erase(0, number.length());
+          lines[i] = trim(lines[i]);
+          number = number_in_string(lines[i]);
+          // Setting for discovering only first number in a paragraph.
+          if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (checkbutton_verses_at_start))) {
+            number.clear();
+          }
+        }
+
+      }
+      // Store line.
       output.append(lines[i]);
       lines[i] = output;
     }
