@@ -17,11 +17,12 @@
  **  
  */
 
+
 #include "libraries.h"
 #include <glib.h>
 #include "windownotes.h"
 #include "help.h"
-#include "window.h"
+#include "floatingwindow.h"
 #include "gui_features.h"
 #include "notes_utils.h"
 #include "books.h"
@@ -37,9 +38,11 @@
 #include "bible.h"
 #include "gtkwrappers.h"
 #include "dialogprojectnote.h"
+#include "dialogyesnoalways.h"
 
-WindowNotes::WindowNotes(GtkAccelGroup * accelerator_group, bool startup, GtkWidget * parent_box):
-WindowBase(widNotes, "Project notes", startup, 0, parent_box)
+
+WindowNotes::WindowNotes(GtkWidget * parent_layout, GtkAccelGroup *accelerator_group, bool startup):
+FloatingWindow(parent_layout, widNotes, "Project notes", startup)
 // Project notes window.
 {
   // Initialize variables.
@@ -47,12 +50,13 @@ WindowBase(widNotes, "Project notes", startup, 0, parent_box)
   redisplay_source_id = 0;
   displayprojectnotes = NULL;
   gui_source_id = 0;
-
+  edited_note_id = 0;
+  
   GuiFeatures guifeatures(0);
 
   notebook1 = gtk_notebook_new();
   gtk_widget_show(notebook1);
-  gtk_container_add(GTK_CONTAINER(window_vbox), notebook1);
+  gtk_container_add(GTK_CONTAINER(vbox_client), notebook1);
   gtk_notebook_set_show_tabs(GTK_NOTEBOOK(notebook1), FALSE);
 
   scrolledwindow_notes = gtk_scrolled_window_new(NULL, NULL);
@@ -65,7 +69,7 @@ WindowBase(widNotes, "Project notes", startup, 0, parent_box)
   gtk_container_add(GTK_CONTAINER(scrolledwindow_notes), htmlview_notes);
   gtk_html_allow_selection(GTK_HTML(htmlview_notes), true);
 
-  g_signal_connect((gpointer) htmlview_notes, "visibility-notify-event", G_CALLBACK(on_visibility_notify_event), gpointer(this));
+  connect_focus_signals (htmlview_notes);
 
   hbox14 = gtk_hbox_new(FALSE, 0);
   gtk_widget_show(hbox14);
@@ -238,7 +242,7 @@ WindowBase(widNotes, "Project notes", startup, 0, parent_box)
   gtk_container_add(GTK_CONTAINER(scrolledwindow_note_editor), htmlview_note_editor);
   gtk_html_allow_selection(GTK_HTML(htmlview_note_editor), true);
 
-  g_signal_connect((gpointer) htmlview_note_editor, "visibility-notify-event", G_CALLBACK(on_visibility_notify_event), gpointer(this));
+  connect_focus_signals (htmlview_note_editor);
 
   vbox_controls = gtk_vbox_new(FALSE, 0);
   gtk_widget_show(vbox_controls);
@@ -295,6 +299,8 @@ WindowBase(widNotes, "Project notes", startup, 0, parent_box)
   gtk_box_pack_start(GTK_BOX(vbox_controls), textview_note_references, TRUE, TRUE, 0);
   gtk_text_view_set_accepts_tab(GTK_TEXT_VIEW(textview_note_references), FALSE);
 
+  connect_focus_signals (textview_note_references);
+  
   g_signal_connect((gpointer) htmlview_notes, "link-clicked", G_CALLBACK(on_html_link_clicked), gpointer(this));
   g_signal_connect((gpointer) button_note_ok, "clicked", G_CALLBACK(on_button_ok_clicked), gpointer(this));
   g_signal_connect((gpointer) button_note_cancel, "clicked", G_CALLBACK(on_button_cancel_clicked), gpointer(this));
@@ -333,6 +339,7 @@ WindowBase(widNotes, "Project notes", startup, 0, parent_box)
   gtk_widget_grab_focus (last_focused_widget);
 }
 
+
 WindowNotes::~WindowNotes()
 {
   // Stop possible thread that is displaying notes.
@@ -344,11 +351,13 @@ WindowNotes::~WindowNotes()
   gtk_widget_destroy(references_available_signal_button);
 }
 
+
 void WindowNotes::go_to(Reference & reference)
 {
 
 }
 
+
 void WindowNotes::new_note()
 // Create a new note.
 {
@@ -362,6 +371,7 @@ void WindowNotes::new_note()
   notes_fill_edit_screen(id, true);
 }
 
+
 void WindowNotes::notes_fill_edit_screen(int id, bool newnote)
 /*
  When a new note is made, or an existing one edited, this function
@@ -535,22 +545,26 @@ void WindowNotes::notes_fill_edit_screen(int id, bool newnote)
   gtk_widget_grab_focus(htmlview_note_editor);
 }
 
+
 void WindowNotes::on_combobox_note_edit_font_size_changed(GtkComboBox * combobox, gpointer user_data)
 {
   ((WindowNotes *) user_data)->combobox_note_edit_font_size_changed();
 }
 
+
 void WindowNotes::combobox_note_edit_font_size_changed()
 {
   GtkHTMLFontStyle style = note_editor_font_size_name_to_enum(combobox_get_active_string(combobox_note_edit_font_size));
   gtk_html_set_font_style(GTK_HTML(htmlview_note_editor), GtkHTMLFontStyle(GTK_HTML_FONT_STYLE_SIZE_MASK & ~GTK_HTML_FONT_STYLE_SIZE_MASK), style);
 }
 
+
 void WindowNotes::on_note_editor_insertion_font_style_changed(GtkHTML * html, GtkHTMLFontStyle style, gpointer user_data)
 {
   ((WindowNotes *) user_data)->note_editor_insertion_font_style_changed(style);
 }
 
+
 void WindowNotes::note_editor_insertion_font_style_changed(GtkHTMLFontStyle style)
 {
   combobox_set_string(combobox_note_edit_font_size, note_editor_font_size_enum_to_name(GtkHTMLFontStyle(style & GTK_HTML_FONT_STYLE_SIZE_MASK)));
@@ -560,32 +574,38 @@ void WindowNotes::note_editor_insertion_font_style_changed(GtkHTMLFontStyle styl
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(togglebutton_note_edit_strike_through), style & GTK_HTML_FONT_STYLE_STRIKEOUT);
 }
 
+
 void WindowNotes::on_combobox_note_edit_paragraph_style_changed(GtkComboBox * combobox, gpointer user_data)
 {
   ((WindowNotes *) user_data)->combobox_note_edit_paragraph_style_changed();
 }
 
+
 void WindowNotes::combobox_note_edit_paragraph_style_changed()
 {
   GtkHTMLParagraphStyle style = note_editor_paragraph_style_name_to_enum(combobox_get_active_string(combobox_note_edit_paragraph_style));
   gtk_html_set_paragraph_style(GTK_HTML(htmlview_note_editor), style);
 }
 
+
 void WindowNotes::on_note_editor_current_paragraph_style_changed(GtkHTML * html, GtkHTMLParagraphStyle style, gpointer user_data)
 {
   ((WindowNotes *) user_data)->note_editor_current_paragraph_style_changed(style);
 }
 
+
 void WindowNotes::note_editor_current_paragraph_style_changed(GtkHTMLParagraphStyle style)
 {
   combobox_set_string(combobox_note_edit_paragraph_style, note_editor_paragraph_style_enum_to_name(style));
 }
 
+
 void WindowNotes::on_togglebutton_note_edit_bold_toggled(GtkToggleButton * togglebutton, gpointer user_data)
 {
   ((WindowNotes *) user_data)->togglebutton_note_edit_bold_toggled();
 }
 
+
 void WindowNotes::togglebutton_note_edit_bold_toggled()
 {
   if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton_note_edit_bold))) {
@@ -595,11 +615,13 @@ void WindowNotes::togglebutton_note_edit_bold_toggled()
   }
 }
 
+
 void WindowNotes::on_togglebutton_note_edit_italics_toggled(GtkToggleButton * togglebutton, gpointer user_data)
 {
   ((WindowNotes *) user_data)->togglebutton_note_edit_italics_toggled();
 }
 
+
 void WindowNotes::togglebutton_note_edit_italics_toggled()
 {
   if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton_note_edit_italics))) {
@@ -609,11 +631,13 @@ void WindowNotes::togglebutton_note_edit_italics_toggled()
   }
 }
 
+
 void WindowNotes::on_togglebutton_note_edit_underline_toggled(GtkToggleButton * togglebutton, gpointer user_data)
 {
   ((WindowNotes *) user_data)->togglebutton_note_edit_underline_toggled();
 }
 
+
 void WindowNotes::togglebutton_note_edit_underline_toggled()
 {
   if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton_note_edit_underline))) {
@@ -623,11 +647,13 @@ void WindowNotes::togglebutton_note_edit_underline_toggled()
   }
 }
 
+
 void WindowNotes::on_togglebutton_note_edit_strike_through_toggled(GtkToggleButton * togglebutton, gpointer user_data)
 {
   ((WindowNotes *) user_data)->togglebutton_note_edit_strike_through_toggled();
 }
 
+
 void WindowNotes::togglebutton_note_edit_strike_through_toggled()
 {
   if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton_note_edit_strike_through))) {
@@ -637,11 +663,13 @@ void WindowNotes::togglebutton_note_edit_strike_through_toggled()
   }
 }
 
+
 void WindowNotes::on_togglebutton_note_edit_left_justify_toggled(GtkToggleButton * togglebutton, gpointer user_data)
 {
   ((WindowNotes *) user_data)->togglebutton_note_edit_left_justify_toggled();
 }
 
+
 void WindowNotes::togglebutton_note_edit_left_justify_toggled()
 {
   if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton_note_edit_left_justify))) {
@@ -649,11 +677,13 @@ void WindowNotes::togglebutton_note_edit_left_justify_toggled()
   }
 }
 
+
 void WindowNotes::on_togglebutton_note_edit_center_justify_toggled(GtkToggleButton * togglebutton, gpointer user_data)
 {
   ((WindowNotes *) user_data)->togglebutton_note_edit_center_justify_toggled();
 }
 
+
 void WindowNotes::togglebutton_note_edit_center_justify_toggled()
 {
   if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton_note_edit_center_justify))) {
@@ -661,11 +691,13 @@ void WindowNotes::togglebutton_note_edit_center_justify_toggled()
   }
 }
 
+
 void WindowNotes::on_togglebutton_note_edit_right_justify_toggled(GtkToggleButton * togglebutton, gpointer user_data)
 {
   ((WindowNotes *) user_data)->togglebutton_note_edit_right_justify_toggled();
 }
 
+
 void WindowNotes::togglebutton_note_edit_right_justify_toggled()
 {
   if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton_note_edit_right_justify))) {
@@ -673,11 +705,13 @@ void WindowNotes::togglebutton_note_edit_right_justify_toggled()
   }
 }
 
+
 void WindowNotes::on_current_paragraph_alignment_changed(GtkHTML * html, GtkHTMLParagraphAlignment new_alignment, gpointer user_data)
 {
   ((WindowNotes *) user_data)->current_paragraph_alignment_changed(new_alignment);
 }
 
+
 void WindowNotes::current_paragraph_alignment_changed(GtkHTMLParagraphAlignment new_alignment)
 {
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(togglebutton_note_edit_left_justify), new_alignment == GTK_HTML_PARAGRAPH_ALIGNMENT_LEFT);
@@ -685,43 +719,53 @@ void WindowNotes::current_paragraph_alignment_changed(GtkHTMLParagraphAlignment
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(togglebutton_note_edit_right_justify), new_alignment == GTK_HTML_PARAGRAPH_ALIGNMENT_RIGHT);
 }
 
+
 void WindowNotes::on_button_note_edit_decrease_indent_clicked(GtkButton * button, gpointer user_data)
 {
-  ((WindowNotes *) user_data)->button_note_edit_decrease_indent_clicked();
+  ((WindowNotes *) user_data)->decrease_indent();
 }
 
-void WindowNotes::button_note_edit_decrease_indent_clicked()
+
+void WindowNotes::decrease_indent()
 {
-  //guint indentation = gtk_html_get_paragraph_indentation (GTK_HTML (htmlview_note_editor));
-  //if (indentation > 0)
-  gtk_html_indent_pop_level(GTK_HTML(htmlview_note_editor));
+  if (note_being_edited()) {
+    gtk_html_indent_pop_level(GTK_HTML(htmlview_note_editor));
+  }
 }
 
+
 void WindowNotes::on_button_note_edit_increase_indent_clicked(GtkButton * button, gpointer user_data)
 {
-  ((WindowNotes *) user_data)->button_note_edit_increase_indent_clicked();
+  ((WindowNotes *) user_data)->increase_indent();
 }
 
-void WindowNotes::button_note_edit_increase_indent_clicked()
+
+void WindowNotes::increase_indent()
 {
-  gtk_html_indent_push_level(GTK_HTML(htmlview_note_editor), HTML_LIST_TYPE_BLOCKQUOTE);
+  if (note_being_edited()) {
+    gtk_html_indent_push_level(GTK_HTML(htmlview_note_editor), HTML_LIST_TYPE_BLOCKQUOTE);
+  }
 }
 
+
 void WindowNotes::on_current_paragraph_indentation_changed(GtkHTML * html, guint new_indentation, gpointer user_data)
 {
   ((WindowNotes *) user_data)->current_paragraph_indentation_changed(new_indentation);
 }
 
+
 void WindowNotes::current_paragraph_indentation_changed(guint new_indentation)
 {
   gtk_widget_set_sensitive(toolitem_note_edit_decrease_indent, new_indentation > 0);
 }
 
+
 void WindowNotes::on_colorbutton_note_edit_color_set(GtkColorButton * colorbutton, gpointer user_data)
 {
   ((WindowNotes *) user_data)->colorbutton_note_edit_color_set(colorbutton);
 }
 
+
 void WindowNotes::colorbutton_note_edit_color_set(GtkColorButton * colorbutton)
 {
   GdkColor gdk_color;
@@ -731,16 +775,19 @@ void WindowNotes::colorbutton_note_edit_color_set(GtkColorButton * colorbutton)
   html_color_unref(html_color);
 }
 
+
 void WindowNotes::on_insertion_color_changed(GtkHTML * html, GdkColor * color, gpointer user_data)
 {
   ((WindowNotes *) user_data)->insertion_color_changed(color);
 }
 
+
 void WindowNotes::insertion_color_changed(GdkColor * color)
 {
   gtk_color_button_set_color(GTK_COLOR_BUTTON(colorbutton_note_edit), color);
 }
 
+
 void WindowNotes::redisplay()
 {
   // Do not display notes while a note is being edited.
@@ -753,21 +800,24 @@ void WindowNotes::redisplay()
   redisplay_source_id = g_timeout_add_full(G_PRIORITY_DEFAULT, 500, GSourceFunc(on_redisplay_timeout), gpointer(this), NULL);
 }
 
+
 bool WindowNotes::on_redisplay_timeout(gpointer data)
 {
   ((WindowNotes *) data)->redisplay_timeout();
   return false;
 }
 
+
 void WindowNotes::redisplay_timeout()
 {
   // Get actual verse from the settings.
   extern Settings *settings;
   ustring reference = books_id_to_english(settings->genconfig.book_get()) + " " + settings->genconfig.chapter_get() + ":" + settings->genconfig.verse_get();
   // Create displaying object.
-  displayprojectnotes = new DisplayProjectNotes(reference, htmlview_notes, NULL);
+  displayprojectnotes = new DisplayProjectNotes(reference, htmlview_notes, NULL, edited_note_id);
 }
 
+
 void WindowNotes::stop_displaying_more_notes()
 // Stop the process of displaying notes.
 {
@@ -784,12 +834,14 @@ void WindowNotes::stop_displaying_more_notes()
   }
 }
 
+
 bool WindowNotes::on_gui_timeout(gpointer data)
 {
   ((WindowNotes *) data)->on_gui();
   return true;
 }
 
+
 void WindowNotes::on_gui()
 // Tasks related to the GUI.
 {
@@ -808,28 +860,33 @@ void WindowNotes::on_gui()
   }
 }
 
+
 void WindowNotes::display(vector < unsigned int >&ids)
 {
   stop_displaying_more_notes();
-  displayprojectnotes = new DisplayProjectNotes("", htmlview_notes, &ids);
+  displayprojectnotes = new DisplayProjectNotes("", htmlview_notes, &ids, edited_note_id);
 }
 
+
 void WindowNotes::on_button_cancel_clicked(GtkButton * button, gpointer user_data)
 {
   ((WindowNotes *) user_data)->on_notes_button_cancel();
 }
 
+
 void WindowNotes::on_notes_button_cancel()
 {
   // Do standard functions for both ok and cancel.
   on_notes_button_ok_cancel();
 }
 
+
 void WindowNotes::on_button_ok_clicked(GtkButton * button, gpointer user_data)
 {
   ((WindowNotes *) user_data)->on_notes_button_ok();
 }
 
+
 void WindowNotes::on_notes_button_ok()
 {
   sqlite3 *db;
@@ -878,12 +935,12 @@ void WindowNotes::on_notes_button_ok()
           message.append(messages[i]);
           message.append("\n");
         }
-        gtkw_dialog_error(window_vbox, message);
+        gtkw_dialog_error(vbox_client, message);
       }
     }
     // See whether any references are left. If not give a message.
     if (encoded_references.empty()) {
-      gtkw_dialog_error(window_vbox, "No valid references. Note was not stored");
+      gtkw_dialog_error(vbox_client, "No valid references. Note was not stored");
       return;
     }
     // Connect to database and start transaction.
@@ -904,7 +961,7 @@ void WindowNotes::on_notes_button_ok()
       throw runtime_error(error);
     }
     // Put new data in the database.
-    // ID (integer), we take variable "myid"
+    // ID (integer),
     // References (text), we take variable "encoded_references"
     // Project (text) - done already.    
     // Status (integer) This field is not used, and could be reused.
@@ -981,6 +1038,11 @@ void WindowNotes::on_notes_button_ok()
     if (rc != SQLITE_OK) {
       throw runtime_error(error);
     }
+    // Store the note's id, so that this note can be displayed even if it normally would not have displayed.
+    // The reason is that if a user edits a note, then clicks OK to store it, then it would disappear,
+    // then the user would wonder where that note went, whether he cancelled it by mistake. 
+    // For that reason the id of this note is stored, so that when displaying notes, this id should display as well.
+    edited_note_id = note_editor->id;
   }
   catch(exception & ex) {
     gw_critical(ex.what());
@@ -991,6 +1053,7 @@ void WindowNotes::on_notes_button_ok()
   on_notes_button_ok_cancel();
 }
 
+
 void WindowNotes::on_notes_button_ok_cancel()
 // Functions common to both the ok and cancel buttons.
 {
@@ -1012,9 +1075,9 @@ void WindowNotes::on_notes_button_ok_cancel()
 
   // Just to be sure, redisplay the notes.
   redisplay();
-
 }
 
+
 gboolean WindowNotes::note_save_receiver(const HTMLEngine * engine, const char *data, unsigned int len, void *user_data)
 // Called by the gtkhtml project note editor when saving its data
 {
@@ -1022,6 +1085,7 @@ gboolean WindowNotes::note_save_receiver(const HTMLEngine * engine, const char *
   return true;
 }
 
+
 void WindowNotes::insert_standard_text(unsigned int selector)
 // Sets the system to insert standard text into the note.
 {
@@ -1094,12 +1158,14 @@ void WindowNotes::insert_standard_text(unsigned int selector)
   }
 }
 
+
 void WindowNotes::get_references_from_note(vector < Reference > &references, vector < ustring > &messages)
 {
   if (note_editor)
     notes_get_references_from_editor(note_editor->textbuffer_references, references, messages);
 }
 
+
 void WindowNotes::get_references_from_id(gint id)
 // Get the references from the note id
 {
@@ -1143,12 +1209,14 @@ void WindowNotes::get_references_from_id(gint id)
   gtk_button_clicked(GTK_BUTTON(references_available_signal_button));
 }
 
+
 gboolean WindowNotes::on_html_link_clicked(GtkHTML * html, const gchar * url, gpointer user_data)
 {
   ((WindowNotes *) user_data)->html_link_clicked(html, url);
   return true;
 }
 
+
 void WindowNotes::html_link_clicked(GtkHTML * html, const gchar * url)
 // Callback for clicking a link in the project notes.
 {
@@ -1171,6 +1239,7 @@ void WindowNotes::html_link_clicked(GtkHTML * html, const gchar * url)
   }
 }
 
+
 void WindowNotes::delete_ids(const vector < gint > &ids)
 // Deletes notes whose id is given in "ids".
 {
@@ -1183,8 +1252,7 @@ void WindowNotes::delete_ids(const vector < gint > &ids)
   else
     message.append("these notes");
   message.append("?");
-
-  if (gtkw_dialog_question(GTK_IS_WINDOW (window_vbox) ? window_vbox : NULL, message) != GTK_RESPONSE_YES)
+  if (!yes_no_always_dialog (message, ynadtDeleteNote, true, false))
     return;
   for (unsigned int i = 0; i < ids.size(); i++) {
     notes_delete_one(ids[i]);
@@ -1193,29 +1261,28 @@ void WindowNotes::delete_ids(const vector < gint > &ids)
   redisplay();
 }
 
+
 void WindowNotes::cut()
 {
   // Cut to clipboard if editing.
   if (note_being_edited()) {
-    GtkWidget *focused_widget = gtk_window_get_focus(GTK_WINDOW(window_vbox));
-    if (focused_widget == htmlview_note_editor)
+    if (last_focused_widget == htmlview_note_editor)
       gtk_html_cut(GTK_HTML(htmlview_note_editor));
-    if (focused_widget == textview_note_references) {
+    if (last_focused_widget == textview_note_references) {
       GtkClipboard *clipboard = gtk_clipboard_get(GDK_SELECTION_CLIPBOARD);
       gtk_text_buffer_cut_clipboard(note_editor->textbuffer_references, clipboard, true);
     }
   }
 }
 
+
 void WindowNotes::copy()
 {
   // Copy to clipboard.
   if (note_being_edited()) {
-
-    GtkWidget *focused_widget = gtk_window_get_focus(GTK_WINDOW(window_vbox));
-    if (focused_widget == htmlview_note_editor)
+    if (last_focused_widget == htmlview_note_editor)
       gtk_html_copy(GTK_HTML(htmlview_note_editor));
-    if (focused_widget == textview_note_references) {
+    if (last_focused_widget == textview_note_references) {
       GtkClipboard *clipboard = gtk_clipboard_get(GDK_SELECTION_CLIPBOARD);
       gtk_text_buffer_copy_clipboard(note_editor->textbuffer_references, clipboard);
     }
@@ -1224,20 +1291,21 @@ void WindowNotes::copy()
   }
 }
 
+
 void WindowNotes::paste()
 {
   // Paste from clipboard if editing.
   if (note_being_edited()) {
-    GtkWidget *focused_widget = gtk_window_get_focus(GTK_WINDOW(window_vbox));
-    if (focused_widget == htmlview_note_editor)
+    if (last_focused_widget == htmlview_note_editor)
       gtk_html_paste(GTK_HTML(htmlview_note_editor), false);
-    if (focused_widget == textview_note_references) {
+    if (last_focused_widget == textview_note_references) {
       GtkClipboard *clipboard = gtk_clipboard_get(GDK_SELECTION_CLIPBOARD);
       gtk_text_buffer_paste_clipboard(note_editor->textbuffer_references, clipboard, NULL, true);
     }
   }
 }
 
+
 void WindowNotes::undo()
 {
   // Undo if editing.
@@ -1246,6 +1314,7 @@ void WindowNotes::undo()
   }
 }
 
+
 void WindowNotes::redo()
 {
   if (note_being_edited()) {
@@ -1253,21 +1322,25 @@ void WindowNotes::redo()
   }
 }
 
+
 bool WindowNotes::note_being_edited()
 // Returns whether a note is now being edited.
 {
   return (gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook1)) > 0);
 }
 
+
 void WindowNotes::on_button_more_clicked(GtkButton * button, gpointer user_data)
 {
   ((WindowNotes *) user_data)->on_button_more();
 }
 
+
 void WindowNotes::on_button_more()
 {
-  ProjectNoteDialog dialog(window_vbox, projects, project, created_on, created_by, edited_on, logbook);
+  ProjectNoteDialog dialog(vbox_client, projects, project, created_on, created_by, edited_on, logbook);
   if (dialog.run() == GTK_RESPONSE_OK) {
     project = dialog.project;
   }
 }
+
