@@ -17,19 +17,22 @@
  **  
  */
 
+
 #ifndef INCLUDED_WINDOW_OUTLINE_H
 #define INCLUDED_WINDOW_OUTLINE_H
 
+
 #include <gtk/gtk.h>
 #include "ustring.h"
 #include "reference.h"
-#include "window.h"
+#include "floatingwindow.h"
 #include "outline.h"
 
-class WindowOutline : public WindowBase
+
+class WindowOutline : public FloatingWindow
 {
 public:
-  WindowOutline(GtkAccelGroup *accelerator_group, bool startup, GtkWidget * parent_box);
+  WindowOutline(GtkWidget * parent_layout, GtkAccelGroup *accelerator_group, bool startup);
   virtual ~WindowOutline();
   void go_to(const ustring& project, Reference& reference);
   Outline * outline;
@@ -39,4 +42,5 @@ private:
   Reference myreference;
 };
 
+
 #endif
