@@ -17,6 +17,7 @@
  **  
  */
 
+
 #include "libraries.h"
 #include "utilities.h"
 #include "windowsoutpost.h"
@@ -29,6 +30,10 @@
 #include "books.h"
 #include "settings.h"
 #include "tiny_utilities.h"
+#include "bibleworks.h"
+#include "directories.h"
+#include "onlinebible.h"
+
 
 #define STAGE_ZERO 0
 #define STAGE_START 1
@@ -37,6 +42,7 @@
 #define STAGE_WAIT_RETRY 1000
 #define STAGE_RETRY 1600
 
+
 WindowsOutpost::WindowsOutpost(bool dummy)
 /*
  This controls a Bibledit Windows Outpost program.
@@ -47,10 +53,14 @@ WindowsOutpost::WindowsOutpost(bool dummy)
   sock = 0;
   clear();
   thread_running = false;
+  online_bible_server_requested_action = 0;
+  online_bible_server_connected = false;
 }
 
+
 WindowsOutpost::~WindowsOutpost()
 {
+  online_bible_server_connect (false);
   // Disconnect.
   disconnect();
   // Indicate to the thread we want to stop.
@@ -60,6 +70,7 @@ WindowsOutpost::~WindowsOutpost()
     g_usleep(10000);
 }
 
+
 void WindowsOutpost::Start()
 // This effectually starts the whole system.
 {
@@ -67,6 +78,17 @@ void WindowsOutpost::Start()
   g_thread_create(GThreadFunc(thread_start), gpointer(this), false, NULL);
 }
 
+
+ustring WindowsOutpost::BibleWorksReferenceGet()
+// Gets the reference from BibleWorks.
+{
+  // Store command for retrieving the reference.
+  get_reference_command = "BibleWorksReferenceGet";
+  // Return the reply that was given previously.
+  return get_reference_reply;
+}
+
+
 void WindowsOutpost::BibleWorksReferenceSet(const Reference & reference)
 // Schedules a reference to be sent to BibleWorks.
 {
@@ -85,6 +107,17 @@ void WindowsOutpost::BibleWorksReferenceSet(const Reference & reference)
   bibleworks_reference_set_value = "BibleWorksReferenceSet " + bw_book + " " + convert_to_string(goto_ch) + ":" + goto_vs;
 }
 
+
+ustring WindowsOutpost::SantaFeFocusReferenceGet()
+// Gets the reference from the SantaFe focus sharing system as used by Paratext and others.
+{
+  // Store command for retrieving the reference.
+  get_reference_command = "SantaFeFocusReferenceGet";
+  // Return the reply that was given previously.
+  return get_reference_reply;
+}
+
+
 void WindowsOutpost::SantaFeFocusReferenceSet(const Reference & reference)
 // Schedules a reference to be sent to the santa fe focus system.
 {
@@ -96,12 +129,45 @@ void WindowsOutpost::SantaFeFocusReferenceSet(const Reference & reference)
   santafefocus_reference_set_value = "SantaFeFocusReferenceSet " + bk + " " + convert_to_string(reference.chapter) + ":" + reference.verse;
 }
 
+
 void WindowsOutpost::SantaFeFocusWordSet(const ustring & word)
 // Schedules a word to be sent to the santa fe focus system.
 {
   santafefocus_word_set_value = "SantaFeFocusWordSet " + word;
 }
 
+
+void WindowsOutpost::OnlineBibleReferenceSet(const Reference & reference)
+// Schedules a reference to be sent to the Online Bible.
+// Sample: 
+// OLB ShowPassage AV "Mt 10:5"
+{
+  // Ensure that the Online Bible server is connected.
+  online_bible_server_connect (true);
+
+  // Send the references.
+  if (!reference.book)
+    return;
+  if (!reference.chapter)
+    return;
+  if (reference.verse.empty())
+    return;
+  onlinebible_reference_set_value = "OLB ShowPassage AV \"" + books_id_to_online_bible (reference.book) + " " + convert_to_string(reference.chapter) + ":" + reference.verse + "\"";
+}
+
+
+ustring WindowsOutpost::OnlineBibleReferenceGet()
+// Gets the reference from the Online Bible.
+{
+  // Ensure that the Online Bible server is connected.
+  online_bible_server_connect (true);
+  // Store command for retrieving the reference.
+  get_reference_command = "OLB GetPassage";
+  // Return the reply that was given previously.
+  return get_reference_reply;
+}
+
+
 void WindowsOutpost::clear()
 {
   disconnect();
@@ -109,11 +175,13 @@ void WindowsOutpost::clear()
   connected = false;
 }
 
+
 void WindowsOutpost::thread_start(gpointer data)
 {
   ((WindowsOutpost *) data)->thread_main();
 }
 
+
 void WindowsOutpost::thread_main()
 {
   extern Settings *settings;
@@ -134,11 +202,11 @@ void WindowsOutpost::thread_main()
           break;
         }
         // Start Outpost if it does not already run.
-        if (!program_is_running(BIBLEDIT_WINDOWS_OUTPOST)) {
+        if (!program_is_running(BIBLEDIT_WINDOWS_OUTPOST_EXE)) {
           // Windows? Or Unix?
           if (uname_get() == untWindows) {
             // We run in Windows: start Outpost and wait a few seconds till started. 
-            GwSpawn spawn("bwoutpost.exe");
+            GwSpawn spawn(BIBLEDIT_WINDOWS_OUTPOST_EXE);
             spawn.async();
             spawn.run();
             g_usleep(3000000);
@@ -147,7 +215,7 @@ void WindowsOutpost::thread_main()
             // Is wine there?
             if (gw_find_program_in_path(settings->genconfig.wine_path_get())) {
               ustring command = settings->genconfig.outpost_command_get() + " &";
-              if (system(command.c_str())) ;
+              if (system(command.c_str())) ; // This one is too unpredictable to use GwSpawn.
               // Wait few seconds to give it a chance to start.
               g_usleep(3000000);
             } else {
@@ -156,10 +224,11 @@ void WindowsOutpost::thread_main()
           }
         }
         // Decide on next stage.
-        if (program_is_running(BIBLEDIT_WINDOWS_OUTPOST))
+        if (program_is_running(BIBLEDIT_WINDOWS_OUTPOST_EXE)) {
           stage = STAGE_CONNECT;
-        else
+        } else {
           stage = STAGE_WAIT_RETRY;
+        }
         break;
       }
     case STAGE_CONNECT:
@@ -178,32 +247,73 @@ void WindowsOutpost::thread_main()
     case STAGE_COMMUNICATE:
       {
         // Carry out the scheduled tasks.
-        // If BibleWorks does not run, and Outpost tries to contact it, it 
-        // crashes in Wine and becomes unusable. Therefore always check whether
-        // BibleWorks runs.
-        if (!bibleworks_reference_set_value.empty()) {
-          if (program_is_running(settings->genconfig.bibleworks_executable_get()) || settings->genconfig.outpost_networked_get()) {
-            ustring line(bibleworks_reference_set_value);
-            bibleworks_reference_set_value.clear();
-            send_line(line);
+        // Whether the Online Bible server should be connected to.
+        if (online_bible_server_requested_action != 0) {
+          if (online_bible_server_requested_action) {
+            // There is a request to connect to the Online Bible server.
+            if (!online_bible_server_connected) {
+              if (online_bible_is_running () || settings->genconfig.outpost_networked_get()) {
+                send_line("OLB Connect");
+                log (Readln ());
+                online_bible_server_connected = true;
+              }
+            }
+          } else {
+            // There is a request to disconnect from the Online Bible server.
+            if (online_bible_server_connected) {
+              if (online_bible_is_running () || settings->genconfig.outpost_networked_get()) {
+                send_line("OLB Disconnect");
+              }
+            }
+            // Since the Online Bible may have been shutdown, it will always be disconnected.
+            online_bible_server_connected = false;
           }
+          // Requested action handled.
+          online_bible_server_requested_action = 0;
+          break;
+        }
+        if (!bibleworks_reference_set_value.empty()) {
+          // Make a quick copy of the value, so that if the value is set again during the time
+          // it takes to send this to BibleWorks, the new value will be kept for next time.
+          ustring value (bibleworks_reference_set_value);
+          bibleworks_reference_set_value.clear();
+          // If BibleWorks does not run, and Outpost tries to contact it, it 
+          // crashes in Wine and becomes unusable. Therefore check whether BibleWorks runs.
+          if (bibleworks_is_running () || settings->genconfig.outpost_networked_get()) {
+            send_line(value);
+          }
+          break;
         }
         if (!santafefocus_reference_set_value.empty()) {
-          ustring line(santafefocus_reference_set_value);
+          ustring value (santafefocus_reference_set_value);
           santafefocus_reference_set_value.clear();
-          send_line(line);
+          send_line(value);
+          break;
         }
         if (!santafefocus_word_set_value.empty()) {
-          ustring line(santafefocus_word_set_value);
+          ustring value (santafefocus_word_set_value);
           santafefocus_word_set_value.clear();
-          send_line(line);
+          send_line(value);
+          break;
+        }
+        if (!onlinebible_reference_set_value.empty()) {
+          ustring value (onlinebible_reference_set_value);
+          onlinebible_reference_set_value.clear();
+          bool online_bible_runs = online_bible_is_running () || settings->genconfig.outpost_networked_get();
+          if (online_bible_runs) {
+            if (online_bible_server_connected) {
+              send_line (value);
+            }
+          } else {
+            online_bible_server_connected = false;
+          }
+          break;
+        }
+        if (!get_reference_command.empty()) {
+          send_line (get_reference_command);
+          get_reference_command.clear();
+          get_reference_reply = Readln ();
         }
-        /*
-           Later: 
-           The status of the other programs needs to be collected regularly, e.g. 
-           every second, so that the current reference is immediately available on 
-           request.
-         */
         break;
       }
     case STAGE_WAIT_RETRY:
@@ -226,6 +336,7 @@ void WindowsOutpost::thread_main()
   thread_running = false;
 }
 
+
 void WindowsOutpost::disconnect()
 {
   if (sock) {
@@ -246,6 +357,7 @@ void WindowsOutpost::disconnect()
   sock = 0;
 }
 
+
 void WindowsOutpost::telnet(const ustring & hostname)
 {
   // If the computer address can be converted to an IP, do so. 
@@ -281,28 +393,13 @@ void WindowsOutpost::telnet(const ustring & hostname)
       } else {
         // We've a connection. Set the socket to non-blocking mode.
 #ifdef WIN32
-	u_long socketmode = 1; // Set non-blocking
-	ioctlsocket(sock, FIONBIO, &socketmode);
+        u_long socketmode = 1; // Set non-blocking
+        ioctlsocket(sock, FIONBIO, &socketmode);
 #else
         fcntl(sock, F_SETFL, fcntl(sock, F_GETFL, 0) | O_NONBLOCK);
 #endif
         log("Connected");
         connected = true;
-        // Hide GUI.
-        send_line("hide");
-        // Check for the right version number.
-        send_line("version");
-        ustring s;
-        s = Readln();
-        if (connected) {
-          if (s.length() > 5) {
-            s = s.substr(3, 100);
-            if (s != BIBLEDIT_WINDOWS_OUTPOST_VERSION) {
-              log("Version is " + s + ", but " + BIBLEDIT_WINDOWS_OUTPOST_VERSION + " is needed");
-              log("Running with reduced fuctionality");
-            }
-          }
-        }
       }
     } else {
       log("No socket available");
@@ -313,6 +410,7 @@ void WindowsOutpost::telnet(const ustring & hostname)
   }
 }
 
+
 void WindowsOutpost::log(const ustring & message)
 // Logs messages. 
 // It does not output the same message repeatedly.
@@ -323,6 +421,7 @@ void WindowsOutpost::log(const ustring & message)
   }
 }
 
+
 void WindowsOutpost::send_line(const ustring & command)
 // Sends "command" to the windows outpost.
 {
@@ -352,6 +451,7 @@ void WindowsOutpost::send_line(const ustring & command)
   }
 }
 
+
 ustring WindowsOutpost::Readln()
 /*
  Receives a line from the windows outpost.
@@ -387,6 +487,19 @@ ustring WindowsOutpost::Readln()
   return "";
 }
 
+
+void WindowsOutpost::online_bible_server_connect (bool connect)
+{
+  if (connect == online_bible_server_connected)
+    return;
+  if (connect) {
+    online_bible_server_requested_action = 1;
+  } else {
+    online_bible_server_requested_action = -1;
+  }
+}
+
+
 void windowsoutpost_open_url(const ustring & url)
 // This function supposes that the Bibledit Windows Outpost already runs.
 // It commands the outpost to open "url", a .pdf file or .html, etc.
@@ -440,6 +553,7 @@ void windowsoutpost_open_url(const ustring & url)
   }
 }
 
+
 bool windowsoutpost_telnet(const ustring & hostname)
 // This makes a connection with the Outpost on "host" and then disconnects again.
 // It returns true if this worked out.
@@ -480,8 +594,18 @@ bool windowsoutpost_telnet(const ustring & hostname)
   return success;
 }
 
-// Below are some files that show how the SantaFeFocus system works. They were sent
-// to me by Nathan Miles, Paratext programmer.
+
+ustring windowsoutpost_path ()
+// Gives the full path to the bwoutpost.exe
+{
+  ustring path;
+  path = gw_build_filename (directories_get_package_data (), BIBLEDIT_WINDOWS_OUTPOST_EXE);
+  return path;
+}
+
+
+// Below are some files that show how the SantaFeFocus system works. 
+// They were kindly sent to me by Nathan Miles, Paratext programmer.
 
 // File SFFocus.ctl
 /*
@@ -1004,3 +1128,4 @@ bool windowsoutpost_telnet(const ustring & hostname)
 // Make the dialog smaller: no outpost selection, no wine selection, in win32
 // Default is off, and on Windows don't use the outpost to start pdf and html, but use the "start" 
 // function from mingw.
+
