@@ -17,9 +17,11 @@
  **  
  */
 
+
 #ifndef INCLUDED_WINDOWSOUTPOST_H
 #define INCLUDED_WINDOWSOUTPOST_H
 
+
 #include "libraries.h"
 #ifndef WIN32
 #include <arpa/inet.h>
@@ -32,9 +34,9 @@
 #include <stdio.h>
 #include "reference.h"
 
-#define BIBLEDIT_WINDOWS_OUTPOST "bwoutpost"
+
 #define BIBLEDIT_WINDOWS_OUTPOST_EXE "bwoutpost.exe"
-#define BIBLEDIT_WINDOWS_OUTPOST_VERSION "1.6"
+
 
 class WindowsOutpost
 {
@@ -42,9 +44,13 @@ public:
   WindowsOutpost(bool dummy);
   ~WindowsOutpost();
   void Start();
+  ustring BibleWorksReferenceGet ();
   void BibleWorksReferenceSet(const Reference& reference);
+  ustring SantaFeFocusReferenceGet ();
   void SantaFeFocusReferenceSet(const Reference& reference);
   void SantaFeFocusWordSet(const ustring& word);
+  void OnlineBibleReferenceSet (const Reference& reference);
+  ustring OnlineBibleReferenceGet ();
 private:
   struct sockaddr_in address;
   struct in_addr inaddr;
@@ -66,9 +72,18 @@ private:
   ustring bibleworks_reference_set_value;
   ustring santafefocus_reference_set_value;
   ustring santafefocus_word_set_value;
+  void online_bible_server_connect (bool connect);
+  int online_bible_server_requested_action;
+  bool online_bible_server_connected;
+  ustring onlinebible_reference_set_value;
+  ustring get_reference_command;
+  ustring get_reference_reply;
 };
 
+
 void windowsoutpost_open_url(const ustring& url);
 bool windowsoutpost_telnet(const ustring& hostname);
+ustring windowsoutpost_path ();
+
 
 #endif
