@@ -17,11 +17,12 @@
  **  
  */
 
+
 #include "libraries.h"
 #include <glib.h>
 #include "windowstyles.h"
 #include "help.h"
-#include "window.h"
+#include "floatingwindow.h"
 #include "tiny_utilities.h"
 #include "utilities.h"
 #include "combobox.h"
@@ -39,8 +40,9 @@
 #include "gwrappers.h"
 #include "styles.h"
 
-WindowStyles::WindowStyles(GtkAccelGroup * accelerator_group, bool startup, GtkWidget * stl, GtkWidget * stl_menu, GtkWidget * stl_expand_all, GtkWidget * stl_collapse_all, GtkWidget * stl_insert, GtkWidget * stl_edit_mode, GtkWidget * stl_new, GtkWidget * stl_properties, GtkWidget * stl_delete, GtkWidget * stlsheet_switch, GtkWidget * stlsheet_new, GtkWidget * stlsheet_delete, GtkWidget * stlsheet_rename, GtkWidget * stlsheet_import, GtkWidget * parent_box):
-WindowBase(widStyles, "Stylesheet", startup, 0, parent_box)
+
+WindowStyles::WindowStyles(GtkWidget * parent_layout, GtkAccelGroup *accelerator_group, bool startup, GtkWidget *stl, GtkWidget *stl_menu, GtkWidget *stl_expand_all, GtkWidget *stl_collapse_all, GtkWidget *stl_insert, GtkWidget *stl_edit_mode, GtkWidget *stl_new, GtkWidget *stl_properties, GtkWidget *stl_delete, GtkWidget *stlsheet_switch, GtkWidget *stlsheet_new, GtkWidget *stlsheet_delete, GtkWidget *stlsheet_rename):
+FloatingWindow(parent_layout, widStyles, "Stylesheet", startup)
 // Styles window.
 {
   // Variables.
@@ -57,7 +59,6 @@ WindowBase(widStyles, "Stylesheet", startup, 0, parent_box)
   stylesheet_new = stlsheet_new;
   stylesheet_remove = stlsheet_delete;
   stylesheet_rename = stlsheet_rename;
-  stylesheet_import1 = stlsheet_import;
 
   // Signalling buttons.
   apply_signal = gtk_button_new();
@@ -67,7 +68,7 @@ WindowBase(widStyles, "Stylesheet", startup, 0, parent_box)
   // GUI proper.
   vbox = gtk_vbox_new(FALSE, 0);
   gtk_widget_show(vbox);
-  gtk_container_add(GTK_CONTAINER(window_vbox), vbox);
+  gtk_container_add(GTK_CONTAINER(vbox_client), vbox);
 
   scrolledwindow = gtk_scrolled_window_new(NULL, NULL);
   gtk_widget_show(scrolledwindow);
@@ -81,7 +82,7 @@ WindowBase(widStyles, "Stylesheet", startup, 0, parent_box)
   gtk_container_add(GTK_CONTAINER(scrolledwindow), treeview);
   gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(treeview), false);
 
-  g_signal_connect((gpointer) treeview, "visibility-notify-event", G_CALLBACK(on_visibility_notify_event), gpointer(this));
+  connect_focus_signals (treeview);
 
   GtkCellRenderer *renderer = gtk_cell_renderer_text_new();
 
@@ -102,7 +103,6 @@ WindowBase(widStyles, "Stylesheet", startup, 0, parent_box)
   new_stylesheet_handler_id = 0;
   delete_stylesheet_handler_id = 0;
   rename_stylesheet_handler_id = 0;
-  import_stylesheet_handler_id = 0;
   if (style)
     styles_menu_handler_id = g_signal_connect((gpointer) style, "activate", G_CALLBACK(on_style_menu_activate), gpointer(this));
   if (style_expand_all)
@@ -125,8 +125,6 @@ WindowBase(widStyles, "Stylesheet", startup, 0, parent_box)
     delete_stylesheet_handler_id = g_signal_connect((gpointer) stylesheet_remove, "activate", G_CALLBACK(on_stylesheet_delete_activate), gpointer(this));
   if (stylesheet_rename)
     rename_stylesheet_handler_id = g_signal_connect((gpointer) stylesheet_rename, "activate", G_CALLBACK(on_stylesheet_rename_activate), gpointer(this));
-  if (stylesheet_import1)
-    import_stylesheet_handler_id = g_signal_connect((gpointer) stylesheet_import1, "activate", G_CALLBACK(on_stylesheet_import_activate), gpointer(this));
 
   g_signal_connect((gpointer) treeview, "key_press_event", G_CALLBACK(on_key_press_event), gpointer(this));
   g_signal_connect((gpointer) treeview, "button_press_event", G_CALLBACK(on_button_press_event), gpointer(this));
@@ -150,6 +148,7 @@ WindowBase(widStyles, "Stylesheet", startup, 0, parent_box)
   gtk_widget_grab_focus (last_focused_widget);
 }
 
+
 WindowStyles::~WindowStyles()
 {
   // Save the expanded states to the configuration.
@@ -184,37 +183,33 @@ WindowStyles::~WindowStyles()
     g_signal_handler_disconnect((gpointer) stylesheet_remove, delete_stylesheet_handler_id);
   if (rename_stylesheet_handler_id)
     g_signal_handler_disconnect((gpointer) stylesheet_rename, rename_stylesheet_handler_id);
-  if (import_stylesheet_handler_id)
-    g_signal_handler_disconnect((gpointer) stylesheet_import1, import_stylesheet_handler_id);
 }
 
+
 void WindowStyles::load(const ustring & stylesheet)
 {
   // Only load a new sheet if there's a change.
   if (stylesheet == mystylesheet)
     return;
-  // If there was al stylesheet, save its usage data.
+  // If there was a previous stylesheet, save its usage data.
   if (!mystylesheet.empty())
     store_recently_used_data();
   // Save new sheet
   mystylesheet = stylesheet;
   // The actual loading is done with a delay, to make it easier for Gtk.
   g_timeout_add(500, GSourceFunc(on_load_timeout), gpointer(this));
-  // Set the title.
-  ustring title = window_data + " " + stylesheet;
-  if (hbox_title) {
-    gtk_progress_bar_set_text(GTK_PROGRESS_BAR(progressbar_title), title.c_str());
-  } else {
-    gtk_window_set_title(GTK_WINDOW(window_vbox), title.c_str());
-  }
+  // Set the name of the sheet.
+  status1 (mystylesheet);
 }
 
+
 bool WindowStyles::on_load_timeout(gpointer data)
 {
   ((WindowStyles *) data)->reload();
   return false;
 }
 
+
 void WindowStyles::reload()
 {
   // If no sheet, bail out.
@@ -239,6 +234,7 @@ void WindowStyles::reload()
   load_stylesheet();
 }
 
+
 gboolean WindowStyles::on_key_press_event(GtkWidget * widget, GdkEventKey * event, gpointer user_data)
 {
   // Pressing Delete deletes the selected style(s).
@@ -259,11 +255,13 @@ gboolean WindowStyles::on_key_press_event(GtkWidget * widget, GdkEventKey * even
   return FALSE;
 }
 
+
 gboolean WindowStyles::on_button_press_event(GtkWidget * widget, GdkEventButton * event, gpointer user_data)
 {
   return ((WindowStyles *) user_data)->on_button_press(widget, event);
 }
 
+
 bool WindowStyles::on_button_press(GtkWidget * widget, GdkEventButton * event)
 {
   // Double-clicking a style if edit mode is on, edits it.
@@ -282,6 +280,7 @@ bool WindowStyles::on_button_press(GtkWidget * widget, GdkEventButton * event)
   return false;
 }
 
+
 gboolean WindowStyles::on_popup_menu(GtkWidget * widget, gpointer user_data)
 {
   ((WindowStyles *) user_data)->popup_menu(widget);
@@ -289,22 +288,26 @@ gboolean WindowStyles::on_popup_menu(GtkWidget * widget, gpointer user_data)
   return true;
 }
 
+
 void WindowStyles::popup_menu(GtkWidget * widget)
 // Keyboard popup menu handler.
 {
   show_styles_popup_menu(treeview, NULL);
 }
 
+
 void WindowStyles::on_treeview_styles_row_collapsed(GtkTreeView * treeview, GtkTreeIter * iter, GtkTreePath * path, gpointer user_data)
 {
   ((WindowStyles *) user_data)->on_treeview_styles_collapsed_expanded(iter, path, false);
 }
 
+
 void WindowStyles::on_treeview_styles_row_expanded(GtkTreeView * treeview, GtkTreeIter * iter, GtkTreePath * path, gpointer user_data)
 {
   ((WindowStyles *) user_data)->on_treeview_styles_collapsed_expanded(iter, path, true);
 }
 
+
 void WindowStyles::on_treeview_styles_collapsed_expanded(GtkTreeIter * iter, GtkTreePath * path, bool expand)
 {
   // Get the name of the row that has been affected.
@@ -322,6 +325,7 @@ void WindowStyles::on_treeview_styles_collapsed_expanded(GtkTreeIter * iter, Gtk
   }
 }
 
+
 void WindowStyles::expand_all()
 {
   gtk_tree_view_expand_all(GTK_TREE_VIEW(treeview));
@@ -330,16 +334,19 @@ void WindowStyles::expand_all()
   gtk_widget_queue_draw(treeview);
 }
 
+
 void WindowStyles::collapse_all()
 {
   gtk_tree_view_collapse_all(GTK_TREE_VIEW(treeview));
 }
 
+
 void WindowStyles::on_row_activated(GtkTreeView * treeview, GtkTreePath * path, GtkTreeViewColumn * column, gpointer user_data)
 {
   ((WindowStyles *) user_data)->row_activated();
 }
 
+
 void WindowStyles::row_activated()
 {
   bool editmode = style_edit_mode && gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(style_edit_mode));
@@ -350,18 +357,21 @@ void WindowStyles::row_activated()
   }
 }
 
+
 void WindowStyles::insert()
 // Insert a style in the editor.
 {
   gtk_button_clicked(GTK_BUTTON(apply_signal));
 }
 
+
 ustring WindowStyles::get_focus()
 // Return the focused style.
 {
   return get_focused_style();
 }
 
+
 void WindowStyles::use(const ustring & marker)
 // Adapt GUI to using this style.
 {
@@ -375,8 +385,10 @@ void WindowStyles::use(const ustring & marker)
   settings->session.selected_style = complete_style;
 }
 
+
 #define RECENTLY_USED "Recently Used"
 
+
 void WindowStyles::load_recently_used_styles()
 // Sets the recently used styles in the treeview.
 {
@@ -418,6 +430,7 @@ void WindowStyles::load_recently_used_styles()
     gtk_main_iteration();
 }
 
+
 vector < ustring > WindowStyles::get_focused_regular_styles()
 {
   // Containers.
@@ -439,6 +452,7 @@ vector < ustring > WindowStyles::get_focused_regular_styles()
   return focused_styles;
 }
 
+
 vector < ustring > WindowStyles::get_focused_recently_used_styles()
 {
   // Containers.
@@ -460,6 +474,7 @@ vector < ustring > WindowStyles::get_focused_recently_used_styles()
   return focused_styles;
 }
 
+
 vector < ustring > WindowStyles::get_focused_categories()
 {
   // Containers.
@@ -478,17 +493,20 @@ vector < ustring > WindowStyles::get_focused_categories()
   return focused_categories;
 }
 
+
 ustring WindowStyles::get_sheet()
 // Returns the object's stylesheet.
 {
   return mystylesheet;
 }
 
+
 void WindowStyles::on_style_menu_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
   ((WindowStyles *) user_data)->on_style_menu();
 }
 
+
 void WindowStyles::on_style_menu()
 {
   // Some variables to be used to (dis/en)able menu items.
@@ -515,16 +533,19 @@ void WindowStyles::on_style_menu()
     gtk_widget_set_sensitive(stylesheet_rename, !mystylesheet.empty());
 }
 
+
 void WindowStyles::on_expand_all_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
   ((WindowStyles *) user_data)->expand_all();
 }
 
+
 void WindowStyles::on_collapse_all_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
   ((WindowStyles *) user_data)->collapse_all();
 }
 
+
 void WindowStyles::show_styles_popup_menu(GtkWidget * my_widget, GdkEventButton * event)
 {
   int button, event_time;
@@ -539,11 +560,13 @@ void WindowStyles::show_styles_popup_menu(GtkWidget * my_widget, GdkEventButton
   gtk_menu_popup(GTK_MENU(style_menu), NULL, NULL, NULL, NULL, button, event_time);
 }
 
+
 void WindowStyles::on_style_new_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
   ((WindowStyles *) user_data)->on_style_new();
 }
 
+
 void WindowStyles::on_style_new()
 {
   // Do nothing if this widget does not display.
@@ -584,11 +607,13 @@ void WindowStyles::on_style_new()
   focus_string(focus);
 }
 
+
 void WindowStyles::on_style_properties_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
   ((WindowStyles *) user_data)->on_style_properties();
 }
 
+
 void WindowStyles::on_style_properties()
 {
   // If inactive, bail out.
@@ -609,11 +634,13 @@ void WindowStyles::on_style_properties()
   }
 }
 
+
 void WindowStyles::on_style_delete_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
   ((WindowStyles *) user_data)->on_style_delete();
 }
 
+
 void WindowStyles::on_style_delete()
 {
   // If inactive, bail out.
@@ -649,11 +676,13 @@ void WindowStyles::on_style_delete()
   focus_string(string_before_focus);
 }
 
+
 void WindowStyles::on_style_insert_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
   ((WindowStyles *) user_data)->insert();
 }
 
+
 void WindowStyles::stylesheet_open(const ustring & stylesheet)
 // Open a stylesheet, initiated by this object.
 {
@@ -661,11 +690,13 @@ void WindowStyles::stylesheet_open(const ustring & stylesheet)
   gtk_button_clicked(GTK_BUTTON(open_signal));
 }
 
+
 void WindowStyles::on_stylesheet_new_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
   ((WindowStyles *) user_data)->on_stylesheet_new();
 }
 
+
 void WindowStyles::on_stylesheet_new()
 {
   // Show dialog. Bail out on Cancel.
@@ -678,11 +709,13 @@ void WindowStyles::on_stylesheet_new()
   stylesheet_open(dialog.name);
 }
 
+
 void WindowStyles::on_stylesheet_delete_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
   ((WindowStyles *) user_data)->on_stylesheet_delete();
 }
 
+
 void WindowStyles::on_stylesheet_delete()
 {
   OpenStylesheetDialog dialog(osdtDelete, mystylesheet);
@@ -693,11 +726,13 @@ void WindowStyles::on_stylesheet_delete()
   }
 }
 
+
 void WindowStyles::on_stylesheet_rename_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
   ((WindowStyles *) user_data)->on_stylesheet_rename();
 }
 
+
 void WindowStyles::on_stylesheet_rename()
 {
   // Ask for a new name.
@@ -717,10 +752,6 @@ void WindowStyles::on_stylesheet_rename()
   }
 }
 
-void WindowStyles::on_stylesheet_import_activate(GtkMenuItem * menuitem, gpointer user_data)
-{
-  ((WindowStyles *) user_data)->on_stylesheet_import();
-}
 
 void WindowStyles::on_stylesheet_import()
 {
@@ -733,6 +764,7 @@ void WindowStyles::on_stylesheet_import()
   }
 }
 
+
 void WindowStyles::export_sheet(const ustring& filename)
 {
   if (filename.empty())
@@ -740,11 +772,13 @@ void WindowStyles::export_sheet(const ustring& filename)
   stylesheet_export(mystylesheet, filename);
 }
 
+
 void WindowStyles::on_stylesheet_switch_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
   ((WindowStyles *) user_data)->on_stylesheet_switch();
 }
 
+
 void WindowStyles::on_stylesheet_switch()
 {
   OpenStylesheetDialog dialog(osdtSwitch, mystylesheet);
@@ -754,6 +788,7 @@ void WindowStyles::on_stylesheet_switch()
   }
 }
 
+
 bool WindowStyles::styletree_expand_collapse(bool expand)
 // Expands (or collapses) the selected item(s) in the treeview.
 {
@@ -785,6 +820,7 @@ bool WindowStyles::styletree_expand_collapse(bool expand)
   return expanded_collapsed;
 }
 
+
 void WindowStyles::delete_categories(vector < ustring > categories)
 {
   // Get a list of all the markers in our stylesheet.
@@ -814,6 +850,7 @@ void WindowStyles::delete_categories(vector < ustring > categories)
   }
 }
 
+
 ustring WindowStyles::get_string_before_focus()
 // This returns the visible text just before the first focused item.
 {
@@ -871,6 +908,7 @@ ustring WindowStyles::get_string_before_focus()
   return returnvalue;
 }
 
+
 ustring WindowStyles::get_focused_style()
 {
   // Containers.
@@ -895,6 +933,7 @@ ustring WindowStyles::get_focused_style()
   return focused_style;
 }
 
+
 void WindowStyles::focus_string(const ustring & string)
 // Focuses "string" in the treeview.
 {
@@ -942,6 +981,7 @@ void WindowStyles::focus_string(const ustring & string)
     gtk_main_iteration();
 }
 
+
 void WindowStyles::focus_iter(GtkTreeIter * iter, bool expand)
 {
   GtkTreeModel *model = GTK_TREE_MODEL(treestore);
@@ -956,6 +996,7 @@ void WindowStyles::focus_iter(GtkTreeIter * iter, bool expand)
     gtk_main_iteration();
 }
 
+
 size_t WindowStyles::get_expanded_state_offset(const ustring & row)
 {
   size_t offset = 0;            // Default: recently used.
@@ -1002,6 +1043,7 @@ size_t WindowStyles::get_expanded_state_offset(const ustring & row)
   return offset;
 }
 
+
 void WindowStyles::use_style(const ustring & style)
 // "Uses" a style, and so ranks it at the top of the recently used styles,
 // and updates both the store and the configuration.
@@ -1055,6 +1097,7 @@ void WindowStyles::use_style(const ustring & style)
   }
 }
 
+
 void WindowStyles::clear_recently_used_styles()
 {
   vector < ustring > styles;
@@ -1062,6 +1105,7 @@ void WindowStyles::clear_recently_used_styles()
   stylesheet_set_recently_used(mystylesheet, styles, count);
 }
 
+
 void WindowStyles::clear_recently_used_style(const ustring & style)
 {
   // Remove the style.
@@ -1076,6 +1120,7 @@ void WindowStyles::clear_recently_used_style(const ustring & style)
   store_recently_used_data();
 }
 
+
 void WindowStyles::load_stylesheet()
 // Load a whole stylesheet.
 {
@@ -1129,6 +1174,7 @@ void WindowStyles::load_stylesheet()
   }
 }
 
+
 void WindowStyles::get_focused_strings(vector < ustring > &focused_strings, vector < bool > &recently_used, vector < bool > &categories)
 {
   // Get the model
@@ -1174,6 +1220,7 @@ void WindowStyles::get_focused_strings(vector < ustring > &focused_strings, vect
   g_list_free(sellist);
 }
 
+
 bool WindowStyles::get_expanded_state(const ustring & row)
 // Taking the string in "row", this returns the expanded state.
 {
@@ -1185,6 +1232,7 @@ bool WindowStyles::get_expanded_state(const ustring & row)
   return state;
 }
 
+
 ustring WindowStyles::get_name(const ustring & marker)
 // Returns the name of the marker.
 {
@@ -1196,6 +1244,7 @@ ustring WindowStyles::get_name(const ustring & marker)
   return "Unknown";
 }
 
+
 void WindowStyles::retrieve_recently_used_data()
 // Retrieves the recently used styles and usage counts from disk.
 {
@@ -1207,6 +1256,7 @@ void WindowStyles::retrieve_recently_used_data()
   process_recently_used_data();
 }
 
+
 void WindowStyles::process_recently_used_data()
 // Do some processing on the data of the recently used styles.
 {
@@ -1231,6 +1281,7 @@ void WindowStyles::process_recently_used_data()
   allrecentmarkers = existing_ones;
 }
 
+
 void WindowStyles::store_recently_used_data()
 // Stores the recently used styles and usage count to disk.
 {
